@@ -20,17 +20,7 @@
 
 #if defined(__linux__)
 
-#define _GNU_SOURCE
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <unistd.h>
 #include <glob.h>
-#include <limits.h>
-#include <errno.h>
-#include <sched.h>
 
 #if defined(__linux__)
 #define SYS_CPU_PREFIX               "/sys/devices/system/cpu"
@@ -56,6 +46,18 @@ static const struct generic_map cache_type_map[] = {
 static const char *get_cache_name(cache_type_t type)
 	__attribute__((unused));
 
+/**
+ *
+ * cache_get_cpu()
+ *
+ **/
+static inline unsigned int cache_get_cpu(const cpus_t *cpus)
+{
+	const unsigned int cpu = stress_get_cpu();
+
+	return (cpu >= cpus->count) ? 0 : cpu;
+}
+
 /**
  * file_exists()
  * @path: file to check.
@@ -374,13 +376,9 @@ uint16_t get_max_cache_level(const cpus_t *cpus)
 		return 0;
 	}
 
-	/* 
-	 * FIXME: should really determine current CPU index using
-	 * sched_getcpu(3) rather than just taking the first cpu.
-	 */
-	cpu = &cpus->cpus[0];
+	cpu = &cpus->cpus[cache_get_cpu(cpus)];
 
-	for (i=0; i < cpu->cache_count; i++) {
+	for (i = 0; i < cpu->cache_count; i++) {
 		cpu_cache_t *cache;
 
 		cache = &cpu->caches[i];
@@ -413,10 +411,7 @@ cpu_cache_t * get_cpu_cache(const cpus_t *cpus, const uint16_t cache_level)
 		return NULL;
 	}
 
-	/* FIXME: should really determine current CPU index using
-	 * sched_getcpu(3) rather than just taking the first cpu.
-	 */
-	cpu = &cpus->cpus[0];
+	cpu = &cpus->cpus[cache_get_cpu(cpus)];
 
 	return get_cache_by_cpu(cpu, cache_level);
 }
@@ -592,6 +587,7 @@ cpus_t * get_all_cpu_cache_details(void)
 			cpu->online = 1;
 		} else {
 			len = strlen(results[i]);
+			strncpy(path, results[i], len);
 			MK_PATH(path, len, "/online");
 
 			contents = get_string_from_file(path);
