@@ -22,33 +22,18 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
 
-#include <stdio.h>
-#include <stdint.h>
-#include <stdlib.h>
-#include <stdbool.h>
-#include <string.h>
-#include <unistd.h>
-#include <fcntl.h>
-#include <limits.h>
-#include <inttypes.h>
 #include <libgen.h>
-#include <signal.h>
-#include <time.h>
 #include <math.h>
-#include <signal.h>
-#include <sys/ioctl.h>
-#include <sys/stat.h>
-#include <sys/types.h>
 #if defined(__linux__)
 #include <sys/utsname.h>
 #include <sys/sysinfo.h>
 #include <sys/prctl.h>
 #endif
-#include <sys/resource.h>
+#if !defined(__NetBSD__) && !defined(__OpenBSD__) && !defined(__FreeBSD__)
+#include <sys/utsname.h>
+#endif
 
 #if !defined(PR_SET_DISABLE)
 #define SUID_DUMP_DISABLE	(0)       /* No setuid dumping */
@@ -69,7 +54,7 @@ static const char *stress_temp_path = ".";
  */
 size_t stress_get_pagesize(void)
 {
-#ifdef _SC_PAGESIZE
+#if defined(_SC_PAGESIZE)
 	long sz;
 #endif
 	static size_t page_size = 0;
@@ -77,11 +62,11 @@ size_t stress_get_pagesize(void)
 	if (page_size > 0)
 		return page_size;
 
-#ifdef _SC_PAGESIZE
+#if defined(_SC_PAGESIZE)
         sz = sysconf(_SC_PAGESIZE);
 	page_size = (sz <= 0) ? PAGE_4K : (size_t)sz;
 #else
-        page_size = PAGE_4K;
+	page_size = PAGE_4K;
 #endif
 
 	return page_size;
@@ -98,7 +83,7 @@ int32_t stress_get_processors_online(void)
 	if (processors_online > 0)
 		return processors_online;
 
-#ifdef _SC_NPROCESSORS_ONLN
+#if defined(_SC_NPROCESSORS_ONLN)
 	processors_online = (int32_t)sysconf(_SC_NPROCESSORS_ONLN);
 	if (processors_online < 0)
 		processors_online = 1;
@@ -119,7 +104,7 @@ int32_t stress_get_processors_configured(void)
 	if (processors_configured > 0)
 		return processors_configured;
 
-#ifdef _SC_NPROCESSORS_CONF
+#if defined(_SC_NPROCESSORS_CONF)
 	processors_configured = (int32_t)sysconf(_SC_NPROCESSORS_CONF);
 	if (processors_configured < 0)
 		processors_configured = stress_get_processors_online();
@@ -140,7 +125,7 @@ int32_t stress_get_ticks_per_second(void)
 	if (ticks_per_second > 0)
 		return ticks_per_second;
 
-#ifdef _SC_CLK_TCK
+#if defined(_SC_CLK_TCK)
 	ticks_per_second = sysconf(_SC_CLK_TCK);
 	return ticks_per_second;
 #else
@@ -275,7 +260,7 @@ int stress_process_dumpable(const bool dumpable)
 	(void)prctl(PR_SET_DUMPABLE,
 		dumpable ? SUID_DUMP_USER : SUID_DUMP_DISABLE);
 #endif
-	snprintf(path, sizeof(path), "/proc/%u/coredump_filter", getpid());
+	snprintf(path, sizeof(path), "/proc/%d/coredump_filter", (int)getpid());
 	if ((fd = open(path, O_WRONLY)) >= 0) {
 		char const *str =
 			dumpable ? "0x33" : "0x00";
@@ -329,10 +314,11 @@ void set_proc_name(const char *name)
  *  munge_underscore()
  *	turn '_' to '-' in strings
  */
-char *munge_underscore(char *str)
+char *munge_underscore(const char *str)
 {
 	static char munged[128];
-	char *src, *dst;
+	char *dst;
+	const char *src;
 	size_t str_len = strlen(str);
 	ssize_t len = STRESS_MINIMUM(str_len, sizeof(munged) - 1);
 
@@ -344,16 +330,30 @@ char *munge_underscore(char *str)
 	return munged;
 }
 
+static ssize_t __stress_get_stack_direction(const uint8_t *val1)
+{
+	const uint8_t val2;
+	const ssize_t diff = &val2 - (const uint8_t *)val1;
+
+	return (diff > 0) - (diff < 0);
+}
+
 /*
  *  stress_get_stack_direction()
  *      determine which way the stack goes, up / down
  *	just pass in any var on the stack before calling
+ *	return:
+ *		 1 - stack goes down (conventional)
+ *		 0 - error
+ *	  	-1 - stack goes up (unconventional)
  */
-ssize_t stress_get_stack_direction(const void *val1)
+ssize_t stress_get_stack_direction(void)
 {
-	uint8_t val2;
+	uint8_t val1 = 0;
+	uint8_t waste[64];
 
-	return ((uint8_t *)val1 - &val2) > 0 ? 1 : -1;
+	waste[(sizeof waste) - 1] = 0;
+	return __stress_get_stack_direction(&val1);
 }
 
 /*
@@ -398,12 +398,12 @@ int stress_temp_filename(
         const uint32_t instance,
         const uint64_t magic)
 {
-	return snprintf(path, len, "%s/tmp-%s-%i-%"
-		PRIu32 "/%s-%i-%"
+	return snprintf(path, len, "%s/tmp-%s-%d-%"
+		PRIu32 "/%s-%d-%"
                 PRIu32 "-%" PRIu64,
 		stress_temp_path,
-                name, pid, instance,
-		name, pid, instance, magic);
+                name, (int)pid, instance,
+		name, (int)pid, instance, magic);
 }
 
 /*
@@ -417,8 +417,8 @@ int stress_temp_dir(
         const pid_t pid,
         const uint32_t instance)
 {
-	return snprintf(path, len, "%s/tmp-%s-%i-%" PRIu32,
-		stress_temp_path, name, pid, instance);
+	return snprintf(path, len, "%s/tmp-%s-%d-%" PRIu32,
+		stress_temp_path, name, (int)pid, instance);
 }
 
 /*
@@ -538,7 +538,7 @@ void pr_yaml_runinfo(FILE *yaml)
 	time_t t;
 	struct tm *tm = NULL;
 	char hostname[128];
-	char *user = getlogin();
+	char *user = shim_getlogin();
 
 	pr_yaml(yaml, "system-info:\n");
 	if (time(&t) != ((time_t)-1))
@@ -574,9 +574,9 @@ void pr_yaml_runinfo(FILE *yaml)
 	}
 #endif
 	pr_yaml(yaml, "      pagesize: %zd\n", stress_get_pagesize());
-	pr_yaml(yaml, "      cpus: %ld\n", stress_get_processors_configured());
-	pr_yaml(yaml, "      cpus-online: %ld\n", stress_get_processors_online());
-	pr_yaml(yaml, "      ticks-per-second: %ld\n", stress_get_ticks_per_second());
+	pr_yaml(yaml, "      cpus: %" PRId32 "\n", stress_get_processors_configured());
+	pr_yaml(yaml, "      cpus-online: %" PRId32 "\n", stress_get_processors_online());
+	pr_yaml(yaml, "      ticks-per-second: %" PRId32 "\n", stress_get_ticks_per_second());
 	pr_yaml(yaml, "\n");
 }
 
@@ -588,7 +588,7 @@ void pr_yaml_runinfo(FILE *yaml)
 int stress_cache_alloc(const char *name)
 {
 #if defined(__linux__)
-	cpus_t *cpu_caches = NULL;
+	cpus_t *cpu_caches;
 	cpu_cache_t *cache = NULL;
 	uint16_t max_cache_level = 0;
 #endif
@@ -827,3 +827,142 @@ int stress_sigrestore(
 	}
 	return 0;
 }
+
+/*
+ *  stress_get_cpu()
+ *	get cpu number that process is currently on
+ */
+unsigned int stress_get_cpu(void)
+{
+#if defined(__linux__)
+	int cpu;
+
+	cpu = sched_getcpu();
+	return (unsigned int)((cpu < 0) ? 0 : cpu);
+#else
+	return 0;
+#endif
+}
+
+/*
+ *  stress_not_implemented()
+ *	report that a stressor is not implemented
+ *	on a particular arch or kernel
+ */
+int stress_not_implemented(
+        uint64_t *const counter,
+        const uint32_t instance,
+        const uint64_t max_ops,
+        const char *name)
+{
+	(void)counter;
+	(void)instance;
+	(void)max_ops;
+
+#if !defined(__NetBSD__) && !defined(__OpenBSD__) && !defined(__FreeBSD__)
+	struct utsname buf;
+
+	if (!uname(&buf)) {
+		pr_inf(stderr, "%s: this stressor is not implemented on this system: %s %s %s\n",
+			name, buf.machine, buf.sysname, buf.release);
+		return EXIT_NOT_IMPLEMENTED;
+	}
+#endif
+	pr_inf(stderr, "%s: this stressor is not implemented on this system\n",
+		name);
+	return EXIT_NOT_IMPLEMENTED;
+}
+
+#if defined(__linux__) && defined(F_SETPIPE_SZ)
+/*
+ *  stress_check_max_pipe_size()
+ *	check if the given pipe size is allowed
+ */
+static inline size_t stress_check_max_pipe_size(
+	const size_t sz,
+	const size_t page_size)
+{
+	int fds[2];
+
+	if (sz < page_size)
+		return -1;
+
+	if (pipe(fds) < 0)
+		return -1;
+
+	if (fcntl(fds[0], F_SETPIPE_SZ, sz) < 0)
+		return -1;
+
+	(void)close(fds[0]);
+	(void)close(fds[1]);
+	return 0;
+}
+#endif
+
+/*
+ *  stress_probe_max_pipe_size()
+ *	determine the maximim allowed pipe size
+ */
+size_t stress_probe_max_pipe_size(void)
+{
+	static size_t max_pipe_size;
+
+#if defined(__linux__) && defined(F_SETPIPE_SZ)
+	size_t i, ret, prev_sz, sz, min, max;
+	char buf[64];
+	size_t page_size;
+#endif
+	/* Already determined? returned cached size */
+	if (max_pipe_size)
+		return max_pipe_size;
+
+#if defined(__linux__) && defined(F_SETPIPE_SZ)
+	page_size = stress_get_pagesize();
+
+	/*
+	 *  Try and find maximum pipe size directly
+	 */
+	ret = system_read("/proc/sys/fs/pipe-max-size", buf, sizeof(buf));
+	if (ret > 0) {
+		if (sscanf(buf, "%zd", &sz) == 1)
+			if (!stress_check_max_pipe_size(sz, page_size))
+				goto ret;
+	}
+
+	/*
+	 *  Need to find size by binary chop probing
+	 */
+	min = page_size;
+	max = INT_MAX;
+	prev_sz = 0;
+	for (i = 0; i < 64; i++) {
+		sz = min + (max - min) / 2;
+		if (prev_sz == sz)
+			return sz;
+		prev_sz = sz;
+		if (stress_check_max_pipe_size(sz, page_size) == 0) {
+			min = sz;
+		} else {
+			max = sz;
+		}
+	}
+ret:
+	max_pipe_size = sz;
+#else
+	max_pipe_size = stress_get_pagesize();
+
+#endif
+	return max_pipe_size;
+}
+
+/*
+ *  align_address
+ *	align address to alignment, alignment MUST be a power of 2
+ */
+void *align_address(const void *addr, const size_t alignment)
+{
+	const uintptr_t uintptr =
+		((uintptr_t)addr + alignment) & ~(alignment - 1);
+
+	return (void *)uintptr;
+}
