@@ -22,17 +22,6 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
-#include <stdio.h>
-#include <stdint.h>
-#include <stdlib.h>
-#include <stdbool.h>
-#include <unistd.h>
-#include <sys/types.h>
-#include <sys/wait.h>
-#include <signal.h>
-
 #include "stress-ng.h"
 
 typedef struct {
@@ -85,7 +74,7 @@ void ignite_cpu_start(void)
 		len = strlen(buf);
 		if (len == 0)
 			continue;
-	
+
 		settings[i].default_setting_len =
 			strlen(settings[i].default_setting);
 		/* If we can't update the setting, skip it */
@@ -122,7 +111,7 @@ void ignite_cpu_start(void)
 		return;
 	} else if (pid == 0) {
 		/* Child */
-		setpgid(0, pgrp);
+		(void)setpgid(0, pgrp);
 		stress_parent_died_alarm();
 
 		for (;;) {
@@ -137,7 +126,7 @@ void ignite_cpu_start(void)
 		}
 	} else {
 		/* Parent */
-		setpgid(pid, pgrp);
+		(void)setpgid(pid, pgrp);
 	}
 }
 
