@@ -22,18 +22,8 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <errno.h>
-#if defined(__linux__)
-#include <sys/syscall.h>
-#endif
-
 /*
  *  get_opt_ionice_class()
  *	string io scheduler to IOPRIO_CLASS
@@ -73,12 +63,12 @@ int32_t get_opt_ionice_class(const char *const str)
 }
 
 /*
- *  sys_ioprio_set()
+ *  shim_ioprio_set()
  *	ioprio_set system call
  */
-int sys_ioprio_set(int which, int who, int ioprio)
+int shim_ioprio_set(int which, int who, int ioprio)
 {
-#if defined(STRESS_IOPRIO) && defined(__NR_ioprio_set)
+#if defined(__linux__) && defined(__NR_ioprio_set)
         return syscall(__NR_ioprio_set, which, who, ioprio);
 #else
 	(void)which;
@@ -91,12 +81,12 @@ int sys_ioprio_set(int which, int who, int ioprio)
 }
 
 /*
- *  sys_ioprio_get()
+ *  shim_ioprio_get()
  *	ioprio_get system call
  */
-int sys_ioprio_get(int which, int who)
+int shim_ioprio_get(int which, int who)
 {
-#if defined(STRESS_IOPRIO) && defined(__NR_ioprio_get)
+#if defined(__linux__) && defined(__NR_ioprio_get)
         return syscall(__NR_ioprio_get, which, who);
 #else
 	(void)which;
@@ -107,7 +97,7 @@ int sys_ioprio_get(int which, int who)
 #endif
 }
 
-#if defined(STRESS_IOPRIO) && defined(__NR_ioprio_set)
+#if defined(__linux__) && defined(__NR_ioprio_set)
 /*
  *  set_iopriority()
  *	check ioprio settings and set
@@ -138,7 +128,7 @@ void set_iopriority(const int32_t class, const int32_t level)
 		fprintf(stderr, "Unknown priority class: %d\n", class);
 		exit(EXIT_FAILURE);
 	}
-	rc = sys_ioprio_set(IOPRIO_WHO_PROCESS, 0,
+	rc = shim_ioprio_set(IOPRIO_WHO_PROCESS, 0,
 		IOPRIO_PRIO_VALUE(class, data));
 	if (rc < 0) {
 		fprintf(stderr, "Cannot set I/O priority: errno=%d (%s)\n",
