@@ -22,16 +22,8 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <stdarg.h>
-#include <errno.h>
-#include <syslog.h>
-
 #include "stress-ng.h"
+#include <syslog.h>
 
 static uint16_t	abort_fails;	/* count of failures */
 static bool	abort_msg_emitted;
@@ -113,8 +105,8 @@ int pr_msg(
 		if (opt_flags & OPT_FLAGS_LOG_BRIEF) {
 			ret = vfprintf(fp, fmt, ap);
 		} else {
-			int n = snprintf(buf, sizeof(buf), "%s [%i] ",
-				type, getpid());
+			int n = snprintf(buf, sizeof(buf), "%s [%d] ",
+				type, (int)getpid());
 			ret = vsnprintf(buf + n, sizeof(buf) - n, fmt, ap);
 			fprintf(fp, "%s: %s", app_name, buf);
 		}
