@@ -22,31 +22,17 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
+#include "stress-ng.h"
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <string.h>
-#include <stdbool.h>
-#include <signal.h>
-#include <unistd.h>
-#include <errno.h>
-
-#include <sys/types.h>
-#include <sys/socket.h>
-#include <sys/wait.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
-#ifdef AF_INET6
+#if defined(AF_INET6)
 #include <netinet/in.h>
 #endif
-#ifdef AF_UNIX
+#if defined(AF_UNIX)
 #include <sys/un.h>
 #endif
 
-#include "stress-ng.h"
-
 typedef struct {
 	const char *name;
 	const int  domain;
@@ -57,7 +43,6 @@ static const domain_t domains[] = {
 	{ "ipv4",	AF_INET,	DOMAIN_INET },
 	{ "ipv6",	AF_INET6,	DOMAIN_INET6 },
 	{ "unix",	AF_UNIX,	DOMAIN_UNIX },
-	{ NULL,		-1, ~0 }
 };
 
 /*
@@ -88,7 +73,7 @@ int stress_set_net_domain(
 {
 	size_t i;
 
-	for (i = 0; domains[i].name; i++) {
+	for (i = 0; i < SIZEOF_ARRAY(domains); i++) {
 		if ((domain_mask & domains[i].domain_flags) &&
 		    !strcmp(domain_name, domains[i].name)) {
 			*domain = domains[i].domain;
@@ -96,7 +81,7 @@ int stress_set_net_domain(
 		}
 	}
 	fprintf(stderr, "%s: domain must be one of:", name);
-	for (i = 0; domains[i].name; i++)
+	for (i = 0; i < SIZEOF_ARRAY(domains); i++)
 		if (domain_mask & domains[i].domain_flags)
 			fprintf(stderr, " %s", domains[i].name);
 	fprintf(stderr, "\n");
@@ -118,7 +103,7 @@ void stress_set_sockaddr(
 	int net_addr)
 {
 	switch (domain) {
-#ifdef AF_INET
+#if defined(AF_INET)
 	case AF_INET: {
 		static struct sockaddr_in addr;
 
@@ -139,7 +124,7 @@ void stress_set_sockaddr(
 		break;
 	}
 #endif
-#ifdef AF_INET6
+#if defined(AF_INET6)
 	case AF_INET6: {
 		static struct sockaddr_in6 addr;
 #if defined(__minix__)
@@ -163,7 +148,7 @@ void stress_set_sockaddr(
 		break;
 	}
 #endif
-#ifdef AF_UNIX
+#if defined(AF_UNIX)
 	case AF_UNIX: {
 		static struct sockaddr_un addr;
 
@@ -171,7 +156,7 @@ void stress_set_sockaddr(
 		addr.sun_family = AF_UNIX;
 		snprintf(addr.sun_path, sizeof(addr.sun_path),
 			"/tmp/stress-ng-%d-%" PRIu32,
-			ppid, instance);
+			(int)ppid, instance);
 		*sockaddr = (struct sockaddr *)&addr;
 		*len = sizeof(addr);
 		break;
@@ -193,7 +178,7 @@ void HOT stress_set_sockaddr_port(
 	struct sockaddr *sockaddr)
 {
 	switch (domain) {
-#ifdef AF_INET
+#if defined(AF_INET)
 	case AF_INET: {
 		struct sockaddr_in *addr = (struct sockaddr_in *)sockaddr;
 
@@ -201,14 +186,14 @@ void HOT stress_set_sockaddr_port(
 		break;
 	}
 #endif
-#ifdef AF_INET6
+#if defined(AF_INET6)
 	case AF_INET6: {
 		struct sockaddr_in6 *addr = (struct sockaddr_in6 *)sockaddr;
 		addr->sin6_port = htons(port);
 		break;
 	}
 #endif
-#ifdef AF_UNIX
+#if defined(AF_UNIX)
 	case AF_UNIX:
 		break;
 #endif
