@@ -22,18 +22,6 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
-#include <stdio.h>
-#include <stdbool.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <string.h>
-#include <unistd.h>
-#include <ctype.h>
-#include <inttypes.h>
-#include <errno.h>
-
 #include "stress-ng.h"
 
 /*
@@ -75,10 +63,10 @@ void check_range(
  */
 static void ensure_positive(const char *const str)
 {
-	char *ptr;
+	const char *ptr;
 	bool negative = false;
 
-	for (ptr = (char *)str; *ptr; ptr++) {
+	for (ptr = str; *ptr; ptr++) {
 		if (*ptr == '-') {
 			negative = true;
 			continue;
