@@ -22,21 +22,14 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
 #include "perf-event.h"
 
 #if defined(STRESS_PERF_STATS)
 /* perf enabled systems */
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <unistd.h>
 #include <locale.h>
-#include <pthread.h>
-#include <ctype.h>
+#include <linux/perf_event.h>
 
 #define THOUSAND	(1000.0)
 #define MILLION		(THOUSAND * THOUSAND)
@@ -46,10 +39,6 @@
 #define QUINTILLION	(THOUSAND * QUADRILLION)
 
 
-#include <sys/ioctl.h>
-#include <sys/syscall.h>
-#include <linux/perf_event.h>
-
 /* used for table of perf events to gather */
 typedef struct {
 	int id;				/* stress-ng perf ID */
@@ -640,7 +629,7 @@ void perf_stat_dump(
 		if (!got_data)
 			continue;
 
-		munged = munge_underscore((char *)stressors[i].name);
+		munged = munge_underscore(stressors[i].name);
 		pr_inf(stdout, "%s:\n", munged);
 		pr_yaml(yaml, "    - stressor: %s\n", munged);
 		pr_yaml(yaml, "      duration: %f\n", duration);
