@@ -22,17 +22,6 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <unistd.h>
-#include <errno.h>
-#if (defined(_POSIX_PRIORITY_SCHEDULING) || defined(__linux__)) && \
-    !defined(__OpenBSD__)
-#include <sched.h>
-#endif
-
 #include "stress-ng.h"
 
 #if (defined(_POSIX_PRIORITY_SCHEDULING) || defined(__linux__)) && \
@@ -41,7 +30,7 @@
  *  get_sched_name()
  *	convert sched class to human readable string
  */
-static const char *get_sched_name(const int32_t sched)
+const char *get_sched_name(const int sched)
 {
 	switch (sched) {
 #if defined(SCHED_IDLE)
@@ -80,7 +69,7 @@ static const char *get_sched_name(const int32_t sched)
  *  set_sched()
  * 	are sched settings valid, if so, set them
  */
-void set_sched(const int32_t sched, const int32_t sched_priority)
+void set_sched(const int sched, const int32_t sched_priority)
 {
 #if defined(SCHED_FIFO) || defined(SCHED_RR)
 	int min, max;
@@ -154,49 +143,49 @@ void set_sched(const int32_t sched, const int32_t sched_priority)
  */
 int32_t get_opt_sched(const char *const str)
 {
-#ifdef SCHED_OTHER
+#if defined(SCHED_OTHER)
 	if (!strcmp("other", str))
 		return SCHED_OTHER;
 #endif
-#ifdef SCHED_BATCH
+#if defined(SCHED_BATCH)
 	if (!strcmp("batch", str))
 		return SCHED_BATCH;
 #endif
-#ifdef SCHED_IDLE
+#if defined(SCHED_IDLE)
 	if (!strcmp("idle", str))
 		return SCHED_IDLE;
 #endif
-#ifdef SCHED_FIFO
+#if defined(SCHED_FIFO)
 	if (!strcmp("fifo", str))
 		return SCHED_FIFO;
 #endif
-#ifdef SCHED_RR
+#if defined(SCHED_RR)
 	if (!strcmp("rr", str))
 		return SCHED_RR;
 #endif
-#ifdef SCHED_DEADLINE
+#if defined(SCHED_DEADLINE)
 	if (!strcmp("deadline", str))
 		return SCHED_DEADLINE;
 #endif
 	if (strcmp("which", str))
 		fprintf(stderr, "Invalid sched option: %s\n", str);
 	fprintf(stderr, "Available scheduler options are:"
-#ifdef SCHED_OTHER
+#if defined(SCHED_OTHER)
 		" other"
 #endif
-#ifdef SCHED_BATCH
+#if defined(SCHED_BATCH)
 		" batch"
 #endif
-#ifdef SCHED_DEADLINE
+#if defined(SCHED_DEADLINE)
 		" deadline"
 #endif
-#ifdef SCHED_IDLE
+#if defined(SCHED_IDLE)
 		" idle"
 #endif
-#ifdef SCHED_FIFO
+#if defined(SCHED_FIFO)
 		" fifo"
 #endif
-#ifdef SCHED_FIFO
+#if defined(SCHED_FIFO)
 		" rr"
 #endif
 		"\n");
