@@ -22,18 +22,10 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
 
-#if defined(STRESS_AF_ALG)
+#if defined(__linux__) && defined(AF_ALG)
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <unistd.h>
-#include <string.h>
-#include <sys/socket.h>
 #include <linux/if_alg.h>
 #include <linux/socket.h>
 
@@ -134,7 +126,7 @@ static alg_rng_info_t algo_rng_info[] = {
 	{ "jitterentropy_rng" }
 };
 
-int stress_af_alg_hash(
+static int stress_af_alg_hash(
 	uint64_t *const counter,
 	const uint64_t max_ops,
 	const char *name,
@@ -199,7 +191,7 @@ int stress_af_alg_hash(
 	return EXIT_SUCCESS;
 }
 
-int stress_af_alg_cipher(
+static int stress_af_alg_cipher(
 	uint64_t *const counter,
 	const uint64_t max_ops,
 	const char *name,
@@ -350,7 +342,7 @@ int stress_af_alg_cipher(
 	return EXIT_SUCCESS;
 }
 
-int stress_af_alg_rng(
+static int stress_af_alg_rng(
 	uint64_t *const counter,
 	const uint64_t max_ops,
 	const char *name,
@@ -440,7 +432,7 @@ int stress_af_alg(
 		 * cipher modules which can be racy or
 		 * take some time
 		 */
-		usleep(200000);
+		(void)shim_usleep(200000);
 	}
 
 	do {
@@ -469,4 +461,13 @@ tidy:
 
 	return rc;
 }
+#else
+int stress_af_alg(
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
+{
+	return stress_not_implemented(counter, instance, max_ops, name);
+}
 #endif
