@@ -22,18 +22,9 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
 
-#if defined(STRESS_AFFINITY)
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <unistd.h>
-#include <sched.h>
-
+#if defined(__linux__) && NEED_GLIBC(2,3,0)
 
 /*
  *  stress on sched_affinity()
@@ -67,9 +58,7 @@ int stress_affinity(
 			pr_fail(stderr, "%s: failed to move to CPU %" PRIu32
 				", errno=%d (%s)\n",
 				name, cpu, errno, strerror(errno));
-#if defined(_POSIX_PRIORITY_SCHEDULING)
-			sched_yield();
-#endif
+			(void)shim_sched_yield();
 		} else {
 			/* Now get and check */
 			CPU_ZERO(&mask);
@@ -87,4 +76,13 @@ int stress_affinity(
 
 	return EXIT_SUCCESS;
 }
+#else
+int stress_affinity(
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
+{
+	return stress_not_implemented(counter, instance, max_ops, name);
+}
 #endif
