@@ -22,23 +22,19 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
 
-#if defined(STRESS_AIO_LINUX)
+#if defined(__linux__) &&	\
+    defined(HAVE_LIB_AIO) &&	\
+    defined(__NR_io_setup) &&	\
+    defined(__NR_io_destroy) &&	\
+    defined(__NR_io_submit) &&	\
+    defined(__NR_io_getevents)
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <unistd.h>
-#include <errno.h>
-#include <signal.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <fcntl.h>
 #include <libaio.h>
 
+#endif
+
 #define BUFFER_SZ	(4096)
 
 static uint32_t opt_aio_linux_requests = DEFAULT_AIO_LINUX_REQUESTS;
@@ -55,6 +51,13 @@ void stress_set_aio_linux_requests(const char *optarg)
 	opt_aio_linux_requests = aio_linux_requests;
 }
 
+#if defined(__linux__) &&	\
+    defined(HAVE_LIB_AIO) &&	\
+    defined(__NR_io_setup) &&	\
+    defined(__NR_io_destroy) &&	\
+    defined(__NR_io_submit) &&	\
+    defined(__NR_io_getevents)
+
 /*
  *  aio_linux_fill_buffer()
  *	fill buffer with some known pattern
@@ -96,9 +99,34 @@ int stress_aiol(
 		pr_err(stderr, "%s: iol_requests out of range", name);
 		return EXIT_FAILURE;
 	}
-	if (io_setup(opt_aio_linux_requests, &ctx) < 0) {
-		pr_fail_err(name, "io_setup");
-		return EXIT_FAILURE;
+	ret = io_setup(opt_aio_linux_requests, &ctx);
+	if (ret < 0) {
+		/*
+		 *  The libaio interface returns -errno in the
+		 *  return value, so set errno accordingly
+		 */
+		errno = -ret;
+		if ((errno == EAGAIN) || (errno == EACCES)) {
+			pr_err(stderr, "%s: io_setup failed, ran out of "
+				"available events, consider increasing "
+				"/proc/sys/fs/aio-max-nr, errno=%d (%s)\n",
+				name, errno, strerror(errno));
+			return EXIT_NO_RESOURCE;
+		} else if (errno == ENOMEM) {
+			pr_err(stderr, "%s: io_setup failed, ran out of "
+				"memory, errno=%d (%s)\n",
+				name, errno, strerror(errno));
+			return EXIT_NO_RESOURCE;
+		} else if (errno == ENOSYS) {
+			pr_err(stderr, "%s: io_setup failed, no io_setup "
+				"system call with this kernel, "
+				"errno=%d (%s)\n",
+				name, errno, strerror(errno));
+			return EXIT_NO_RESOURCE;
+		} else {
+			pr_fail_err(name, "io_setup");
+			return EXIT_FAILURE;
+		}
 	}
 	ret = stress_temp_dir_mk(name, pid, instance);
 	if (ret < 0)
@@ -121,7 +149,6 @@ int stress_aiol(
 		struct io_event events[opt_aio_linux_requests];
 		uint8_t buffers[opt_aio_linux_requests][BUFFER_SZ];
 		uint32_t i;
-		int ret;
 		long n;
 
 		for (i = 0; i < opt_aio_linux_requests; i++)
@@ -138,6 +165,7 @@ int stress_aiol(
 		}
 		ret = io_submit(ctx, (long)opt_aio_linux_requests, cbs);
 		if (ret < 0) {
+			errno = -ret;
 			if (errno == EAGAIN)
 				continue;
 			pr_fail_err(name, "io_submit");
@@ -161,6 +189,7 @@ int stress_aiol(
 
 			ret = io_getevents(ctx, 1, n, events, timeout_ptr);
 			if (ret < 0) {
+				errno = -ret;
 				if ((errno == EINTR) && (opt_do_run))
 					continue;
 				pr_fail_err(name, "io_getevents");
@@ -179,5 +208,13 @@ finish:
 	(void)stress_temp_dir_rm(name, pid, instance);
 	return rc;
 }
-
+#else
+int stress_aiol(
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
+{
+	return stress_not_implemented(counter, instance, max_ops, name);
+}
 #endif
