@@ -22,30 +22,14 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
 
-#if defined(STRESS_AIO)
+#if defined(HAVE_LIB_RT) && defined(__linux__) && NEED_GLIBC(2,1,0)
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <unistd.h>
-#include <errno.h>
-#include <signal.h>
-#include <sys/types.h>
-#include <sys/stat.h>
 #include <aio.h>
-#include <fcntl.h>
-
 
 #define BUFFER_SZ	(16)
 
-static int opt_aio_requests = DEFAULT_AIO_REQUESTS;
-static bool set_aio_requests = false;
-static volatile bool do_accounting = true;
-
 /* per request async I/O data */
 typedef struct {
 	int		request;		/* Request slot */
@@ -55,6 +39,12 @@ typedef struct {
 	volatile uint64_t count;		/* Signal handled count */
 } io_req_t;
 
+static volatile bool do_accounting = true;
+#endif
+
+static int opt_aio_requests = DEFAULT_AIO_REQUESTS;
+static bool set_aio_requests = false;
+
 void stress_set_aio_requests(const char *optarg)
 {
 	uint64_t aio_requests;
@@ -66,6 +56,7 @@ void stress_set_aio_requests(const char *optarg)
 	opt_aio_requests = (int)aio_requests;
 }
 
+#if defined(HAVE_LIB_RT) && defined(__linux__) && NEED_GLIBC(2,1,0)
 /*
  *  aio_fill_buffer()
  *	fill buffer with some known pattern
@@ -181,7 +172,6 @@ int stress_aio(
 	uint64_t total = 0;
 	char filename[PATH_MAX];
 	const pid_t pid = getpid();
-	size_t io_req_sz;
 
 	if (!set_aio_requests) {
 		if (opt_flags & OPT_FLAGS_MAXIMIZE)
@@ -189,17 +179,17 @@ int stress_aio(
 		if (opt_flags & OPT_FLAGS_MINIMIZE)
 			opt_aio_requests = MIN_AIO_REQUESTS;
 	}
-	io_req_sz = (size_t)opt_aio_requests * sizeof(io_req_t);
 
-	if ((io_reqs = alloca(io_req_sz)) == NULL) {
+	if ((io_reqs = calloc(opt_aio_requests, sizeof(io_req_t))) == NULL) {
 		pr_err(stderr, "%s: cannot allocate io request structures\n", name);
 		return EXIT_NO_RESOURCE;
 	}
-	memset(io_reqs, 0, io_req_sz);
 
 	ret = stress_temp_dir_mk(name, pid, instance);
-	if (ret < 0)
+	if (ret < 0) {
+		free(io_reqs);
 		return exit_status(-ret);
+	}
 
 	(void)stress_temp_filename(filename, sizeof(filename),
 		name, pid, instance, mwc32());
@@ -232,7 +222,7 @@ int stress_aio(
 	}
 
 	do {
-		usleep(250000); /* wait until a signal occurs */
+		(void)shim_usleep(250000); /* wait until a signal occurs */
 
 		for (i = 0; opt_do_run && (i < opt_aio_requests); i++) {
 			if (io_reqs[i].status != EINPROGRESS)
@@ -272,11 +262,21 @@ cancel:
 	}
 	(void)close(fd);
 finish:
+	free(io_reqs);
+
 	pr_dbg(stderr, "%s: total of %" PRIu64 " async I/O signals "
 		"caught (instance %d)\n",
 		name, total, instance);
 	(void)stress_temp_dir_rm(name, pid, instance);
 	return rc;
 }
-
+#else
+int stress_aio(
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
+{
+	return stress_not_implemented(counter, instance, max_ops, name);
+}
 #endif
