@@ -22,38 +22,23 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
 
-#include <stdio.h>
-#include <stdint.h>
-#include <stdbool.h>
-#include <stdlib.h>
-#include <unistd.h>
-#include <signal.h>
-#include <dirent.h>
+#if defined(__linux__) && defined(HAVE_APPARMOR)
 
 #include <sys/select.h>
-#include <sys/types.h>
-#include <sys/time.h>
-#include <sys/wait.h>
-#if defined(STRESS_APPARMOR)
 #include <sys/apparmor.h>
-#endif
 
 #define APPARMOR_BUF_SZ	(4096)
 
 typedef int (*apparmor_func)(const char *name,
 			     const uint64_t max_ops, uint64_t *counter);
 
-#if defined(STRESS_APPARMOR)
 static volatile bool apparmor_run = true;
 static char *apparmor_path = NULL;
 
 extern char apparmor_data[];
 extern const size_t apparmor_data_len;
-#endif
 
 /*
  *  stress_apparmor_supported()
@@ -61,7 +46,6 @@ extern const size_t apparmor_data_len;
  */
 int stress_apparmor_supported(void)
 {
-#if defined(STRESS_APPARMOR)
 	int fd;
 	char path[PATH_MAX];
 
@@ -96,23 +80,19 @@ int stress_apparmor_supported(void)
 				"errno=%d (%s)\n", errno, strerror(errno));
 			break;
 		}
+		free(apparmor_path);
+		apparmor_path = NULL;
 		return -1;
 	}
 	(void)close(fd);
 
 	return 0;
-#else
-	pr_inf(stderr, "apparmor was not built in, missing apparmor "
-		"development headers\n");
-	return -1;
-#endif
 }
 
 
-#if defined(STRESS_APPARMOR)
 /*
- *  stress_lease_handler()
- *      lease signal handler
+ *  stress_apparmor_handler()
+ *      signal handler
  */
 static void MLOCKED stress_apparmor_handler(int dummy)
 {
@@ -231,13 +211,14 @@ again:
 		if (stress_sighandler(name, SIGALRM,
 				stress_apparmor_handler, NULL) < 0)
 			exit(EXIT_FAILURE);
-		setpgid(0, pgrp);
+		(void)setpgid(0, pgrp);
 		stress_parent_died_alarm();
 
 		ret = func(name, max_ops, counter);
+		free(apparmor_path);
 		exit(ret);
 	}
-	setpgid(pid, pgrp);
+	(void)setpgid(pid, pgrp);
 	return pid;
 }
 
@@ -673,6 +654,26 @@ int stress_apparmor(
 	}
 	munmap(counters, counters_sz);
 
+	free(apparmor_path);
+	apparmor_path = NULL;
+
 	return EXIT_SUCCESS;
 }
+#else
+int stress_apparmor_supported(void)
+{
+	pr_inf(stderr, "apparmor stressor will be skipped, "
+		"AppArmor is not available\n");
+	return -1;
+}
+
+int stress_apparmor(
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
+{
+	return stress_not_implemented(counter, instance, max_ops, name);
+
+}
 #endif
