@@ -22,17 +22,9 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
 
-#if defined(STRESS_BIND_MOUNT)
-
-#include <stdlib.h>
-#include <unistd.h>
-#include <sys/types.h>
-#include <sys/wait.h>
-#include <sys/mount.h>
+#if defined(__linux__) && defined(MS_BIND) && defined(MS_REC)
 
 #define CLONE_STACK_SIZE	(64*1024)
 
@@ -48,17 +40,17 @@ typedef struct {
  *	aggressively perform bind mounts, this can force out of memory
  *	situations
  */
-int stress_bind_mount_child(void *arg)
+static int stress_bind_mount_child(void *arg)
 {
 	context_t *context = (context_t *)arg;
+	uint64_t *counter = context->counter;
 
-	setpgid(0, pgrp);
+	(void)setpgid(0, pgrp);
 	stress_parent_died_alarm();
 
 	do {
 		if (mount("/", "/", "", MS_BIND | MS_REC, 0) < 0) {
-			pr_fail(stderr, "%s: mount failed: errno=%d (%s)\n",
-				context->name, errno, strerror(errno));
+			pr_fail_err(context->name, "mount");
 			break;
 		}
 		/*
@@ -66,8 +58,9 @@ int stress_bind_mount_child(void *arg)
 	`	 *  just to make the kernel work harder
 		 */
 		(void)umount("/");
+		(*counter)++;
 	} while (opt_do_run &&
-		 (!context->max_ops || *(context->counter) < context->max_ops));
+		 (!context->max_ops || *counter < context->max_ops));
 
 	return 0;
 }
@@ -85,7 +78,7 @@ int stress_bind_mount(
 	int pid = 0, status;
 	context_t context;
 	const ssize_t stack_offset =
-		stress_get_stack_direction(&pid) *
+		stress_get_stack_direction() *
 		(CLONE_STACK_SIZE - 64);
 	char stack[CLONE_STACK_SIZE];
 	char *stack_top = stack + stack_offset;
@@ -103,14 +96,13 @@ int stress_bind_mount(
 	if (pid < 0) {
 		int rc = exit_status(errno);
 
-		pr_fail(stderr, "%s: clone failed: errno=%d (%s)\n",
-			name, errno, strerror(errno));
+		pr_fail_err(name, "clone");
 		return rc;
 	}
 
 	do {
 		/* Twiddle thumbs */
-		sleep(1);
+		(void)shim_usleep(10000);
 	} while (opt_do_run && (!max_ops || *counter < max_ops));
 
 	(void)kill(pid, SIGKILL);
@@ -118,5 +110,14 @@ int stress_bind_mount(
 
 	return EXIT_SUCCESS;
 }
+#else
+int stress_bind_mount(
+        uint64_t *const counter,
+        const uint32_t instance,
+        const uint64_t max_ops,
+        const char *name)
+{
+	return stress_not_implemented(counter, instance, max_ops, name);
+}
 
 #endif
