@@ -22,20 +22,6 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <stdbool.h>
-#include <string.h>
-#include <errno.h>
-#include <unistd.h>
-#include <inttypes.h>
-#include <signal.h>
-#include <sys/types.h>
-#include <sys/wait.h>
-
 #include "stress-ng.h"
 
 /*
@@ -49,7 +35,7 @@ int stress_brk(
 	const char *name)
 {
 	pid_t pid;
-	uint32_t ooms= 0, segvs = 0, nomems = 0;
+	uint32_t ooms = 0, segvs = 0, nomems = 0;
 	const size_t page_size = stress_get_pagesize();
 
 again:
@@ -64,7 +50,7 @@ again:
 	} else if (pid > 0) {
 		int status, ret;
 
-		setpgid(pid, pgrp);
+		(void)setpgid(pid, pgrp);
 		/* Parent, wait for child */
 		ret = waitpid(pid, &status, 0);
 		if (ret < 0) {
@@ -103,7 +89,7 @@ again:
 		bool touch = !(opt_flags & OPT_FLAGS_BRK_NOTOUCH);
 		int i = 0;
 
-		setpgid(0, pgrp);
+		(void)setpgid(0, pgrp);
 		stress_parent_died_alarm();
 
 		/* Make sure this is killable by OOM killer */
@@ -111,8 +97,7 @@ again:
 
 		start_ptr = sbrk(0);
 		if (start_ptr == (void *) -1) {
-			pr_err(stderr, "%s: sbrk(0) failed: errno=%d (%s)\n",
-				name, errno, strerror(errno));
+			pr_fail_err(name, "sbrk(0)");
 			exit(EXIT_FAILURE);
 		}
 
