@@ -22,12 +22,6 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
-#include <stdio.h>
-#include <stdint.h>
-#include <stdlib.h>
-
 #include "stress-ng.h"
 
 static uint64_t opt_bsearch_size = DEFAULT_BSEARCH_SIZE;
@@ -51,8 +45,8 @@ void stress_set_bsearch_size(const char *optarg)
  */
 static int cmp(const void *p1, const void *p2)
 {
-	int32_t *i1 = (int32_t *)p1;
-	int32_t *i2 = (int32_t *)p2;
+	const int32_t *i1 = (const int32_t *)p1;
+	const int32_t *i2 = (const int32_t *)p2;
 
 	if (*i1 > *i2)
 		return 1;
