@@ -22,20 +22,11 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
 
-#if defined(STRESS_CAP)
+#if defined(__linux__) && defined(HAVE_SYS_CAP_H)
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <unistd.h>
-#include <ctype.h>
 #include <sys/capability.h>
-#include <sys/types.h>
-#include <dirent.h>
 
 static int stress_capgetset_pid(
 	const char *name,
@@ -118,7 +109,7 @@ int stress_cap(
 
 				if (!isdigit(d->d_name[0]))
 					continue;
-				if (sscanf(d->d_name, "%u", &p) != 1)
+				if (sscanf(d->d_name, "%d", &p) != 1)
 					continue;
 				stress_capgetset_pid(name, p, false,
 					counter, false);
@@ -131,5 +122,13 @@ int stress_cap(
 
 	return EXIT_SUCCESS;
 }
-
+#else
+int stress_cap(
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
+{
+	return stress_not_implemented(counter, instance, max_ops, name);
+}
 #endif
