@@ -22,54 +22,43 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <unistd.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <fcntl.h>
-#include <errno.h>
-
 #include "stress-ng.h"
 
 static const mode_t modes[] = {
-#ifdef S_ISUID
+#if defined(S_ISUID)
 	S_ISUID,
 #endif
-#ifdef S_ISGID
+#if defined(S_ISGID)
 	S_ISGID,
 #endif
-#ifdef S_ISVTX
+#if defined(S_ISVTX)
 	S_ISVTX,
 #endif
-#ifdef S_IRUSR
+#if defined(S_IRUSR)
 	S_IRUSR,
 #endif
-#ifdef S_IWUSR
+#if defined(S_IWUSR)
 	S_IWUSR,
 #endif
-#ifdef S_IXUSR
+#if defined(S_IXUSR)
 	S_IXUSR,
 #endif
-#ifdef S_IRGRP
+#if defined(S_IRGRP)
 	S_IRGRP,
 #endif
-#ifdef S_IWGRP
+#if defined(S_IWGRP)
 	S_IWGRP,
 #endif
-#ifdef S_IXGRP
+#if defined(S_IXGRP)
 	S_IXGRP,
 #endif
-#ifdef S_IROTH
+#if defined(S_IROTH)
 	S_IROTH,
 #endif
-#ifdef S_IWOTH
+#if defined(S_IWOTH)
 	S_IWOTH,
 #endif
-#ifdef S_IXOTH
+#if defined( S_IXOTH)
 	S_IXOTH,
 #endif
 	0
@@ -79,7 +68,7 @@ static const mode_t modes[] = {
  *  BSD systems can return EFTYPE which we can ignore
  *  as a "known" error on invalid chmod mode bits
  */
-#ifdef EFTYPE
+#if defined(EFTYPE)
 #define CHECK(x) if ((x) && (errno != EFTYPE)) return -1
 #else
 #define CHECK(x) if (x) return -1
@@ -168,7 +157,7 @@ int stress_chmod(
 			if ((fd = open(filename, O_RDWR, S_IRUSR | S_IWUSR)) > - 1)
 				break;
 
-			(void)usleep(100000);
+			(void)shim_usleep(100000);
 			if (++retries >= 100) {
 				pr_err(stderr, "%s: chmod: file %s took %d "
 					"retries to open and gave up "
@@ -193,8 +182,7 @@ int stress_chmod(
 		for (i = 0; modes[i]; i++) {
 			mask |= modes[i];
 			if (do_fchmod(fd, i, mask, all_mask) < 0) {
-				pr_fail(stderr, "%s: fchmod: errno=%d (%s)\n",
-					name, errno, strerror(errno));
+				pr_fail_err(name, "fchmod");
 			}
 			if (do_chmod(filename, i, mask, all_mask) < 0) {
 				if (errno == ENOENT || errno == ENOTDIR) {
@@ -205,8 +193,7 @@ int stress_chmod(
 					rc = EXIT_SUCCESS;
 					goto tidy;
 				}
-				pr_fail(stderr, "%s: chmod: errno=%d (%s)\n",
-					name, errno, strerror(errno));
+				pr_fail_err(name, "chmod");
 			}
 		}
 		(*counter)++;
