@@ -22,24 +22,10 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
 
-#if defined(STRESS_CLONE)
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <unistd.h>
-#include <sys/types.h>
-#include <sys/wait.h>
-
 #define CLONE_STACK_SIZE	(16*1024)
 
-static uint64_t opt_clone_max = DEFAULT_ZOMBIES;
-static bool set_clone_max = false;
-
 typedef struct clone {
 	pid_t	pid;
 	struct clone *next;
@@ -53,6 +39,11 @@ typedef struct {
 	uint64_t length;	/* Length of list */
 } clone_list_t;
 
+static uint64_t opt_clone_max = DEFAULT_ZOMBIES;
+static bool set_clone_max = false;
+
+#if defined(__linux__) && NEED_GLIBC(2,14,0)
+
 static clone_list_t clones;
 
 /*
@@ -118,7 +109,21 @@ static const int unshare_flags[] = {
 	CLONE_SYSVSEM,
 #endif
 };
+#endif
 
+/*
+ *  stress_set_clone_max()
+ *	set maximum number of clones allowed
+ */
+void stress_set_clone_max(const char *optarg)
+{
+	set_clone_max = true;
+	opt_clone_max = get_uint64_byte(optarg);
+	check_range("clone-max", opt_clone_max,
+		MIN_ZOMBIES, MAX_ZOMBIES);
+}
+
+#if defined(__linux__) && NEED_GLIBC(2,14,0)
 
 /*
  *  stress_clone_new()
@@ -155,7 +160,7 @@ static clone_t *stress_clone_new(void)
  *	reap a clone and remove a clone from head of list, put it onto
  *	the free clone list
  */
-void stress_clone_head_remove(void)
+static void stress_clone_head_remove(void)
 {
 	if (clones.head) {
 		int status;
@@ -182,7 +187,7 @@ void stress_clone_head_remove(void)
  *  stress_clone_free()
  *	free the clones off the clone free lists
  */
-void stress_clone_free(void)
+static void stress_clone_free(void)
 {
 	while (clones.head) {
 		clone_t *next = clones.head->next;
@@ -198,18 +203,6 @@ void stress_clone_free(void)
 	}
 }
 
-/*
- *  stress_set_clone_max()
- *	set maximum number of clones allowed
- */
-void stress_set_clone_max(const char *optarg)
-{
-	set_clone_max = true;
-	opt_clone_max = get_uint64_byte(optarg);
-	check_range("clone-max", opt_clone_max,
-		MIN_ZOMBIES, MAX_ZOMBIES);
-}
-
 /*
  *  clone_func()
  *	clone thread just returns immediately
@@ -239,7 +232,7 @@ int stress_clone(
 {
 	uint64_t max_clones = 0;
 	const ssize_t stack_offset =
-		stress_get_stack_direction(&max_clones) *
+		stress_get_stack_direction() *
 		(CLONE_STACK_SIZE - 64);
 
 	(void)instance;
@@ -292,5 +285,13 @@ int stress_clone(
 
 	return EXIT_SUCCESS;
 }
-
+#else
+int stress_clone(
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
+{
+	return stress_not_implemented(counter, instance, max_ops, name);
+}
 #endif
