@@ -22,48 +22,11 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
 
-#if defined(STRESS_COPY_FILE)
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <unistd.h>
-#include <fcntl.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-
 static uint64_t opt_copy_file_bytes = DEFAULT_COPY_FILE_BYTES;
 static bool set_copy_file_bytes;
 
-static int sys_copy_file_range(
-	int fd_in,
-	loff_t *off_in,
-	int fd_out,
-	loff_t *off_out,
-	size_t len,
-	unsigned int flags)
-{
-#if defined(__NR_copy_file_range)
-	return syscall(__NR_copy_file_range,
-		fd_in, off_in, fd_out, off_out, len, flags);
-#else
-	(void)fd_in;
-	(void)off_in;
-	(void)fd_out;
-	(void)off_out;
-	(void)len;
-	(void)flags;
-
-	errno = ENOSYS;
-	return -1;
-#endif
-}
-
-
 void stress_set_copy_file_bytes(const char *optarg)
 {
 	set_copy_file_bytes = true;
@@ -72,6 +35,8 @@ void stress_set_copy_file_bytes(const char *optarg)
 		MIN_COPY_FILE_BYTES, MAX_COPY_FILE_BYTES);
 }
 
+#if defined(__linux__) && (__NR_copy_file_range)
+
 /*
  *  stress_copy_file
  *	stress reading chunks of file using copy_file_range()
@@ -132,7 +97,8 @@ int stress_copy_file(
 		off_in = mwc64() % (opt_copy_file_bytes - DEFAULT_COPY_FILE_SIZE);
 		off_out = mwc64() % (opt_copy_file_bytes - DEFAULT_COPY_FILE_SIZE);
 
-		ret =  sys_copy_file_range(fd_in, &off_in, fd_out, &off_out, DEFAULT_COPY_FILE_SIZE, 0);
+		ret =  shim_copy_file_range(fd_in, &off_in, fd_out,
+			&off_out, DEFAULT_COPY_FILE_SIZE, 0);
 		if (ret < 0) {
 			if ((errno == EAGAIN) ||
 			    (errno == EINTR) ||
@@ -155,5 +121,13 @@ tidy_dir:
 
 	return rc;
 }
-
+#else
+int stress_copy_file(
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
+{
+	return stress_not_implemented(counter, instance, max_ops, name);
+}
 #endif
