@@ -22,20 +22,13 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <stddef.h>
+#include "stress-ng.h"
 #include <math.h>
 #include <complex.h>
-#include <sys/time.h>
-#include <unistd.h>
-#include "stress-ng.h"
 
 #define GAMMA 	(0.57721566490153286060651209008240243104215933593992L)
-#define OMEGA	(0.5671432904097838729999686622L)
-#define PSI	(3.35988566624317755317201130291892717968890513373L)
+#define OMEGA	(0.56714329040978387299996866221035554975381578718651L)
+#define PSI	(3.359885666243177553172011302918927179688905133732L)
 
 /* Some awful *BSD math lib workarounds */
 #if defined(__NetBSD__)
@@ -129,7 +122,7 @@ static void HOT stress_cpu_sqrt(const char *name)
 /*
  *  We need to stop gcc optimising out the loop additions.. sigh
  */
-#if __GNUC__ && !defined(__clang__)
+#if __GNUC__ && NEED_GNUC(4, 4, 0) && !defined(__clang__)
 static void stress_cpu_loop(const char *)  __attribute__((optimize("-O0")));
 #endif
 
@@ -189,7 +182,7 @@ static void HOT OPTIMIZE3 stress_cpu_bitops(const char *name)
 
 	for (i = 0; i < 16384; i++) {
 		{
-			uint32_t r, v, s = (sizeof(v) * 8) - 1;
+			register uint32_t r, v, s = (sizeof(v) * 8) - 1;
 
 			/* Reverse bits */
 			r = v = i;
@@ -202,7 +195,8 @@ static void HOT OPTIMIZE3 stress_cpu_bitops(const char *name)
 		}
 		{
 			/* parity check */
-			uint32_t v = i;
+			register uint32_t v = i;
+
 			v ^= v >> 16;
 			v ^= v >> 8;
 			v ^= v >> 4;
@@ -211,14 +205,16 @@ static void HOT OPTIMIZE3 stress_cpu_bitops(const char *name)
 		}
 		{
 			/* Brian Kernighan count bits */
-			uint32_t j, v = i;
+			register uint32_t j, v = i;
+
 			for (j = 0; v; j++)
 				v &= v - 1;
 			i_sum += j;
 		}
 		{
 			/* round up to nearest highest power of 2 */
-			uint32_t v = i - 1;
+			register uint32_t v = i - 1;
+
 			v |= v >> 1;
 			v |= v >> 2;
 			v |= v >> 4;
@@ -544,7 +540,7 @@ static void stress_cpu_hash_generic(
  */
 static uint32_t HOT OPTIMIZE3 jenkin(const uint8_t *data, const size_t len)
 {
-	uint8_t i;
+	register uint8_t i;
 	register uint32_t h = 0;
 
 	for (i = 0; i < len; i++) {
@@ -586,10 +582,11 @@ static void stress_cpu_jenkin(const char *name)
  */
 static uint32_t HOT OPTIMIZE3 pjw(const char *str)
 {
-	uint32_t h = 0;
+	register uint32_t h = 0;
 
 	while (*str) {
-		uint32_t g;
+		register uint32_t g;
+
 		h = (h << 4) + (*str);
 		if (0 != (g = h & 0xf0000000)) {
 			h = h ^ (g >> 24);
@@ -615,8 +612,8 @@ static void stress_cpu_pjw(const char *name)
  */
 static uint32_t HOT OPTIMIZE3 djb2a(const char *str)
 {
-	uint32_t hash = 5381;
-	int c;
+	register uint32_t hash = 5381;
+	register int c;
 
 	while ((c = *str++)) {
 		/* (hash * 33) ^ c */
@@ -640,9 +637,9 @@ static void stress_cpu_djb2a(const char *name)
  */
 static uint32_t HOT OPTIMIZE3 fnv1a(const char *str)
 {
-	uint32_t hash = 5381;
+	register uint32_t hash = 5381;
 	const uint32_t fnv_prime = 16777619; /* 2^24 + 2^9 + 0x93 */
-	int c;
+	register int c;
 
 	while ((c = *str++)) {
 		hash ^= c;
@@ -667,8 +664,8 @@ static void HOT stress_cpu_fnv1a(const char *name)
  */
 static uint32_t OPTIMIZE3 sdbm(const char *str)
 {
-	uint32_t hash = 0;
-	int c;
+	register uint32_t hash = 0;
+	register int c;
 
 	while ((c = *str++))
 		hash = c + (hash << 6) + (hash << 16) - hash;
@@ -1062,7 +1059,7 @@ static void HOT OPTIMIZE3 stress_cpu_rgb(const char *name)
 
 	/* Do a 1000 colours starting from the rgb seed */
 	for (i = 0; i < 1000; i++) {
-		float y,u,v;
+		float y, u, v;
 
 		/* RGB to CCIR 601 YUV */
 		y = (0.299f * r) + (0.587f * g) + (0.114f * b);
@@ -1252,7 +1249,7 @@ static void HOT stress_cpu_explog(const char *name)
 /*
  *  Undocumented gcc-ism, force -O0 optimisation
  */
-#if __GNUC__ && !defined(__clang__)
+#if __GNUC__ && NEED_GNUC(4, 4, 0) && !defined(__clang__)
 static void stress_cpu_jmp(const char *name)  __attribute__((optimize("-O0")));
 #endif
 
@@ -1314,7 +1311,7 @@ static uint16_t HOT OPTIMIZE3 ccitt_crc16(const uint8_t *data, size_t n)
 	 *  we are assuming the top bit is always set.
 	 */
 	const uint16_t polynomial = 0x8408;
-	uint16_t crc = ~0;
+	register uint16_t crc = ~0;
 
 	if (!n)
 		return 0;
@@ -1483,7 +1480,7 @@ static void HOT OPTIMIZE3 stress_cpu_sieve(const char *name)
  */
 static inline HOT OPTIMIZE3 bool is_prime(uint32_t n)
 {
-	uint32_t i, max;
+	register uint32_t i, max;
 
 	if (n <= 3)
 		return n >= 2;
@@ -1520,8 +1517,8 @@ static void stress_cpu_prime(const char *name)
  */
 static void HOT OPTIMIZE3 stress_cpu_gray(const char *name)
 {
-	uint32_t i;
-	uint64_t sum = 0;
+	register uint32_t i;
+	register uint64_t sum = 0;
 
 	for (i = 0; i < 0x10000; i++) {
 		register uint32_t gray_code;
@@ -1816,7 +1813,7 @@ static void stress_cpu_parity(const char *name)
 	size_t i;
 
 	for (i = 0; i < 1000; i++, val++) {
-		uint32_t v, parity, p;
+		register uint32_t v, parity, p;
 		uint8_t *ptr;
 
 		/*
@@ -2068,10 +2065,10 @@ static void stress_cpu_queens(const char *name)
 
         for (all = 1, n = 1; n < 13; n++) {
 		uint32_t solutions = queens_try(0, 0, 0, all);
-		if ((opt_flags & OPT_FLAGS_VERIFY) && 
+		if ((opt_flags & OPT_FLAGS_VERIFY) &&
 		    (solutions != queens_solutions[n]))
 			pr_fail(stderr, "%s: queens solution error detected "
-				"on board size %" PRIu32 "\n", 
+				"on board size %" PRIu32 "\n",
 				name, n);
                 all = (all + all) + 1;
         }
@@ -2266,6 +2263,9 @@ int stress_cpu(
 			do {
 				(void)func(name);
 				t2 = time_now();
+				if (!opt_do_run)
+					break;
+				(*counter)++;
 			} while (t2 < slice_end);
 		} else {
 			/* > 0, time slice in milliseconds */
@@ -2274,6 +2274,9 @@ int stress_cpu(
 			do {
 				(void)func(name);
 				t2 = time_now();
+				if (!opt_do_run)
+					break;
+				(*counter)++;
 			} while (t2 < slice_end);
 		}
 		t = t2 - t1;
