@@ -22,17 +22,12 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-#define _XOPEN_SOURCE	600
-
 #include "stress-ng.h"
 
-#if defined(STRESS_CRYPT)
+#undef _XOPEN_SOURCE
+#define _XOPEN_SOURCE	600
 
-#include <stdio.h>
-#include <stdint.h>
-#include <stdlib.h>
-#include <unistd.h>
+#if defined(HAVE_LIB_CRYPT)
 #if defined (__linux__)
 #include <crypt.h>
 #endif
@@ -109,5 +104,13 @@ int stress_crypt(
 
 	return EXIT_SUCCESS;
 }
-
+#else
+int stress_crypt(
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
+{
+	return stress_not_implemented(counter, instance, max_ops, name);
+}
 #endif
