@@ -22,19 +22,6 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <inttypes.h>
-#include <limits.h>
-#include <unistd.h>
-
-#include <fcntl.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-
 #include "stress-ng.h"
 
 typedef enum {
@@ -115,7 +102,10 @@ static void stress_dentry_unlink(
 	case ORDER_REVERSE:
 		for (i = 0; i < n; i++) {
 			char path[PATH_MAX];
-			uint64_t j = (n - 1) - i, gray_code = (j >> 1) ^ j;
+			uint64_t gray_code;
+
+			j = (n - 1) - i;
+			gray_code = (j >> 1) ^ j;
 
 			stress_temp_filename(path, sizeof(path),
 				name, pid, instance, gray_code);
