@@ -22,16 +22,6 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <unistd.h>
-#include <fcntl.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-
 #include "stress-ng.h"
 
 /*
@@ -45,7 +35,7 @@ int stress_dup(
 	const char *name)
 {
 	int fds[STRESS_FD_MAX];
-	const size_t max_fd = stress_get_file_limit();
+	size_t max_fd = stress_get_file_limit();
 	size_t i;
 #if defined(__linux__)
 	bool do_dup3 = true;
@@ -53,6 +43,9 @@ int stress_dup(
 
 	(void)instance;
 
+	if (max_fd > SIZEOF_ARRAY(fds))
+		max_fd =  SIZEOF_ARRAY(fds);
+
 	fds[0] = open("/dev/zero", O_RDONLY);
 	if (fds[0] < 0) {
 		pr_fail_dbg(name, "open on /dev/zero");
