@@ -22,46 +22,22 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
 
-#if defined(STRESS_EPOLL)
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <string.h>
-#include <stdbool.h>
-#include <signal.h>
-#include <time.h>
-#include <unistd.h>
-#include <errno.h>
-#include <sys/types.h>
-#include <sys/socket.h>
-#include <sys/epoll.h>
-#include <sys/wait.h>
-#include <netinet/in.h>
-#include <arpa/inet.h>
-#ifdef AF_INET6
-#include <netinet/in.h>
-#endif
-#ifdef AF_UNIX
-#include <sys/un.h>
-#endif
-#include <fcntl.h>
-#include <netdb.h>
-#if defined(_POSIX_PRIORITY_SCHEDULING)
-#include <sched.h>
-#endif
-
 #define MAX_EPOLL_EVENTS 	(1024)
 #define MAX_SERVERS		(4)
 
-static int opt_epoll_domain = AF_UNIX;
-static int opt_epoll_port = DEFAULT_EPOLL_PORT;
-static int max_servers = 1;
-static timer_t epoll_timerid;
+#if defined(HAVE_LIB_RT) && defined(__linux__) && NEED_GLIBC(2,3,2)
+#include <sys/epoll.h>
+#include <netinet/in.h>
+#include <arpa/inet.h>
+#if defined(AF_INET6)
+#include <netinet/in.h>
+#endif
+#if defined(AF_UNIX)
+#include <sys/un.h>
+#endif
+#include <netdb.h>
 
 typedef void (epoll_func_t)(
 	const int child,
@@ -71,6 +47,14 @@ typedef void (epoll_func_t)(
 	const char *name,
 	const pid_t ppid);
 
+static timer_t epoll_timerid;
+
+#endif
+
+static int max_servers = 1;
+static int opt_epoll_domain = AF_UNIX;
+static int opt_epoll_port = DEFAULT_EPOLL_PORT;
+
 /*
  *  stress_set_epoll_port()
  *	set the default port base
@@ -107,6 +91,8 @@ int stress_set_epoll_domain(const char *name)
 	return ret;
 }
 
+#if defined(HAVE_LIB_RT) && defined(__linux__) && NEED_GLIBC(2,3,2)
+
 /*
  * epoll_timer_handler()
  *	catch timer signal and cancel if no more runs flagged
@@ -163,12 +149,12 @@ again:
 		return -1;
 	}
 	if (pid == 0) {
-		setpgid(0, pgrp);
+		(void)setpgid(0, pgrp);
 		stress_parent_died_alarm();
 		func(child, counter, instance, max_ops, name, ppid);
 		exit(EXIT_SUCCESS);
 	}
-	setpgid(pid, pgrp);
+	(void)setpgid(pid, pgrp);
 	return pid;
 }
 
@@ -364,7 +350,7 @@ retry:
 				break;
 			}
 			(void)close(fd);
-			usleep(100000);	/* Twiddle fingers for a moment */
+			(void)shim_usleep(100000);	/* Twiddle fingers for a moment */
 
 			retries++;
 			if (retries > 1000) {
@@ -383,13 +369,11 @@ retry:
 			break;
 		}
 		(void)close(fd);
-#if defined(_POSIX_PRIORITY_SCHEDULING)
-		sched_yield();
-#endif
+		(void)shim_sched_yield();
 		(*counter)++;
 	} while (opt_do_run && (!max_ops || *counter < max_ops));
 
-#ifdef AF_UNIX
+#if defined(AF_UNIX)
 	if (addr && (opt_epoll_domain == AF_UNIX)) {
 		struct sockaddr_un *addr_un = (struct sockaddr_un *)addr;
 		(void)unlink(addr_un->sun_path);
@@ -524,7 +508,7 @@ die_close:
 	if (sfd != -1)
 		(void)close(sfd);
 die:
-#ifdef AF_UNIX
+#if defined(AF_UNIX)
 	if (addr && (opt_epoll_domain == AF_UNIX)) {
 		struct sockaddr_un *addr_un = (struct sockaddr_un *)addr;
 		(void)unlink(addr_un->sun_path);
@@ -598,5 +582,13 @@ reap:
 
 	return rc;
 }
-
+#else
+int stress_epoll(
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
+{
+	return stress_not_implemented(counter, instance, max_ops, name);
+}
 #endif
