@@ -22,21 +22,10 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
 
-#if defined(STRESS_EVENTFD)
+#if defined(__linux__) && NEED_GLIBC(2,8,0)
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <string.h>
-#include <unistd.h>
-#include <errno.h>
-#include <signal.h>
-#include <sys/types.h>
-#include <sys/wait.h>
 #include <sys/eventfd.h>
 
 /*
@@ -78,7 +67,7 @@ again:
 		(void)close(fd2);
 		return EXIT_FAILURE;
 	} else if (pid == 0) {
-		setpgid(0, pgrp);
+		(void)setpgid(0, pgrp);
 		stress_parent_died_alarm();
 
 		while (opt_do_run) {
@@ -180,5 +169,13 @@ exit_parent:
 	}
 	return EXIT_SUCCESS;
 }
-
+#else
+int stress_eventfd(
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
+{
+	return stress_not_implemented(counter, instance, max_ops, name);
+}
 #endif
