@@ -22,19 +22,8 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <unistd.h>
-#include <sys/types.h>
-#include <sys/wait.h>
-
 #include "stress-ng.h"
 
-#if defined(STRESS_EXEC)
-
 static uint64_t opt_exec_max = DEFAULT_EXECS;
 static bool set_exec_max = false;
 
@@ -50,6 +39,8 @@ void stress_set_exec_max(const char *optarg)
 		MIN_EXECS, MAX_EXECS);
 }
 
+#if defined(__linux__)
+
 /*
  *  stress_exec()
  *	stress by forking and exec'ing
@@ -101,7 +92,7 @@ int stress_exec(
 			if (pids[i] == 0) {
 				int ret, fd_out, fd_in;
 
-				setpgid(0, pgrp);
+				(void)setpgid(0, pgrp);
 				stress_parent_died_alarm();
 
 				if ((fd_out = open("/dev/null", O_WRONLY)) < 0) {
@@ -127,7 +118,7 @@ int stress_exec(
 				_exit(ret == 0 ? EXIT_SUCCESS : EXIT_FAILURE);
 			}
 			if (pids[i] > -1)
-				setpgid(pids[i], pgrp);
+				(void)setpgid(pids[i], pgrp);
 			if (!opt_do_run)
 				break;
 		}
@@ -158,5 +149,13 @@ int stress_exec(
 
 	return EXIT_SUCCESS;
 }
-
+#else
+int stress_exec(
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
+{
+	return stress_not_implemented(counter, instance, max_ops, name);
+}
 #endif
