@@ -22,22 +22,8 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
 
-#if defined(STRESS_FALLOCATE)
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <unistd.h>
-#include <inttypes.h>
-#include <fcntl.h>
-
-#include <sys/types.h>
-#include <sys/stat.h>
-
 static off_t opt_fallocate_bytes = DEFAULT_FALLOCATE_BYTES;
 static bool set_fallocate_bytes = false;
 
@@ -49,7 +35,8 @@ void stress_set_fallocate_bytes(const char *optarg)
 		MIN_FALLOCATE_BYTES, MAX_FALLOCATE_BYTES);
 }
 
-#if defined(__linux__)
+#if (_XOPEN_SOURCE >= 600 || _POSIX_C_SOURCE >= 200112L) && NEED_GLIBC(2,10,0)
+
 static const int modes[] = {
 	0,
 #if defined(FALLOC_FL_KEEP_SIZE)
@@ -68,7 +55,6 @@ static const int modes[] = {
 	FALLOC_FL_INSERT_RANGE,
 #endif
 };
-#endif
 
 /*
  *  stress_fallocate
@@ -108,11 +94,11 @@ int stress_fallocate(
 	(void)unlink(filename);
 
 	do {
-		(void)posix_fallocate(fd, (off_t)0, opt_fallocate_bytes);
+		ret = posix_fallocate(fd, (off_t)0, opt_fallocate_bytes);
 		if (!opt_do_run)
 			break;
 		(void)fsync(fd);
-		if (opt_flags & OPT_FLAGS_VERIFY) {
+		if ((ret == 0) && (opt_flags & OPT_FLAGS_VERIFY)) {
 			struct stat buf;
 
 			if (fstat(fd, &buf) < 0)
@@ -150,13 +136,12 @@ int stress_fallocate(
 			ftrunc_errs++;
 		(void)fsync(fd);
 
-#if defined(__linux__)
 		if (SIZEOF_ARRAY(modes) > 1) {
 			/*
 			 *  non-portable Linux fallocate()
 			 */
 			int i;
-			(void)fallocate(fd, 0, (off_t)0, opt_fallocate_bytes);
+			(void)shim_fallocate(fd, 0, (off_t)0, opt_fallocate_bytes);
 			if (!opt_do_run)
 				break;
 			(void)fsync(fd);
@@ -165,7 +150,7 @@ int stress_fallocate(
 				off_t offset = (mwc64() % opt_fallocate_bytes) & ~0xfff;
 				int j = (mwc32() >> 8) % SIZEOF_ARRAY(modes);
 
-				(void)fallocate(fd, modes[j], offset, 64 * KB);
+				(void)shim_fallocate(fd, modes[j], offset, 64 * KB);
 				if (!opt_do_run)
 					break;
 				(void)fsync(fd);
@@ -174,7 +159,6 @@ int stress_fallocate(
 				ftrunc_errs++;
 			(void)fsync(fd);
 		}
-#endif
 		(*counter)++;
 	} while (opt_do_run && (!max_ops || *counter < max_ops));
 	if (ftrunc_errs)
@@ -185,4 +169,13 @@ int stress_fallocate(
 
 	return EXIT_SUCCESS;
 }
+#else
+int stress_fallocate(
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
+{
+	return stress_not_implemented(counter, instance, max_ops, name);
+}
 #endif
