@@ -22,20 +22,6 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <errno.h>
-#include <setjmp.h>
-#include <sys/mman.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <fcntl.h>
-#include <sys/time.h>
-#include <sys/resource.h>
-
 #include "stress-ng.h"
 
 static sigjmp_buf jmp_env;
@@ -65,7 +51,8 @@ int stress_fault(
 {
 	struct rusage usage;
 	char filename[PATH_MAX];
-	int ret, i;
+	int ret;
+	NOCLOBBER int i;
 	const pid_t pid = getpid();
 
 	ret = stress_temp_dir_mk(name, pid, instance);
@@ -97,8 +84,7 @@ int stress_fault(
 		if (fd < 0) {
 			if ((errno == ENOSPC) || (errno == ENOMEM))
 				continue;	/* Try again */
-			pr_err(stderr, "%s: open failed: errno=%d (%s)\n",
-				name, errno, strerror(errno));
+			pr_fail_err(name, "open");
 			break;
 		}
 #if _XOPEN_SOURCE >= 600 || _POSIX_C_SOURCE >= 200112L
@@ -108,9 +94,7 @@ int stress_fault(
 				continue;	/* Try again */
 			}
 			(void)close(fd);
-			pr_err(stderr, "%s: posix_fallocate failed: "
-				"errno=%d (%s)\n",
-				name, errno, strerror(errno));
+			pr_fail_err(name, "posix_fallocate");
 			break;
 		}
 #else
@@ -127,9 +111,7 @@ redo:
 					continue;
 				}
 				(void)close(fd);
-				pr_err(stderr, "%s: write failed: "
-					"errno=%d (%s)\n",
-					name, errno, strerror(errno));
+				pr_fail_err(name, "write");
 				break;
 			}
 		}
@@ -154,6 +136,7 @@ redo:
 			MAP_SHARED, fd, 0);
 		(void)close(fd);
 		fd = -1;
+		(void)fd;
 
 		if (ptr == MAP_FAILED) {
 			pr_err(stderr, "%s: mmap failed: errno=%d (%s)\n",
