@@ -22,21 +22,6 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <unistd.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <fcntl.h>
-#include <errno.h>
-#include <signal.h>
-#if defined(__linux__)
-#include <sys/syscall.h>
-#endif
-
 #include "stress-ng.h"
 
 /*
@@ -52,14 +37,6 @@ static void check_return(const int ret, const char *name, const char *cmd)
 	}
 }
 
-#if defined(__linux__)
-static inline int sys_gettid(void)
-{
-        return syscall(SYS_gettid);
-}
-#endif
-
-
 /*
  *  do_fcntl()
  */
@@ -168,7 +145,7 @@ static int do_fcntl(const int fd, const char *name)
 
 #if defined(__linux__)
 		owner.type = F_OWNER_TID;
-		owner.pid = sys_gettid();
+		owner.pid = shim_gettid();
 		ret = fcntl(fd, F_SETOWN_EX, &owner);
 		check_return(ret, name, "F_SETOWN_EX, F_OWNER_TID");
 #endif
@@ -245,9 +222,7 @@ static int do_fcntl(const int fd, const char *name)
 		const off_t start = mwc16() & 0x7fff;
 
 		if (ftruncate(fd, 65536) < 0) {
-			pr_fail(stderr, "%s: ftruncate failed, "
-				"errno=%d (%s)\n",
-				name, errno, strerror(errno));
+			pr_fail_err(name, "ftruncate");
 			goto lock_abort;
 		}
 
@@ -262,9 +237,7 @@ static int do_fcntl(const int fd, const char *name)
 
 #if 0
 		if (f.l_type != F_UNLCK) {
-			pr_fail(stderr, "%s: fcntl F_GETLK failed, "
-				"expecting l_type to return F_UNLCK\n",
-				name);
+			pr_fail_err(name, "fcntl F_GETLK");
 			goto lock_abort;
 		}
 #endif
@@ -325,9 +298,7 @@ lock_abort:	{ /* Nowt */ }
 		const off_t start = mwc16() & 0x7fff;
 
 		if (ftruncate(fd, 65536) < 0) {
-			pr_fail(stderr, "%s: ftruncate failed, "
-				"errno=%d (%s)\n",
-				name, errno, strerror(errno));
+			pr_fail_err(name, "ftruncate");
 			goto ofd_lock_abort;
 		}
 
@@ -342,9 +313,7 @@ lock_abort:	{ /* Nowt */ }
 
 #if 0
 		if (f.l_type != F_UNLCK) {
-			pr_fail(stderr, "%s: fcntl F_OFD_GETLK failed, "
-				"expecting l_type to return F_UNLCK\n",
-				name);
+			pr_fail_err(name, "fcntl F_OFD_GETLK");
 			goto ofd_lock_abort;
 		}
 #endif
@@ -437,7 +406,7 @@ int stress_fcntl(
 		if ((fd = creat(filename, S_IRUSR | S_IWUSR)) < 0) {
 			if ((errno == EPERM) || (errno == EACCES) ||
 			    (errno == ENOMEM) || (errno == ENOSPC)) {
-				(void)usleep(100000);
+				(void)shim_usleep(100000);
 				continue;
 			}
 			pr_fail_err(name, "open");
