@@ -22,24 +22,11 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
-
-#if defined(STRESS_FIEMAP)
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <unistd.h>
-#include <signal.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <sys/wait.h>
-#include <fcntl.h>
-
+#if defined(__linux__) && defined(FS_IOC_FIEMAP)
 #include <linux/fs.h>
 #include <linux/fiemap.h>
+#endif
 
 #define MAX_FIEMAP_PROCS	(4)		/* Number of FIEMAP stressors */
 
@@ -54,13 +41,15 @@ void stress_set_fiemap_size(const char *optarg)
 		MIN_FIEMAP_SIZE, MAX_FIEMAP_SIZE);
 }
 
+#if defined(__linux__) && defined(FS_IOC_FIEMAP)
+
 /*
  *  stress_fiemap_writer()
  *	write data in random places and punch holes
  *	in data in random places to try and maximize
  *	extents in the file
  */
-int stress_fiemap_writer(
+static int stress_fiemap_writer(
 	const char *name,
 	const int fd,
 	uint64_t *counters,
@@ -79,7 +68,7 @@ int stress_fiemap_writer(
 
 	do {
 		uint64_t offset;
-		size_t i;	
+		size_t i;
 		counter = 0;
 
 		offset = (mwc64() % len) & ~0x1fff;
@@ -97,7 +86,7 @@ int stress_fiemap_writer(
 			continue;
 
 		offset = mwc64() % len;
-		if (fallocate(fd, FALLOC_FL_PUNCH_HOLE |
+		if (shim_fallocate(fd, FALLOC_FL_PUNCH_HOLE |
 				  FALLOC_FL_KEEP_SIZE, offset, 8192) < 0) {
 			if (errno == EOPNOTSUPP)
 				punch_hole = false;
@@ -117,7 +106,7 @@ tidy:
  *  stress_fiemap_ioctl()
  *	exercise the FIEMAP ioctl
  */
-void stress_fiemap_ioctl(
+static void stress_fiemap_ioctl(
 	const char *name,
 	int fd,
 	uint64_t *const counter,
@@ -185,12 +174,12 @@ static inline pid_t stress_fiemap_spawn(
         if (pid < 0)
                 return -1;
         if (pid == 0) {
-                setpgid(0, pgrp);
+                (void)setpgid(0, pgrp);
                 stress_parent_died_alarm();
 		stress_fiemap_ioctl(name, fd, counter, max_ops);
                 exit(EXIT_SUCCESS);
         }
-        setpgid(pid, pgrp);
+        (void)setpgid(pid, pgrp);
         return pid;
 }
 
@@ -271,5 +260,13 @@ clean:
 	(void)stress_temp_dir_rm(name, mypid, instance);
 	return rc;
 }
-
+#else
+int stress_fiemap(
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
+{
+	return stress_not_implemented(counter, instance, max_ops, name);
+}
 #endif
