@@ -22,22 +22,8 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <string.h>
-#include <unistd.h>
-#include <signal.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <sys/wait.h>
-#include <sys/select.h>
-#include <errno.h>
-#include <fcntl.h>
-
 #include "stress-ng.h"
+#include <sys/select.h>
 
 static uint64_t opt_fifo_readers = DEFAULT_FIFO_READERS;
 static bool set_fifo_readers = false;
@@ -66,12 +52,12 @@ static pid_t fifo_spawn(
 		return -1;
 	}
 	if (pid == 0) {
-		setpgid(0, pgrp);
+		(void)setpgid(0, pgrp);
 		stress_parent_died_alarm();
 		func(name, fifoname);
 		exit(EXIT_SUCCESS);
 	}
-	setpgid(pid, pgrp);
+	(void)setpgid(pid, pgrp);
 	return pid;
 }
 
@@ -79,7 +65,7 @@ static pid_t fifo_spawn(
  *  stress_fifo_readers()
  *	read fifo
  */
-void stress_fifo_reader(const char *name, const char *fifoname)
+static void stress_fifo_reader(const char *name, const char *fifoname)
 {
 	int fd;
 	uint64_t val, lastval = 0;
@@ -154,7 +140,7 @@ int stress_fifo(
 	int fd;
 	char fifoname[PATH_MAX];
 	uint64_t i, val = 0ULL;
-	int ret = EXIT_FAILURE;
+	int rc = EXIT_FAILURE;
 	const pid_t pid = getpid();
 
 	if (!set_fifo_readers) {
@@ -164,16 +150,16 @@ int stress_fifo(
 			opt_fifo_readers = MIN_FIFO_READERS;
 	}
 
-	ret = stress_temp_dir_mk(name, pid, instance);
-	if (ret < 0)
-		return exit_status(-ret);
+	rc = stress_temp_dir_mk(name, pid, instance);
+	if (rc < 0)
+		return exit_status(-rc);
 
 	(void)stress_temp_filename(fifoname, sizeof(fifoname),
                 name, pid, instance, mwc32());
 	(void)umask(0077);
 
 	if (mkfifo(fifoname, S_IRUSR | S_IWUSR) < 0) {
-		ret = exit_status(errno);
+		rc = exit_status(errno);
 		pr_err(stderr, "%s: mkfifo failed: errno=%d (%s)\n",
 			name, errno, strerror(errno));
 		goto tidy;
@@ -185,16 +171,21 @@ int stress_fifo(
 		if (pids[i] < 0)
 			goto reap;
 		if (!opt_do_run) {
-			ret = EXIT_SUCCESS;
+			rc = EXIT_SUCCESS;
 			goto reap;
 		}
 	}
 
 	fd = open(fifoname, O_WRONLY);
 	if (fd < 0) {
-		ret = exit_status(fd);
-		pr_err(stderr, "%s: fifo write open failed: errno=%d (%s)\n",
-			name, errno, strerror(errno));
+		if (errno == EINTR) {
+			rc = 0;
+		} else {
+			rc = exit_status(fd);
+			pr_err(stderr, "%s: fifo write open failed: "
+				"errno=%d (%s)\n",
+				name, errno, strerror(errno));
+		}
 		goto reap;
 	}
 
@@ -216,7 +207,7 @@ int stress_fifo(
 	} while (opt_do_run && (!max_ops || *counter < max_ops));
 
 	(void)close(fd);
-	ret = EXIT_SUCCESS;
+	rc = EXIT_SUCCESS;
 reap:
 	for (i = 0; i < opt_fifo_readers; i++) {
 		if (pids[i] > 0) {
@@ -230,5 +221,5 @@ tidy:
 	(void)unlink(fifoname);
 	(void)stress_temp_dir_rm(name, pid, instance);
 
-	return ret;
+	return rc;
 }
