@@ -22,23 +22,10 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <unistd.h>
-#include <fcntl.h>
-#include <sys/file.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <errno.h>
-#if defined(_POSIX_PRIORITY_SCHEDULING) || defined(__linux__)
-#include <sched.h>
-#endif
-
 #include "stress-ng.h"
 
+#if !defined(__sun__) && defined(LOCK_EX) && defined(LOCK_UN)
+
 /*
  *  stress_flock
  *	stress file locking
@@ -91,9 +78,7 @@ retry:
 
 		if (flock(fd, LOCK_EX) < 0)
 			continue;
-#if defined(_POSIX_PRIORITY_SCHEDULING) && !defined(__minix__)
-		sched_yield();
-#endif
+		(void)shim_sched_yield();
 		(void)flock(fd, LOCK_UN);
 		(*counter)++;
 	} while (opt_do_run && (!max_ops || *counter < max_ops));
@@ -104,3 +89,15 @@ retry:
 
 	return EXIT_SUCCESS;
 }
+
+#else
+
+int stress_flock(
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
+{
+	return stress_not_implemented(counter, instance, max_ops, name);
+}
+#endif
