@@ -22,23 +22,12 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <unistd.h>
-#include <sys/types.h>
-#include <sys/wait.h>
-
 #include "stress-ng.h"
 
 static uint64_t opt_fork_max = DEFAULT_FORKS;
 static bool set_fork_max = false;
-#if defined(STRESS_VFORK)
 static uint64_t opt_vfork_max = DEFAULT_VFORKS;
 static bool set_vfork_max = false;
-#endif
 
 /*
  *  stress_set_fork_max()
@@ -52,7 +41,6 @@ void stress_set_fork_max(const char *optarg)
 		MIN_FORKS, MAX_FORKS);
 }
 
-#if defined(STRESS_VFORK)
 /*
  *  stress_set_vfork_max()
  *	set maximum number of vforks allowed
@@ -64,14 +52,13 @@ void stress_set_vfork_max(const char *optarg)
 	check_range("vfork-max", opt_vfork_max,
 		MIN_VFORKS, MAX_VFORKS);
 }
-#endif
 
 /*
  *  stress_fork_fn()
  *	stress by forking and exiting using
  *	fork function fork_fn (fork or vfork)
  */
-int stress_fork_fn(
+static int stress_fork_fn(
 	uint64_t *const counter,
 	const uint32_t instance,
 	const uint64_t max_ops,
@@ -96,7 +83,7 @@ int stress_fork_fn(
 				_exit(0);
 			}
 			if (pid > -1)
-				setpgid(pids[i], pgrp);
+				(void)setpgid(pids[i], pgrp);
 			pids[i] = pid;
 			if (!opt_do_run)
 				break;
@@ -142,7 +129,6 @@ int stress_fork(
 }
 
 
-#if defined(STRESS_VFORK)
 /*
  *  stress_vfork()
  *	stress by vforking and exiting
@@ -163,4 +149,3 @@ int stress_vfork(
 	return stress_fork_fn(counter, instance, max_ops,
 		name, vfork, opt_vfork_max);
 }
-#endif
