@@ -22,23 +22,10 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <stdbool.h>
-#include <string.h>
-#include <unistd.h>
-#include <dirent.h>
-#include <errno.h>
-#include <fcntl.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-
 #include "stress-ng.h"
 
 static const char *opt_fstat_dir = "/dev";
+static sigjmp_buf jmpbuf;
 
 void stress_set_fstat_dir(const char *optarg)
 {
@@ -49,6 +36,18 @@ static const char *blacklist[] = {
 	"/dev/watchdog"
 };
 
+/*
+ *  handle_fstat_sigalrm()
+ *      catch SIGALRM
+ */
+static void MLOCKED handle_fstat_sigalrm(int dummy)
+{
+	(void)dummy;
+	opt_do_run = false;
+
+	siglongjmp(jmpbuf, 1);
+}
+
 /*
  *  do_not_stat()
  *	Check if file should not be stat'd
@@ -82,13 +81,22 @@ int stress_fstat(
 	} dir_info_t;
 
 	DIR *dp;
-	dir_info_t *dir_info = NULL, *di;
+	dir_info_t *di;
+	static dir_info_t *dir_info;
 	struct dirent *d;
-	int ret = EXIT_FAILURE;
+	NOCLOBBER int ret = EXIT_FAILURE;
 	bool stat_some;
+	const uid_t euid = geteuid();
 
 	(void)instance;
 
+	if (stress_sighandler(name, SIGALRM, handle_fstat_sigalrm, NULL) < 0)
+		return EXIT_FAILURE;
+	if (sigsetjmp(jmpbuf, 0) != 0) {
+		ret = EXIT_SUCCESS;
+		goto free_cache;
+	}
+
 	if ((dp = opendir(opt_fstat_dir)) == NULL) {
 		pr_err(stderr, "%s: opendir on %s failed: errno=%d: (%s)\n",
 			name, opt_fstat_dir, errno, strerror(errno));
@@ -99,6 +107,12 @@ int stress_fstat(
 	while ((d = readdir(dp)) != NULL) {
 		char path[PATH_MAX];
 
+		if (!opt_do_run) {
+			ret = EXIT_SUCCESS;
+			(void)closedir(dp);
+			goto free_cache;
+		}
+
 		snprintf(path, sizeof(path), "%s/%s", opt_fstat_dir, d->d_name);
 		if (do_not_stat(path))
 			continue;
@@ -123,10 +137,13 @@ int stress_fstat(
 	do {
 		stat_some = false;
 
-		for (di = dir_info; di; di = di->next) {
+		for (di = dir_info; opt_do_run && di; di = di->next) {
 			int fd;
 			struct stat buf;
 
+			if (!opt_do_run || (max_ops && *counter >= max_ops))
+				goto aborted;
+
 			if (di->ignore)
 				continue;
 
@@ -143,25 +160,33 @@ int stress_fstat(
 			if (di->noaccess)
 				continue;
 
-			fd = open(di->path, O_RDONLY | O_NONBLOCK);
-			if (fd < 0) {
-				di->noaccess = true;
-				continue;
+			/*
+			 *  Opening /dev files such as /dev/urandom
+			 *  may block when running as root, so
+			 *  avoid this.
+			 */
+			if (!euid) {
+				fd = open(di->path, O_RDONLY | O_NONBLOCK);
+				if (fd < 0) {
+					di->noaccess = true;
+					continue;
+				}
+
+				if ((fstat(fd, &buf) < 0) &&
+				    (errno != ENOMEM)) {
+					di->ignore = true;
+					(void)close(fd);
+					continue;
+				}
+
+				(void)close(fd);
 			}
-
-			if ((fstat(fd, &buf) < 0) &&
-			    (errno != ENOMEM))
-				di->ignore = true;
-			(void)close(fd);
-
 			stat_some = true;
-
 			(*counter)++;
-			if (!opt_do_run || (max_ops && *counter >= max_ops))
-				break;
 		}
 	} while (stat_some && opt_do_run && (!max_ops || *counter < max_ops));
 
+aborted:
 	ret = EXIT_SUCCESS;
 free_cache:
 	/* Free cache */
