@@ -22,26 +22,11 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
 
-#if defined(STRESS_FUTEX)
+#if defined(__linux__) && defined(__NR_futex)
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <string.h>
-#include <time.h>
-#include <inttypes.h>
-#include <unistd.h>
-#include <errno.h>
-#include <signal.h>
 #include <linux/futex.h>
-#include <sys/time.h>
-#include <sys/types.h>
-#include <sys/wait.h>
-#include <sys/syscall.h>
 
 #define THRESHOLD	(100000)
 
@@ -67,7 +52,7 @@ static inline int futex_wait(
 }
 
 /*
- *  stress_fuxex()
+ *  stress_futex()
  *	stress system by futex calls. The intention is not to
  * 	efficiently use futex, but to stress the futex system call
  *	by rapidly calling it on wait and wakes
@@ -93,7 +78,7 @@ again:
 	if (pid > 0) {
 		int status;
 
-		setpgid(pid, pgrp);
+		(void)setpgid(pid, pgrp);
 
 		do {
 			int ret;
@@ -107,9 +92,7 @@ again:
 			ret = futex_wake(futex, 1);
 			if (opt_flags & OPT_FLAGS_VERIFY) {
 				if (ret < 0)
-					pr_fail(stderr, "%s: futex wake "
-						"failed: errno=%d (%s)\n",
-						name, errno, strerror(errno));
+					pr_fail_err(name, "futex wake");
 			}
 		} while (opt_do_run && (!max_ops || *counter < max_ops));
 
@@ -122,7 +105,7 @@ again:
 	} else {
 		uint64_t threshold = THRESHOLD;
 
-		setpgid(0, pgrp);
+		(void)setpgid(0, pgrp);
 		stress_parent_died_alarm();
 
 		do {
@@ -143,14 +126,12 @@ again:
 					/*
 					 * Backoff for a short while and						 * start again
 					 */
-					usleep(250000);
+					(void)shim_usleep(250000);
 					threshold += THRESHOLD;
 				}
 			} else {
 				if ((ret < 0) && (opt_flags & OPT_FLAGS_VERIFY)) {
-					pr_fail(stderr, "%s: futex wait "
-						"failed: errno=%d (%s)\n",
-						name, errno, strerror(errno));
+					pr_fail_err(name, "futex wait");
 				}
 				(*counter)++;
 			}
@@ -159,5 +140,13 @@ again:
 
 	return EXIT_SUCCESS;
 }
-
+#else
+int stress_futex(
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
+{
+	return stress_not_implemented(counter, instance, max_ops, name);
+}
 #endif
