@@ -22,25 +22,15 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
+#include "stress-ng.h"
+
 #define _DEFAULT_SOURCE 1
 #define _BSD_SOURCE 1
 
-#include <stdlib.h>
-#include <string.h>
-#include <unistd.h>
-#include <errno.h>
-#include <sys/types.h>
-#include <sys/time.h>
-#include <sys/resource.h>
 #if defined(__linux__)
-#include <sys/syscall.h>
 #include <sys/utsname.h>
 #include <sys/timex.h>
 #endif
-#include <time.h>
-
-#include "stress-ng.h"
 
 #define check_do_run()		\
 	if (!opt_do_run)	\
@@ -49,91 +39,74 @@
 #define GIDS_MAX 	(1024)
 
 static const int rusages[] = {
-#ifdef RUSAGE_SELF
+#if defined(RUSAGE_SELF)
 	RUSAGE_SELF,
 #endif
-#ifdef RUSAGE_CHILDREN
+#if defined(RUSAGE_CHILDREN)
 	RUSAGE_CHILDREN,
 #endif
-#ifdef RUSAGE_THREAD
+#if defined(RUSAGE_THREAD)
 	RUSAGE_THREAD
 #endif
 };
 
 static const int rlimits[] = {
-#ifdef RLIMIT_AS
+#if defined(RLIMIT_AS)
 	RLIMIT_AS,
 #endif
-#ifdef RLIMIT_CORE
+#if defined(RLIMIT_CORE)
 	RLIMIT_CORE,
 #endif
-#ifdef RLIMIT_CPU
+#if defined(RLIMIT_CPU)
 	RLIMIT_CPU,
 #endif
-#ifdef RLIMIT_DATA
+#if defined(RLIMIT_DATA)
 	RLIMIT_DATA,
 #endif
-#ifdef RLIMIT_FSIZE
+#if defined(RLIMIT_FSIZE)
 	RLIMIT_FSIZE,
 #endif
-#ifdef RLIMIT_MEMLOCK
+#if defined(RLIMIT_MEMLOCK)
 	RLIMIT_MEMLOCK,
 #endif
-#ifdef RLIMIT_MSGQUEUE
+#if defined(RLIMIT_MSGQUEUE)
 	RLIMIT_MSGQUEUE,
 #endif
-#ifdef RLIMIT_NICE
+#if defined(RLIMIT_NICE)
 	RLIMIT_NICE,
 #endif
-#ifdef RLIMIT_NOFILE
+#if defined(RLIMIT_NOFILE)
 	RLIMIT_NOFILE,
 #endif
-#ifdef RLIMIT_RSS
+#if defined(RLIMIT_RSS)
 	RLIMIT_RSS,
 #endif
-#ifdef RLIMIT_RTPRIO
+#if defined(RLIMIT_RTPRIO)
 	RLIMIT_RTPRIO,
 #endif
-#ifdef RLIMIT_RTTIME
+#if defined(RLIMIT_RTTIME)
 	RLIMIT_RTTIME,
 #endif
-#ifdef RLIMIT_SIGPENDING
+#if defined(RLIMIT_SIGPENDING)
 	RLIMIT_SIGPENDING,
 #endif
-#ifdef RLIMIT_STACK
+#if defined(RLIMIT_STACK)
 	RLIMIT_STACK
 #endif
 };
 
 static const int priorities[] = {
-#ifdef PRIO_PROCESS
+#if defined(PRIO_PROCESS)
 	PRIO_PROCESS,
 #endif
-#ifdef PRIO_PGRP
+#if defined(PRIO_PGRP)
 	PRIO_PGRP,
 #endif
-#ifdef PRIO_USER
+#if defined(PRIO_USER)
 	PRIO_USER
 #endif
 };
 
-#if defined(__linux__) && defined(__NR_gettid)
-static inline int sys_gettid(void)
-{
-        return syscall(SYS_gettid);
-}
-#endif
-
-#if defined(__linux__) && defined(__NR_getcpu)
-static long sys_getcpu(
-        unsigned *cpu,
-        unsigned *node,
-        void *tcache)
-{
-	return syscall(__NR_getcpu, cpu, node, tcache);
-}
-#endif
-
 /*
  *  stress on get*() calls
  *	stress system by rapid get*() system calls
@@ -152,6 +125,7 @@ int stress_get(
 		char path[PATH_MAX];
 		char *ptr;
 		gid_t gids[GIDS_MAX];
+		unsigned cpu, node;
 #if defined(__linux__)
 		gid_t rgid, egid, sgid;
 		uid_t ruid, euid, suid;
@@ -163,7 +137,7 @@ int stress_get(
 #endif
 		int ret;
 		size_t i;
-		struct timeval tv;
+		struct timeval delta, tv;
 		time_t t;
 
 		check_do_run();
@@ -173,8 +147,7 @@ int stress_get(
 
 		ptr = getcwd(path, sizeof path);
 		if (verify && !ptr)
-			pr_fail(stderr, "%s: getcwd failed, errno=%d (%s)\n",
-				name, errno, strerror(errno));
+			pr_fail_err(name, "getcwd");
 		check_do_run();
 
 		(void)getgid();
@@ -191,8 +164,7 @@ int stress_get(
 
 		ret = getgroups(GIDS_MAX, gids);
 		if (verify && (ret < 0))
-			pr_fail(stderr, "%s: getgroups failed, errno=%d (%s)\n",
-				name, errno, strerror(errno));
+			pr_fail_err(name, "getgroups");
 		check_do_run();
 
 #if !defined(__minix__)
@@ -209,22 +181,19 @@ int stress_get(
 			errno = 0;
 			ret = getpriority(priorities[i], 0);
 			if (verify && errno && (ret < 0))
-				pr_fail(stderr, "%s: getpriority failed, errno=%d (%s)\n",
-					name, errno, strerror(errno));
+				pr_fail_err(name, "getpriority");
 			check_do_run();
 		}
 
 #if defined(__linux__)
 		ret = getresgid(&rgid, &egid, &sgid);
 		if (verify && (ret < 0))
-			pr_fail(stderr, "%s: getresgid failed, errno=%d (%s)\n",
-				name, errno, strerror(errno));
+			pr_fail_err(name, "getresgid");
 		check_do_run();
 
 		ret = getresuid(&ruid, &euid, &suid);
 		if (verify && (ret < 0))
-			pr_fail(stderr, "%s: getresuid failed, errno=%d (%s)\n",
-				name, errno, strerror(errno));
+			pr_fail_err(name, "getresuid");
 		check_do_run();
 #endif
 
@@ -256,7 +225,6 @@ int stress_get(
 					pr_fail(stderr, "%s: prlimit(%d, %zu, ..) failed, errno=%d (%s)\n",
 						name, mypid, i, errno, strerror(errno));
 			}
-		
 			check_do_run();
 		}
 #endif
@@ -274,54 +242,42 @@ int stress_get(
 #if _XOPEN_SOURCE >= 500 || _XOPEN_SOURCE && _XOPEN_SOURCE_EXTENDED
 		ret = getsid(mypid);
 		if (verify && (ret < 0))
-			pr_fail(stderr, "%s: getsid failed, errno=%d (%s)\n",
-				name, errno, strerror(errno));
+			pr_fail_err(name, "getsid");
 		check_do_run();
 #endif
 
-#if defined(__linux__) && defined(__NR_gettid)
-		(void)sys_gettid();
+		(void)shim_gettid();
 		check_do_run();
-#endif
 
-#if defined(__linux__) && defined(__NR_getcpu)
-		{
-			unsigned cpu, node;
-
-			(void)sys_getcpu(&cpu, &node, NULL);
-			(void)sys_getcpu(NULL, &node, NULL);
-			(void)sys_getcpu(&cpu, NULL, NULL);
-			(void)sys_getcpu(NULL, NULL, NULL);
-		}
-#endif
+		(void)shim_getcpu(&cpu, &node, NULL);
+		(void)shim_getcpu(NULL, &node, NULL);
+		(void)shim_getcpu(&cpu, NULL, NULL);
+		(void)shim_getcpu(NULL, NULL, NULL);
+		check_do_run();
 
 		t = time(NULL);
 		if (verify && (t == (time_t)-1))
-			pr_fail(stderr, "%s: time failed, errno=%d (%s)\n",
-				name, errno, strerror(errno));
+			pr_fail_err(name, "time");
 
 		ret = gettimeofday(&tv, NULL);
 		if (verify && (ret < 0))
-			pr_fail(stderr, "%s: gettimeval failed, errno=%d (%s)\n",
-				name, errno, strerror(errno));
+			pr_fail_err(name, "gettimeval");
 #if defined(__linux__)
 		ret = uname(&utsbuf);
 		if (verify && (ret < 0))
-			pr_fail(stderr, "%s: uname failed, errno=%d (%s)\n",
-				name, errno, strerror(errno));
+			pr_fail_err(name, "uname");
 #endif
 
 #if defined(__linux__)
 		timexbuf.modes = 0;
 		ret = adjtimex(&timexbuf);
 		if (verify && (ret < 0))
-			pr_fail(stderr, "%s: adjtimex failed, errno=%d (%s)\n",
-				name, errno, strerror(errno));
+			pr_fail_err(name, "adjtimex");
 #endif
-		ret = adjtime(NULL, &tv);
+		memset(&delta, 0, sizeof(delta));
+		ret = adjtime(&delta, &tv);
 		if (verify && (ret < 0))
-			pr_fail(stderr, "%s: adjtime failed, errno=%d (%s)\n",
-				name, errno, strerror(errno));
+			pr_fail_err(name, "adjtime");
 
 		(*counter)++;
 	} while (opt_do_run && (!max_ops || *counter < max_ops));
