@@ -22,28 +22,10 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
 
-#if defined(STRESS_GETRANDOM)
-
-#include <stdio.h>
-#include <stdint.h>
-#include <stdlib.h>
-
-/*
- *  getrandom() syscall
- */
-static inline int sys_getrandom(void *buff, size_t buflen, unsigned int flags)
-{
-#if defined(__NR_getrandom)
-	return syscall(__NR_getrandom, buff, buflen, flags);
-#else
-	errno = ENOSYS;
-	return -1;
-#endif
-}
+#if defined(__OpenBSD__) || \
+    (defined(__linux__) && defined(__NR_getrandom))
 
 /*
  *  stress_getrandom
@@ -58,10 +40,14 @@ int stress_getrandom(
 	(void)instance;
 
 	do {
+#if defined(__OpenBSD__)
+		char buffer[256];
+#else
 		char buffer[8192];
+#endif
 		ssize_t ret;
 
-		ret = sys_getrandom(buffer, sizeof(buffer), 0);
+		ret = shim_getrandom(buffer, sizeof(buffer), 0);
 		if (ret < 0) {
 			if (errno == EAGAIN)
 				continue;
@@ -73,4 +59,13 @@ int stress_getrandom(
 
 	return EXIT_SUCCESS;
 }
+#else
+int stress_getrandom(
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
+{
+	return stress_not_implemented(counter, instance, max_ops, name);
+}
 #endif
