@@ -22,20 +22,10 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
 
-#if defined(STRESS_HANDLE)
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <unistd.h>
-#include <fcntl.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <sys/resource.h>
+#if defined(__linux__) && defined(__NR_name_to_handle_at) && \
+    defined(__NR_open_by_handle_at) && NEED_GLIBC(2,14,0)
 
 #define MAX_MOUNT_IDS	(1024)
 #define FILENAME	"/dev/zero"
@@ -51,7 +41,7 @@ typedef struct {
 
 static mount_info_t mount_info[MAX_MOUNT_IDS];
 
-void free_mount_info(const int mounts)
+static void free_mount_info(const int mounts)
 {
 	int i;
 
@@ -59,7 +49,7 @@ void free_mount_info(const int mounts)
 		free(mount_info[i].mount_path);
 }
 
-int get_mount_info(const char *name)
+static int get_mount_info(const char *name)
 {
 	FILE *fp;
 	int mounts = 0;
@@ -75,12 +65,15 @@ int get_mount_info(const char *name)
 		size_t line_len = 0;
 
 		ssize_t nread = getline(&line, &line_len, fp);
-		if (nread == -1)
+		if (nread == -1) {
+			free(line);
 			break;
+		}
 
 		nread = sscanf(line, "%12d %*d %*s %*s %" XSTR(PATH_MAX) "s",
 			&mount_info[mounts].mount_id,
 			mount_path);
+		free(line);
 		if (nread != 2)
 			continue;
 
@@ -128,8 +121,7 @@ int stress_handle(
 		fhp->handle_bytes = 0;
 		if ((name_to_handle_at(AT_FDCWD, FILENAME, fhp, &mount_id, 0) != -1) &&
 		    (errno != EOVERFLOW)) {
-			pr_fail(stderr, "%s: name_to_handle_at: failed to get file handle size: errno=%d (%s)\n",
-				name, errno, strerror(errno));
+			pr_fail_err(name, "name_to_handle_at: failed to get file handle size");
 			free(fhp);
 			break;
 		}
@@ -140,8 +132,7 @@ int stress_handle(
 		}
 		fhp = tmp;
 		if (name_to_handle_at(AT_FDCWD, FILENAME, fhp, &mount_id, 0) < 0) {
-			pr_fail(stderr, "%s: name_to_handle_at: failed to get file handle: errno=%d (%s)\n",
-				name, errno, strerror(errno));
+			pr_fail_err(name, "name_to_handle_at: failed to get file handle");
 			free(fhp);
 			break;
 		}
@@ -178,10 +169,20 @@ int stress_handle(
 		}
 		(void)close(mount_fd);
 		free(fhp);
+		(*counter)++;
 	} while (opt_do_run && (!max_ops || *counter < max_ops));
 
 	free_mount_info(mounts);
 
 	return EXIT_SUCCESS;
 }
+#else
+int stress_handle(
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
+{
+	return stress_not_implemented(counter, instance, max_ops, name);
+}
 #endif
