@@ -22,19 +22,8 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <unistd.h>
-#include <errno.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <sys/uio.h>
-#include <fcntl.h>
-
 #include "stress-ng.h"
+#include <sys/uio.h>
 
 #define BUF_ALIGNMENT		(4096)
 #define HDD_IO_VEC_MAX		(16)		/* Must be power of 2 */
@@ -142,7 +131,7 @@ static const hdd_opts_t hdd_opts[] = {
 	{ "fdatasync",	HDD_OPT_FDATASYNC, 0, 0, 0 },
 #endif
 	{ "iovec",	HDD_OPT_IOVEC, 0, 0, 0 },
-#if defined(_GNU_SOURCE) && NEED_GLIBC(2,14,0) && defined(__linux__)
+#if NEED_GLIBC(2,14,0) && defined(__linux__)
 	{ "syncfs",	HDD_OPT_SYNCFS, 0, 0, 0 },
 #endif
 	{ "utimes",	HDD_OPT_UTIMES, 0, 0, 0 },
@@ -202,7 +191,7 @@ static ssize_t stress_hdd_write(const int fd, uint8_t *buf, size_t count)
 	if (opt_hdd_flags & HDD_OPT_FDATASYNC)
 		(void)fdatasync(fd);
 #endif
-#if defined(_GNU_SOURCE) && NEED_GLIBC(2,14,0) && defined(__linux__)
+#if NEED_GLIBC(2,14,0) && defined(__linux__)
 	if (opt_hdd_flags & HDD_OPT_SYNCFS)
 		(void)syncfs(fd);
 #endif
@@ -332,9 +321,11 @@ int stress_hdd(
 	const char *name)
 {
 	uint8_t *buf = NULL;
+	uint8_t *alloc_buf;
 	uint64_t i, min_size, remainder;
 	const pid_t pid = getpid();
-	int ret, rc = EXIT_FAILURE;
+	int rc = EXIT_FAILURE;
+	ssize_t ret;
 	char filename[PATH_MAX];
 	int flags = O_CREAT | O_RDWR | O_TRUNC | opt_hdd_oflags;
 	int fadvise_flags = opt_hdd_flags & HDD_OPT_FADV_MASK;
@@ -397,13 +388,25 @@ int stress_hdd(
 	if ((opt_hdd_flags & HDD_OPT_RD_MASK) == 0)
 		opt_hdd_flags |= HDD_OPT_RD_SEQ;
 
-	ret = posix_memalign((void **)&buf, BUF_ALIGNMENT, (size_t)opt_hdd_write_size);
-	if (ret || !buf) {
+#if defined(__sun__)
+	/* Work around lack of posix_memalign */
+	alloc_buf = malloc((size_t)opt_hdd_write_size + BUF_ALIGNMENT);
+	if (!alloc_buf) {
+		pr_err(stderr, "%s: cannot allocate buffer\n", name);
+		(void)stress_temp_dir_rm(name, pid, instance);
+		return rc;
+	}
+	buf = (uint8_t *)align_address(alloc_buf, BUF_ALIGNMENT);
+#else
+	ret = posix_memalign((void **)&alloc_buf, BUF_ALIGNMENT, (size_t)opt_hdd_write_size);
+	if (ret || !alloc_buf) {
 		rc = exit_status(errno);
 		pr_err(stderr, "%s: cannot allocate buffer\n", name);
 		(void)stress_temp_dir_rm(name, pid, instance);
 		return rc;
 	}
+	buf = alloc_buf;
+#endif
 
 	stress_strnrnd((char *)buf, opt_hdd_write_size);
 
@@ -456,7 +459,6 @@ int stress_hdd(
 				off_t offset = (i == 0) ?
 					opt_hdd_bytes :
 					(mwc64() % opt_hdd_bytes) & ~511;
-				ssize_t ret;
 
 				if (lseek(fd, offset, SEEK_SET) < 0) {
 					pr_fail_err(name, "lseek");
@@ -489,7 +491,6 @@ rnd_wr_retry:
 		/* Sequential Write */
 		if (opt_hdd_flags & HDD_OPT_WR_SEQ) {
 			for (i = 0; i < opt_hdd_bytes; i += opt_hdd_write_size) {
-				ssize_t ret;
 				size_t j;
 seq_wr_retry:
 				if (!opt_do_run || (max_ops && *counter >= max_ops))
@@ -534,7 +535,6 @@ seq_wr_retry:
 				goto finish;
 			}
 			for (i = 0; i < hdd_read_size; i += opt_hdd_write_size) {
-				ssize_t ret;
 seq_rd_retry:
 				if (!opt_do_run || (max_ops && *counter >= max_ops))
 					break;
@@ -585,7 +585,6 @@ seq_rd_retry:
 			uint64_t baddata = 0;
 
 			for (i = 0; i < hdd_read_size; i += opt_hdd_write_size) {
-				ssize_t ret;
 				off_t offset = (mwc64() % (opt_hdd_bytes - opt_hdd_write_size)) & ~511;
 
 				if (lseek(fd, offset, SEEK_SET) < 0) {
@@ -640,7 +639,7 @@ rnd_rd_retry:
 
 	rc = EXIT_SUCCESS;
 finish:
-	free(buf);
+	free(alloc_buf);
 	(void)stress_temp_dir_rm(name, pid, instance);
 	return rc;
 }
