@@ -24,29 +24,13 @@
  * stress-inotify.c is derived from the eCryptfs inotify tests
  * that I authored in 2012.
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
 
-#if defined(STRESS_INOTIFY)
+#if defined(__linux__) && NEED_GLIBC(2,9,0)
 
-#include <stdio.h>
-#include <stdint.h>
-#include <stdlib.h>
-#include <stdbool.h>
-#include <inttypes.h>
-#include <string.h>
-#include <unistd.h>
-#include <limits.h>
-#include <errno.h>
-#include <fcntl.h>
-#include <dirent.h>
-#include <sys/types.h>
-#include <sys/stat.h>
 #include <sys/select.h>
 #include <sys/inotify.h>
 
-
 #define DIR_FLAGS	(S_IRWXU | S_IRWXG)
 #define FILE_FLAGS	(S_IRUSR | S_IWUSR)
 
@@ -90,7 +74,7 @@ retry:
 			 * iteration, in which case we've run out of resources
 			 * temporarily, so sleep a short while and retry.
 			 */
-			usleep(10000);
+			(void)shim_usleep(10000);
 			goto retry;
 		}
 		/* Nope, give up */
@@ -101,8 +85,7 @@ retry:
 
 	if ((wd = inotify_add_watch(fd, watchname, flags)) < 0) {
 		(void)close(fd);
-		pr_fail(stderr, "%s: inotify_add_watch failed: errno=%d (%s)",
-			name, errno, strerror(errno));
+		pr_fail_err(name, "inotify_add_watch");
 		return;
 	}
 
@@ -113,7 +96,7 @@ retry:
 		ssize_t len, i = 0;
 		struct timeval tv;
 		fd_set rfds;
-		int err;
+		int err, nbytes;
 
 		/* We give inotify TIME_OUT seconds to report back */
 		tv.tv_sec = TIME_OUT;
@@ -138,14 +121,28 @@ retry:
 redo:
 		if (!opt_do_run)
 			break;
+		/*
+		 *  Exercise FIOREAD to get inotify code coverage up
+		 */
+		if (ioctl(fd, FIONREAD, &nbytes) < 0) {
+			if (opt_flags & OPT_FLAGS_VERIFY) {
+				pr_fail(stderr, "%s: data is ready, but ioctl FIONREAD failed\n", name);
+				break;
+			}
+		}
+		if (nbytes <= 0) {
+			pr_fail(stderr, "%s: data is ready, but ioctl FIONREAD "
+				"reported %d bytes available\n", name, nbytes);
+			break;
+		}
+
 		len = read(fd, buffer, sizeof(buffer));
 
 		if ((len <= 0) || (len > (ssize_t)sizeof(buffer))) {
 			if ((errno == EAGAIN) || (errno == EINTR))
 				goto redo;
 			if (errno) {
-				pr_fail(stderr, "%s: error reading inotify: errno=%d (%s)\n",
-					name, errno, strerror(errno));
+				pr_fail_err(name, "error reading inotify");
 				break;
 			}
 		}
@@ -305,7 +302,7 @@ static int inotify_attrib_helper(
 	return 0;
 }
 
-void inotify_attrib_file(const char *name, const char *path)
+static void inotify_attrib_file(const char *name, const char *path)
 {
 	char filepath[PATH_MAX];
 
@@ -506,7 +503,7 @@ static int inotify_move_self_helper(
 	const char *oldpath,
 	const void *private)
 {
-	char *newpath = (char*)private;
+	const char *newpath = (const char *)private;
 
 	if (rename(oldpath, newpath) < 0) {
 		pr_err(stderr, "%s: cannot rename %s to %s: errno=%d (%s)\n",
@@ -536,7 +533,7 @@ static int inotify_moved_to_helper(
 	const char *newpath,
 	const void *private)
 {
-	char *oldpath = (char*)private;
+	const char *oldpath = (const char *)private;
 
 	if (rename(oldpath, newpath) < 0) {
 		pr_err(stderr, "%s: cannot rename %s to %s: errno=%d (%s)\n",
@@ -570,7 +567,7 @@ static int inotify_moved_from_helper(
 	const char *oldpath,
 	const void *private)
 {
-	char *newpath = (char*)private;
+	const char *newpath = (const char *)private;
 
 	if (rename(oldpath, newpath) < 0) {
 		pr_err(stderr, "%s: cannot rename %s to %s: errno=%d (%s)\n",
@@ -607,7 +604,7 @@ static int inotify_close_write_helper(
 	(void)name;
 	(void)path;
 
-	(void)close(*(int *)fdptr);
+	(void)close(*(const int *)fdptr);
 	return 0;
 }
 
@@ -640,7 +637,7 @@ static int inotify_close_nowrite_helper(
 	(void)name;
 	(void)path;
 
-	(void)close(*(int *)fdptr);
+	(void)close(*(const int *)fdptr);
 	return 0;
 }
 
@@ -709,5 +706,13 @@ int stress_inotify(
 
 	return EXIT_SUCCESS;
 }
-
+#else
+int stress_inotify(
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
+{
+	return stress_not_implemented(counter, instance, max_ops, name);
+}
 #endif
