@@ -22,20 +22,9 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
 
-#if defined(STRESS_KCMP)
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <string.h>
-#include <unistd.h>
-#include <sys/types.h>
-#include <sys/wait.h>
-#include <sys/syscall.h>
+#if defined(__linux__) && defined(__NR_kcmp)
 
 /* Urgh, should be from linux/kcmp.h */
 enum {
@@ -49,29 +38,9 @@ enum {
         KCMP_TYPES,
 };
 
-/*
- *  sys_kcmp()
- *	kcmp syscall
- */
-static inline long sys_kcmp(int pid1, int pid2, int type, int fd1, int fd2)
-{
-#if defined(__NR_kcmp)
-	errno = 0;
-	return syscall(__NR_kcmp, pid1, pid2, type, fd1, fd2);
-#else
-	(void)pid1;
-	(void)pid2;
-	(void)type;
-	(void)fd1;
-	(void)fd2;
-	errno = ENOSYS;
-	return -1;
-#endif
-}
-
 #define KCMP(pid1, pid2, type, idx1, idx2)		\
 {							\
-	int rc = sys_kcmp(pid1, pid2, type, idx1, idx2);\
+	int rc = shim_kcmp(pid1, pid2, type, idx1, idx2);\
 							\
 	if (rc < 0) {	 				\
 		if (errno == EPERM) {			\
@@ -86,7 +55,7 @@ static inline long sys_kcmp(int pid1, int pid2, int type, int fd1, int fd2)
 
 #define KCMP_VERIFY(pid1, pid2, type, idx1, idx2, res)	\
 {							\
-	int rc = sys_kcmp(pid1, pid2, type, idx1, idx2);\
+	int rc = shim_kcmp(pid1, pid2, type, idx1, idx2);\
 							\
 	if (rc != res) {				\
 		if (rc < 0) {				\
@@ -140,7 +109,7 @@ again:
 		(void)close(fd1);
 		return EXIT_FAILURE;
 	} else if (pid1 == 0) {
-		setpgid(0, pgrp);
+		(void)setpgid(0, pgrp);
 		stress_parent_died_alarm();
 
 		/* Child */
@@ -154,7 +123,7 @@ again:
 		/* Parent */
 		int fd2, status, pid2;
 
-		setpgid(pid1, pgrp);
+		(void)setpgid(pid1, pgrp);
 		pid2 = getpid();
 		if ((fd2 = open("/dev/null", O_WRONLY)) < 0) {
 			pr_fail_err(name, "open");
@@ -214,5 +183,13 @@ reap:
 	}
 	return ret;
 }
-
+#else
+int stress_kcmp(
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
+{
+	return stress_not_implemented(counter, instance, max_ops, name);
+}
 #endif
