@@ -22,19 +22,6 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <inttypes.h>
-#include <unistd.h>
-#include <limits.h>
-#include <fcntl.h>
-
-#include <sys/types.h>
-#include <sys/stat.h>
-
 #include "stress-ng.h"
 
 /*
@@ -110,17 +97,18 @@ static int stress_link_generic(
 			}
 			if (symlink) {
 				char buf[PATH_MAX];
-				ssize_t ret;
+				ssize_t rret;
 
-				ret = readlink(newpath, buf, sizeof(buf));
-				if (ret < 0) {
+				rret = readlink(newpath, buf, sizeof(buf) - 1);
+				if (rret < 0) {
 					rc = exit_status(errno);
 					pr_fail_err(name, "readlink");
 				} else {
-					if ((size_t)ret != oldpathlen)
+					newpath[rret] = '\0';
+					if ((size_t)rret != oldpathlen)
 						pr_fail_err(name, "readlink length error");
 					else
-						if (strncmp(oldpath, buf, ret))
+						if (strncmp(oldpath, buf, rret))
 							pr_fail_err(name, "readlink path error");
 				}
 			}
