@@ -22,23 +22,10 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
 
-#if defined(STRESS_LOCKA)
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <unistd.h>
-#include <fcntl.h>
-#include <sys/file.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <sys/wait.h>
-#include <errno.h>
-#include <signal.h>
+#if defined(F_GETLK) && defined(F_SETLK) && defined(F_SETLKW) && \
+    defined(F_WRLCK) && defined(F_UNLCK)
 
 #define LOCK_FILE_SIZE	(1024 * 1024)
 #define LOCK_SIZE	(8)
@@ -298,7 +285,7 @@ again:
 		goto tidy;
 	}
 	if (cpid == 0) {
-		setpgid(0, pgrp);
+		(void)setpgid(0, pgrp);
 		stress_parent_died_alarm();
 
 		if (stress_locka_contention(name, fd, counter, max_ops) < 0)
@@ -306,7 +293,7 @@ again:
 		stress_locka_info_free();
 		exit(EXIT_SUCCESS);
 	}
-	setpgid(cpid, pgrp);
+	(void)setpgid(cpid, pgrp);
 
 	if (stress_locka_contention(name, fd, counter, max_ops) == 0)
 		ret = EXIT_SUCCESS;
@@ -325,5 +312,13 @@ tidy:
 
 	return ret;
 }
-
+#else
+int stress_locka(
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
+{
+	return stress_not_implemented(counter, instance, max_ops, name);
+}
 #endif
