@@ -22,17 +22,8 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
 
-#include <stdlib.h>
-#include <string.h>
-#include <unistd.h>
-#include <errno.h>
-#include <sched.h>
-#include <setjmp.h>
-
 /*
  *  stress_jmp()
  *	stress system by setjmp/longjmp calls
