@@ -22,15 +22,10 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
-#include <stdio.h>
-#include <stdint.h>
-#include <stdlib.h>
-#include <search.h>
-
 #include "stress-ng.h"
 
+#include <search.h>
+
 static uint64_t opt_lsearch_size = DEFAULT_LSEARCH_SIZE;
 static bool set_lsearch_size = false;
 
@@ -52,7 +47,7 @@ void stress_set_lsearch_size(const char *optarg)
  */
 static int cmp(const void *p1, const void *p2)
 {
-	return (*(uint32_t *)p1 - *(uint32_t *)p2);
+	return (*(const uint32_t *)p1 - *(const uint32_t *)p2);
 }
 
 /*
