@@ -22,23 +22,9 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
 
-#if defined(STRESS_MADVISE)
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <string.h>
-#include <setjmp.h>
-#include <signal.h>
-#include <unistd.h>
-#include <sys/mman.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <fcntl.h>
+#if !defined(__gnu_hurd__) && NEED_GLIBC(2,19,0)
 
 #define NO_MEM_RETRIES_MAX	(256)
 
@@ -46,55 +32,55 @@ static sigjmp_buf jmp_env;
 static uint64_t sigbus_count;
 
 static const int madvise_options[] = {
-#ifdef MADV_NORMAL
+#if defined(MADV_NORMAL)
 	MADV_NORMAL,
 #endif
-#ifdef MADV_RANDOM
+#if defined(MADV_RANDOM)
 	MADV_RANDOM,
 #endif
-#ifdef MADV_SEQUENTIAL
+#if defined(MADV_SEQUENTIAL)
 	MADV_SEQUENTIAL,
 #endif
-#ifdef MADV_WILLNEED
+#if defined(MADV_WILLNEED)
 	MADV_WILLNEED,
 #endif
-#ifdef MADV_DONTNEED
+#if defined(MADV_DONTNEED)
 	MADV_DONTNEED,
 #endif
-#ifdef MADV_REMOVE
+#if defined(MADV_REMOVE)
 	MADV_REMOVE,
 #endif
-#ifdef MADV_DONTFORK
+#if defined(MADV_DONTFORK)
 	MADV_DONTFORK,
 #endif
-#ifdef MADV_DOFORK
+#if defined(MADV_DOFORK)
 	MADV_DOFORK,
 #endif
-#ifdef MADV_HWPOISON
+#if defined(MADV_HWPOISON)
 	MADV_HWPOISON,
 #endif
-#ifdef MADV_MERGEABLE
+#if defined(MADV_MERGEABLE)
 	MADV_MERGEABLE,
 #endif
-#ifdef MADV_UNMERGEABLE
+#if defined(MADV_UNMERGEABLE)
 	MADV_UNMERGEABLE,
 #endif
-#ifdef MADV_SOFT_OFFLINE
+#if defined(MADV_SOFT_OFFLINE)
 	MADV_SOFT_OFFLINE,
 #endif
-#ifdef MADV_HUGEPAGE
+#if defined(MADV_HUGEPAGE)
 	MADV_HUGEPAGE,
 #endif
-#ifdef MADV_NOHUGEPAGE
+#if defined(MADV_NOHUGEPAGE)
 	MADV_NOHUGEPAGE,
 #endif
-#ifdef MADV_DONTDUMP
+#if defined(MADV_DONTDUMP)
 	MADV_DONTDUMP,
 #endif
-#ifdef MADV_DODUMP
+#if defined(MADV_DODUMP)
 	MADV_DODUMP,
 #endif
-#ifdef MADV_FREE
+#if defined(MADV_FREE)
 	MADV_FREE
 #endif
 };
@@ -125,13 +111,14 @@ int stress_madvise(
 	const size_t page_size = stress_get_pagesize();
 	size_t sz = 4 *  MB;
 	const pid_t pid = getpid();
-	int ret, fd = -1, flags = MAP_SHARED;
-	int no_mem_retries = 0;
+	int ret, fd = -1;
+	NOCLOBBER int flags = MAP_SHARED;
+	NOCLOBBER int no_mem_retries = 0;
 	char filename[PATH_MAX];
 	char page[page_size];
 	size_t n;
 
-#ifdef MAP_POPULATE
+#if defined(MAP_POPULATE)
 	flags |= MAP_POPULATE;
 #endif
 	ret = sigsetjmp(jmp_env, 1);
@@ -186,12 +173,12 @@ int stress_madvise(
 			PROT_READ | PROT_WRITE, flags, fd, 0);
 		if (buf == MAP_FAILED) {
 			/* Force MAP_POPULATE off, just in case */
-#ifdef MAP_POPULATE
+#if defined(MAP_POPULATE)
 			flags &= ~MAP_POPULATE;
 #endif
 			no_mem_retries++;
 			if (no_mem_retries > 1)
-				usleep(100000);
+				(void)shim_usleep(100000);
 			continue;	/* Try again */
 		}
 		ret = sigsetjmp(jmp_env, 1);
@@ -211,7 +198,7 @@ int stress_madvise(
 			const int advise = madvise_options[idx];
 
 			(void)madvise(buf + n, page_size, advise);
-			(void)msync(buf + n, page_size, MS_ASYNC);
+			(void)shim_msync(buf + n, page_size, MS_ASYNC);
 		}
 		for (n = 0; n < sz; n += page_size) {
 			size_t m = (mwc64() % sz) & ~(page_size - 1);
@@ -219,7 +206,7 @@ int stress_madvise(
 			const int advise = madvise_options[idx];
 
 			(void)madvise(buf + m, page_size, advise);
-			(void)msync(buf + m, page_size, MS_ASYNC);
+			(void)shim_msync(buf + m, page_size, MS_ASYNC);
 		}
 		(void)munmap((void *)buf, sz);
 		(*counter)++;
@@ -233,5 +220,13 @@ int stress_madvise(
 			name, sigbus_count);
 	return EXIT_SUCCESS;
 }
-
+#else
+int stress_madvise(
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
+{
+	return stress_not_implemented(counter, instance, max_ops, name);
+}
 #endif
