@@ -22,35 +22,16 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <stdbool.h>
-#include <string.h>
-#include <errno.h>
-#include <unistd.h>
-#include <inttypes.h>
-#include <signal.h>
-#include <sys/types.h>
-#include <sys/wait.h>
-#if defined(STRESS_MALLOPT)
-#include <malloc.h>
-#endif
-
 static size_t opt_malloc_bytes = DEFAULT_MALLOC_BYTES;
 static bool set_malloc_bytes = false;
 
 static size_t opt_malloc_max = DEFAULT_MALLOC_MAX;
 static bool set_malloc_max = false;
 
-#if defined(STRESS_MALLOPT)
 static int opt_malloc_threshold = DEFAULT_MALLOC_THRESHOLD;
 static bool set_malloc_threshold = false;
-#endif
 
 void stress_set_malloc_bytes(const char *optarg)
 {
@@ -68,7 +49,6 @@ void stress_set_malloc_max(const char *optarg)
 		MIN_MALLOC_MAX, MAX_MALLOC_MAX);
 }
 
-#if defined(STRESS_MALLOPT)
 void stress_set_malloc_threshold(const char *optarg)
 {
 	set_malloc_threshold = true;
@@ -76,7 +56,6 @@ void stress_set_malloc_threshold(const char *optarg)
 	check_range("malloc-threshold", opt_malloc_threshold,
 		MIN_MALLOC_THRESHOLD, MAX_MALLOC_THRESHOLD);
 }
-#endif
 
 /*
  *  stress_alloc_size()
@@ -118,7 +97,7 @@ int stress_malloc(
 			opt_malloc_max = MIN_MALLOC_MAX;
 	}
 
-#if defined(STRESS_MALLOPT)
+#if defined(__GNUC__) && defined(__linux__)
 	if (set_malloc_threshold)
 		mallopt(M_MMAP_THRESHOLD, opt_malloc_threshold);
 #endif
@@ -133,7 +112,7 @@ again:
 	} else if (pid > 0) {
 		int status, ret;
 
-		setpgid(pid, pgrp);
+		(void)setpgid(pid, pgrp);
 		stress_parent_died_alarm();
 
 		/* Parent, wait for child */
@@ -164,7 +143,7 @@ again:
 		void *addr[opt_malloc_max];
 		size_t j;
 
-		setpgid(0, pgrp);
+		(void)setpgid(0, pgrp);
 		memset(addr, 0, sizeof(addr));
 
 		/* Make sure this is killable by OOM killer */
