@@ -22,18 +22,9 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
 
-#if defined(STRESS_MEMBARRIER)
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <unistd.h>
-#include <pthread.h>
-#include <signal.h>
+#if defined(HAVE_LIB_PTHREAD) && defined(__linux__) && defined(__NR_membarrier)
 
 #define MAX_MEMBARRIER_THREADS	(4)
 
@@ -45,24 +36,16 @@ enum membarrier_cmd {
 	MEMBARRIER_CMD_SHARED = (1 << 0),
 };
 
-static int sys_membarrier(int cmd, int flags)
-{
-#if defined(__NR_membarrier)
-	return syscall(__NR_membarrier, cmd, flags);
-#else
-	errno = ENOSYS;
-	return -1;
-#endif
-}
+typedef struct {
+	const char *name;
+} ctxt_t;
 
-static void *stress_membarrier_thread(void *ctxt)
+static void *stress_membarrier_thread(void *arg)
 {
 	static void *nowt = NULL;
-	uint8_t stack[SIGSTKSZ];
+	uint8_t stack[SIGSTKSZ + STACK_ALIGNMENT];
 	stack_t ss;
-	char *name = (char *)ctxt;
-
-	(void)ctxt;
+	const ctxt_t *ctxt = (ctxt_t *)arg;
 
 	/*
 	 *  Block all signals, let controlling thread
@@ -76,7 +59,7 @@ static void *stress_membarrier_thread(void *ctxt)
 	 *  However, we block signals in this thread
 	 *  so this is probably just totally unncessary.
 	 */
-	ss.ss_sp = (void *)stack;
+	ss.ss_sp = (void *)align_address(stack, STACK_ALIGNMENT);
 	ss.ss_size = SIGSTKSZ;
 	ss.ss_flags = 0;
 	if (sigaltstack(&ss, NULL) < 0) {
@@ -84,9 +67,8 @@ static void *stress_membarrier_thread(void *ctxt)
 		return &nowt;
 	}
 	while (keep_running && opt_do_run) {
-		if (sys_membarrier(MEMBARRIER_CMD_SHARED, 0) < 0) {
-			pr_err(stderr, "%s: membarrier failed: errno=%d: (%s)\n",
-				name, errno, strerror(errno));
+		if (shim_membarrier(MEMBARRIER_CMD_SHARED, 0) < 0) {
+			pr_fail_err(ctxt->name, "membarrier");
 			break;
 		}
 	}
@@ -108,10 +90,11 @@ int stress_membarrier(
 	pthread_t pthreads[MAX_MEMBARRIER_THREADS];
 	size_t i;
 	int pthread_ret[MAX_MEMBARRIER_THREADS];
+	ctxt_t ctxt = { name };
 
 	(void)instance;
 
-	ret = sys_membarrier(MEMBARRIER_CMD_QUERY, 0);
+	ret = shim_membarrier(MEMBARRIER_CMD_QUERY, 0);
 	if (ret < 0) {
 		pr_err(stderr, "%s: membarrier failed: errno=%d: (%s)\n",
 			name, errno, strerror(errno));
@@ -124,17 +107,17 @@ int stress_membarrier(
 	}
 
 	sigfillset(&set);
-	memset(pthread_ret, 0, sizeof(ret));
+	memset(pthread_ret, 0, sizeof(pthread_ret));
 	keep_running = true;
 
 	for (i = 0; i < MAX_MEMBARRIER_THREADS; i++) {
 		pthread_ret[i] =
 			pthread_create(&pthreads[i], NULL,
-				stress_membarrier_thread, (void *)name);
+				stress_membarrier_thread, (void *)&ctxt);
 	}
 
 	do {
-		ret = sys_membarrier(MEMBARRIER_CMD_SHARED, 0);
+		ret = shim_membarrier(MEMBARRIER_CMD_SHARED, 0);
 		if (ret < 0) {
 			pr_err(stderr, "%s: membarrier failed: errno=%d: (%s)\n",
 				name, errno, strerror(errno));
@@ -150,5 +133,13 @@ int stress_membarrier(
 	}
 	return EXIT_SUCCESS;
 }
-
+#else
+int stress_membarrier(
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
+{
+	return stress_not_implemented(counter, instance, max_ops, name);
+}
 #endif
