@@ -22,25 +22,8 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
 
-#if defined(STRESS_MEMFD)
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <stdbool.h>
-#include <string.h>
-#include <errno.h>
-#include <unistd.h>
-#include <inttypes.h>
-#include <signal.h>
-#include <sys/types.h>
-#include <sys/wait.h>
-#include <fcntl.h>
-
 #define MAX_MEM_FDS 	(256)
 
 static size_t opt_memfd_bytes = DEFAULT_MEMFD_BYTES;
@@ -54,18 +37,7 @@ void stress_set_memfd_bytes(const char *optarg)
 		MIN_MEMFD_BYTES, MAX_MEMFD_BYTES);
 }
 
-/*
- *  Ugly hack until glibc defines this
- */
-static inline int sys_memfd_create(const char *name, unsigned int flags)
-{
-#if defined(__NR_memfd_create)
-	return syscall(__NR_memfd_create, name, flags);
-#else
-	errno = ENOSYS;
-	return -1;
-#endif
-}
+#if defined(__linux__) && defined(__NR_memfd_create)
 
 /*
  *  Create allocations using memfd_create, ftruncate and mmap
@@ -93,10 +65,10 @@ static void stress_memfd_allocs(
 		}
 
 		for (i = 0; i < MAX_MEM_FDS; i++) {
-			char name[PATH_MAX];
+			char filename[PATH_MAX];
 
-			snprintf(name, sizeof(name), "memfd-%u-%zu", pid, i);
-			fds[i] = sys_memfd_create(name, 0);
+			snprintf(filename, sizeof(filename), "memfd-%u-%zu", pid, i);
+			fds[i] = shim_memfd_create(filename, 0);
 			if (fds[i] < 0) {
 				switch (errno) {
 				case EMFILE:
@@ -132,8 +104,7 @@ static void stress_memfd_allocs(
 					case EINTR:
 						break;
 					default:
-						pr_fail(stderr, "%s: ftruncate failed, errno=%d (%s)\n",
-                                        		name, errno, strerror(errno));
+						pr_fail_err(name, "ftruncate");
 						break;
 					}
 				}
@@ -152,7 +123,7 @@ static void stress_memfd_allocs(
 				 *  ..and punch a hole
 				 */
 				whence = (mwc32() % size) & ~(page_size - 1);
-				ret = fallocate(fds[i], FALLOC_FL_PUNCH_HOLE |
+				ret = shim_fallocate(fds[i], FALLOC_FL_PUNCH_HOLE |
 					FALLOC_FL_KEEP_SIZE, whence, page_size);
 				(void)ret;
 #endif
@@ -165,42 +136,36 @@ static void stress_memfd_allocs(
 #if defined(SEEK_SET)
 			if (lseek(fds[i], (off_t)size>> 1, SEEK_SET) < 0) {
 				if (errno != ENXIO)
-					pr_fail(stderr, "%s: lseek SEEK_SET on memfd failed: "
-						"errno=%d (%s)\n", name, errno, strerror(errno));
+					pr_fail_err(name, "lseek SEEK_SET on memfd");
 			}
 #endif
 #if defined(SEEK_CUR)
 			if (lseek(fds[i], (off_t)0, SEEK_CUR) < 0) {
 				if (errno != ENXIO)
-					pr_fail(stderr, "%s: lseek SEEK_CUR on memfd failed: "
-						"errno=%d (%s)\n", name, errno, strerror(errno));
+					pr_fail_err(name, "lseek SEEK_CUR on memfd");
 			}
 #endif
 #if defined(SEEK_END)
 			if (lseek(fds[i], (off_t)0, SEEK_END) < 0) {
 				if (errno != ENXIO)
-					pr_fail(stderr, "%s: lseek SEEK_END on memfd failed: "
-						"errno=%d (%s)\n", name, errno, strerror(errno));
+					pr_fail_err(name, "lseek SEEK_END on memfd");
 			}
 #endif
 #if defined(SEEK_HOLE)
 			if (lseek(fds[i], (off_t)0, SEEK_HOLE) < 0) {
 				if (errno != ENXIO)
-					pr_fail(stderr, "%s: lseek SEEK_HOLE on memfd failed: "
-						"errno=%d (%s)\n", name, errno, strerror(errno));
+					pr_fail_err(name, "lseek SEEK_HOLE on memfd");
 			}
 #endif
 #if defined(SEEK_DATA)
 			if (lseek(fds[i], (off_t)0, SEEK_DATA) < 0) {
 				if (errno != ENXIO)
-					pr_fail(stderr, "%s: lseek SEEK_DATA on memfd failed: "
-						"errno=%d (%s)\n", name, errno, strerror(errno));
+					pr_fail_err(name, "lseek SEEK_DATA on memfd");
 			}
 #endif
 			if (!opt_do_run)
 				goto clean;
 		}
-	
 clean:
 		for (i = 0; i < MAX_MEM_FDS; i++) {
 			if (maps[i] != MAP_FAILED)
@@ -245,7 +210,7 @@ again:
 	} else if (pid > 0) {
 		int status, ret;
 
-		setpgid(pid, pgrp);
+		(void)setpgid(pid, pgrp);
 		stress_parent_died_alarm();
 
 		/* Parent, wait for child */
@@ -280,7 +245,7 @@ again:
 			goto again;
 		}
 	} else if (pid == 0) {
-		setpgid(0, pgrp);
+		(void)setpgid(0, pgrp);
 
 		/* Make sure this is killable by OOM killer */
 		set_oom_adjustment(name, true);
@@ -296,5 +261,13 @@ again:
 
 	return EXIT_SUCCESS;
 }
-
+#else
+int stress_memfd(
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
+{
+	return stress_not_implemented(counter, instance, max_ops, name);
+}
 #endif
