@@ -22,24 +22,31 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
 
-#if defined(STRESS_MERGESORT)
-
-#include <stdio.h>
-#include <stdint.h>
-#include <stdlib.h>
-#include <stdbool.h>
-#include <setjmp.h>
-#include <signal.h>
+#if defined(HAVE_LIB_BSD)
 #include <bsd/stdlib.h>
 
+static volatile bool do_jmp = true;
+static sigjmp_buf jmp_env;
+#endif
+
 static uint64_t opt_mergesort_size = DEFAULT_MERGESORT_SIZE;
 static bool set_mergesort_size = false;
-static volatile bool do_jmp = true;
-static sigjmp_buf jmp_env;
+
+/*
+ *  stress_set_mergesort_size()
+ *	set mergesort size
+ */
+void stress_set_mergesort_size(const void *optarg)
+{
+	set_mergesort_size = true;
+	opt_mergesort_size = get_uint64_byte(optarg);
+	check_range("mergesort-size", opt_mergesort_size,
+		MIN_MERGESORT_SIZE, MAX_MERGESORT_SIZE);
+}
+
+#if defined(HAVE_LIB_BSD)
 
 /*
  *  stress_mergesort_handler()
@@ -55,26 +62,14 @@ static void MLOCKED stress_mergesort_handler(int dummy)
 	}
 }
 
-/*
- *  stress_set_mergesort_size()
- *	set mergesort size
- */
-void stress_set_mergesort_size(const void *optarg)
-{
-	set_mergesort_size = true;
-	opt_mergesort_size = get_uint64_byte(optarg);
-	check_range("mergesort-size", opt_mergesort_size,
-		MIN_MERGESORT_SIZE, MAX_MERGESORT_SIZE);
-}
-
 /*
  *  stress_mergesort_cmp_1()
  *	mergesort comparison - sort on int32 values
  */
 static int stress_mergesort_cmp_1(const void *p1, const void *p2)
 {
-	int32_t *i1 = (int32_t *)p1;
-	int32_t *i2 = (int32_t *)p2;
+	const int32_t *i1 = (const int32_t *)p1;
+	const int32_t *i2 = (const int32_t *)p2;
 
 	if (*i1 > *i2)
 		return 1;
@@ -99,8 +94,8 @@ static int stress_mergesort_cmp_2(const void *p1, const void *p2)
  */
 static int stress_mergesort_cmp_3(const void *p1, const void *p2)
 {
-	int8_t *i1 = (int8_t *)p1;
-	int8_t *i2 = (int8_t *)p2;
+	const int8_t *i1 = (const int8_t *)p1;
+	const int8_t *i2 = (const int8_t *)p2;
 
 	/* Force re-ordering on 8 bit value */
 	return *i1 - *i2;
@@ -212,5 +207,13 @@ tidy:
 
 	return EXIT_SUCCESS;
 }
-
+#else
+int stress_mergesort(
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
+{
+	return stress_not_implemented(counter, instance, max_ops, name);
+}
 #endif
