@@ -22,23 +22,9 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
 
-#if defined(STRESS_MINCORE)
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <stddef.h>
-#include <string.h>
-#include <unistd.h>
-#include <errno.h>
-#include <sys/mman.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <fcntl.h>
+#if !defined(__gnu_hurd__) && NEED_GLIBC(2,2,0)
 
 #define VEC_MAX_SIZE 	(64)
 
@@ -52,7 +38,7 @@ int stress_mincore(
 	const uint64_t max_ops,
 	const char *name)
 {
-	volatile uint8_t *addr = 0;
+	uint8_t *addr = 0;
 	const size_t page_size = stress_get_pagesize();
 	const ptrdiff_t mask = ~(page_size - 1);
 
@@ -97,5 +83,13 @@ redo:
 
 	return EXIT_SUCCESS;
 }
-
+#else
+int stress_mincore(
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
+{
+	return stress_not_implemented(counter, instance, max_ops, name);
+}
 #endif
