@@ -22,22 +22,9 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
 
-#if defined(STRESS_MLOCK)
-
-#include <stddef.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <unistd.h>
-
-#include <sys/mman.h>
-#include <sys/types.h>
-#include <sys/wait.h>
-#include <signal.h>
+#if defined(_POSIX_MEMLOCK_RANGE) && !defined(__minix__)
 
 #define MLOCK_MAX	(256*1024)
 
@@ -47,11 +34,6 @@
 #define MLOCK_ONFAULT 1
 #endif
 
-static int sys_mlock2(const void *addr, size_t len, int flags)
-{
-        return (int)syscall(__NR_mlock2, addr, len, flags);
-}
-
 /*
  *  mlock_shim()
  *	if mlock2 is available, randonly exerise this
@@ -70,7 +52,7 @@ static int mlock_shim(const void *addr, size_t len)
 				0 : MLOCK_ONFAULT;
 			int ret;
 
-			ret = sys_mlock2(addr, len, flags);
+			ret = shim_mlock2(addr, len, flags);
 			if (!ret)
 				return 0;
 			if (errno != ENOSYS)
@@ -82,7 +64,7 @@ static int mlock_shim(const void *addr, size_t len)
 	}
 
 	/* Just do mlock */
-	return mlock((void *)addr, len);
+	return mlock((const void *)addr, len);
 }
 #else
 static inline int mlock_shim(const void *addr, size_t len)
@@ -122,7 +104,7 @@ again:
 	} else if (pid > 0) {
 		int status, ret;
 
-		setpgid(pid, pgrp);
+		(void)setpgid(pid, pgrp);
 		stress_parent_died_alarm();
 
 		/* Parent, wait for child */
@@ -158,7 +140,7 @@ again:
 	} else if (pid == 0) {
 		size_t i, n;
 
-		setpgid(0, pgrp);
+		(void)setpgid(0, pgrp);
 
 		/* Make sure this is killable by OOM killer */
 		set_oom_adjustment(name, true);
@@ -233,5 +215,13 @@ again:
 
 	return EXIT_SUCCESS;
 }
-
+#else
+int stress_mlock(
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
+{
+	return stress_not_implemented(counter, instance, max_ops, name);
+}
 #endif
