@@ -22,20 +22,6 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <string.h>
-#include <signal.h>
-#include <unistd.h>
-#include <sys/mman.h>
-#include <sys/types.h>
-#include <sys/wait.h>
-#include <sys/stat.h>
-#include <fcntl.h>
-
 #include "stress-ng.h"
 
 #define NO_MEM_RETRIES_MAX	(256)
@@ -158,10 +144,8 @@ static void stress_mmap_child(
 	const size_t pages4k)
 {
 	int no_mem_retries = 0;
-#if !defined(__gnu_hurd__) && !defined(__minix__)
 	const int ms_flags = (opt_flags & OPT_FLAGS_MMAP_ASYNC) ?
 		MS_ASYNC : MS_SYNC;
-#endif
 
 	do {
 		uint8_t mapped[pages4k];
@@ -183,19 +167,17 @@ static void stress_mmap_child(
 			PROT_READ | PROT_WRITE, *flags | rnd_flag, fd, 0);
 		if (buf == MAP_FAILED) {
 			/* Force MAP_POPULATE off, just in case */
-#ifdef MAP_POPULATE
+#if defined(MAP_POPULATE)
 			*flags &= ~MAP_POPULATE;
 #endif
 			no_mem_retries++;
 			if (no_mem_retries > 1)
-				usleep(100000);
+				(void)shim_usleep(100000);
 			continue;	/* Try again */
 		}
 		if (opt_flags & OPT_FLAGS_MMAP_FILE) {
 			memset(buf, 0xff, sz);
-#if !defined(__gnu_hurd__) && !defined(__minix__)
-			(void)msync((void *)buf, sz, ms_flags);
-#endif
+			(void)shim_msync((void *)buf, sz, ms_flags);
 		}
 		(void)madvise_random(buf, sz);
 		(void)mincore_touch_pages(buf, opt_mmap_bytes);
@@ -233,7 +215,7 @@ static void stress_mmap_child(
 			}
 		}
 		(void)munmap((void *)buf, sz);
-#ifdef MAP_FIXED
+#if defined(MAP_FIXED)
 		/*
 		 *  Step #2, map them back in random order
 		 */
@@ -312,7 +294,7 @@ int stress_mmap(
 	uint32_t ooms = 0, segvs = 0, buserrs = 0;
 	char filename[PATH_MAX];
 
-#ifdef MAP_POPULATE
+#if defined(MAP_POPULATE)
 	flags |= MAP_POPULATE;
 #endif
 	if (!set_mmap_bytes) {
@@ -383,7 +365,7 @@ again:
 	} else if (pid > 0) {
 		int status, ret;
 
-		setpgid(pid, pgrp);
+		(void)setpgid(pid, pgrp);
 		/* Parent, wait for child */
 		ret = waitpid(pid, &status, 0);
 		if (ret < 0) {
@@ -425,7 +407,7 @@ again:
 			}
 		}
 	} else if (pid == 0) {
-		setpgid(0, pgrp);
+		(void)setpgid(0, pgrp);
 		stress_parent_died_alarm();
 
 		/* Make sure this is killable by OOM killer */
