@@ -22,21 +22,11 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
 
-#if defined(STRESS_MMAPFORK)
+#if defined(__linux__)
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <sched.h>
-#include <sys/mman.h>
 #include <sys/sysinfo.h>
-#include <sys/types.h>
-#include <sys/wait.h>
-#include <setjmp.h>
 
 #define MAX_PIDS		(32)
 
@@ -65,6 +55,17 @@ static void MLOCKED stress_segvhandler(int dummy)
 	_exit(segv_ret);
 }
 
+static void __strncat(char *dst, char *src, size_t *n)
+{
+	size_t ln = strlen(src);
+
+	if (*n <= ln)
+		return;
+	
+	strncat(dst, src, *n);
+	*n -= ln;
+}
+
 /*
  *  stress_mmapfork()
  *	stress mappings + fork VM subystem
@@ -100,14 +101,14 @@ retry:			if (!opt_do_run)
 			if (pids[n] < 0) {
 				/* Out of resources for fork, re-do, ugh */
 				if (errno == EAGAIN) {
-					usleep(10000);
+					(void)shim_usleep(10000);
 					goto retry;
 				}
 				break;
 			}
 			if (pids[n] == 0) {
 				/* Child */
-				setpgid(0, pgrp);
+				(void)setpgid(0, pgrp);
 				stress_parent_died_alarm();
 
 				if (stress_sighandler(name, SIGSEGV, stress_segvhandler, NULL) < 0)
@@ -137,7 +138,7 @@ retry:			if (!opt_do_run)
 				}
 				_exit(EXIT_SUCCESS);
 			}
-			setpgid(pids[n], pgrp);
+			(void)setpgid(pids[n], pgrp);
 		}
 reap:
 		for (i = 0; i < n; i++) {
@@ -164,19 +165,20 @@ reap:
 
 	if (segv_count) {
 		char buffer[1024];
+		size_t n = sizeof(buffer) - 1;
 
 		*buffer = '\0';
 
 		if (segv_reasons & _EXIT_SEGV_MMAP)
-			strncat(buffer, " mmap", sizeof(buffer));
+			__strncat(buffer, " mmap", &n);
 		if (segv_reasons & _EXIT_SEGV_MADV_WILLNEED)
-			strncat(buffer, " madvise-WILLNEED", sizeof(buffer));
+			__strncat(buffer, " madvise-WILLNEED", &n);
 		if (segv_reasons & _EXIT_SEGV_MADV_DONTNEED)
-			strncat(buffer, " madvise-DONTNEED", sizeof(buffer));
+			__strncat(buffer, " madvise-DONTNEED", &n);
 		if (segv_reasons & _EXIT_SEGV_MEMSET)
-			strncat(buffer, " memset", sizeof(buffer));
+			__strncat(buffer, " memset", &n);
 		if (segv_reasons & _EXIT_SEGV_MUNMAP)
-			strncat(buffer, " munmap", sizeof(buffer));
+			__strncat(buffer, " munmap", &n);
 
                 pr_dbg(stderr, "%s: SIGSEGV errors: %" PRIu64 " (where:%s)\n",
 			name, segv_count, buffer);
@@ -184,5 +186,13 @@ reap:
 
 	return EXIT_SUCCESS;
 }
-
+#else
+int stress_mmapfork(
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
+{
+	return stress_not_implemented(counter, instance, max_ops, name);
+}
 #endif
