@@ -22,17 +22,6 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <unistd.h>
-#include <sys/mman.h>
-#include <sys/types.h>
-#include <sys/wait.h>
-#include <signal.h>
-
 #include "stress-ng.h"
 
 #define MMAP_MAX	(256*1024)
@@ -71,7 +60,7 @@ again:
 	} else if (pid > 0) {
 		int status, ret;
 
-		setpgid(pid, pgrp);
+		(void)setpgid(pid, pgrp);
 
 		/* Parent, wait for child */
 		ret = waitpid(pid, &status, 0);
@@ -105,7 +94,7 @@ again:
 	} else if (pid == 0) {
 		ssize_t i, n;
 
-		setpgid(0, pgrp);
+		(void)setpgid(0, pgrp);
 		stress_parent_died_alarm();
 
 		/* Make sure this is killable by OOM killer */
