@@ -22,32 +22,16 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
 
-#if defined(STRESS_MQ)
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <stdbool.h>
-#include <string.h>
-#include <unistd.h>
-#include <signal.h>
-#include <limits.h>
-#include <errno.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <sys/wait.h>
-#include <fcntl.h>
+#if defined(HAVE_LIB_RT) && defined(__linux__)
 #include <mqueue.h>
-#include <time.h>
 
 typedef struct {
 	uint64_t	value;
 	bool		stop;
 } msg_t;
+#endif
 
 static int opt_mq_size = DEFAULT_MQ_SIZE;
 static bool set_mq_size = false;
@@ -63,6 +47,8 @@ void stress_set_mq_size(const char *optarg)
                 MIN_MQ_SIZE, MAX_MQ_SIZE);
 }
 
+#if defined(HAVE_LIB_RT) && defined(__linux__)
+
 static void stress_mq_notify_func(union sigval s)
 {
 	(void)s;
@@ -163,7 +149,7 @@ again:
 		sigev.sigev_notify_function = stress_mq_notify_func;
 		sigev.sigev_notify_attributes = NULL;
 
-		setpgid(0, pgrp);
+		(void)setpgid(0, pgrp);
 		stress_parent_died_alarm();
 
 		while (opt_do_run) {
@@ -210,7 +196,7 @@ again:
 		msg_t msg;
 
 		/* Parent */
-		setpgid(pid, pgrp);
+		(void)setpgid(pid, pgrp);
 
 		do {
 			int ret;
@@ -220,8 +206,6 @@ again:
 			msg.value = (*counter);
 			msg.stop = false;
 			if ((attr_count++ & 31) == 0) {
-				struct mq_attr attr;
-
 				if (mq_getattr(mq, &attr) < 0)
 					pr_fail_dbg(name, "mq_getattr");
 			}
@@ -259,5 +243,13 @@ again:
 	}
 	return EXIT_SUCCESS;
 }
-
+#else
+int stress_mq(
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
+{
+	return stress_not_implemented(counter, instance, max_ops, name);
+}
 #endif
