@@ -22,23 +22,8 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
 
-#if defined(STRESS_MREMAP)
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <string.h>
-#include <errno.h>
-#include <unistd.h>
-#include <sys/mman.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <fcntl.h>
-
 static size_t opt_mremap_bytes = DEFAULT_MREMAP_BYTES;
 static bool set_mremap_bytes = false;
 
@@ -50,6 +35,37 @@ void stress_set_mremap_bytes(const char *optarg)
 		MIN_MREMAP_BYTES, MAX_MREMAP_BYTES);
 }
 
+#if defined(__linux__) && NEED_GLIBC(2,4,0)
+
+#if defined(MREMAP_FIXED)
+/*
+ *  rand_mremap_addr()
+ *	try and find a random unmapped region of memory
+ */
+static inline void *rand_mremap_addr(const size_t sz, int flags)
+{
+	void *addr;
+
+	flags &= ~(MREMAP_FIXED | MAP_SHARED | MAP_POPULATE);
+	flags |= (MAP_PRIVATE | MAP_ANONYMOUS);
+
+	addr = mmap(NULL, sz, PROT_READ | PROT_WRITE, flags, -1, 0);
+	if (addr == MAP_FAILED)
+		return NULL;
+
+	munmap(addr, sz);
+
+	/*
+	 * At this point, we know that we can remap to this addr
+	 * in this process if we don't do any memory mappings between
+	 * the munmap above and the remapping
+	 */
+
+	return addr;
+}
+#endif
+
+
 
 /*
  *  try_remap()
@@ -62,17 +78,34 @@ static int try_remap(
 	const size_t new_sz)
 {
 	uint8_t *newbuf;
-	int retry;
+	int retry, flags = 0;
 #if defined(MREMAP_MAYMOVE)
-	int flags = MREMAP_MAYMOVE;
+	const int maymove = MREMAP_MAYMOVE;
 #else
-	int flags = 0;
+	const int maymove = 0;
+#endif
+
+#if defined(MREMAP_FIXED) && defined(MREMAP_MAYMOVE)
+	flags = maymove | (mwc32() & MREMAP_FIXED);
+#else
+	flags = maymove;
 #endif
 
 	for (retry = 0; retry < 100; retry++) {
+#if defined(MREMAP_FIXED)
+		void *addr = rand_mremap_addr(new_sz, flags);
+#endif
 		if (!opt_do_run)
 			return 0;
+#if defined(MREMAP_FIXED)
+		if (addr) {
+			newbuf = mremap(*buf, old_sz, new_sz, flags, addr);
+		} else {
+			newbuf = mremap(*buf, old_sz, new_sz, flags & ~MREMAP_FIXED);
+		}
+#else
 		newbuf = mremap(*buf, old_sz, new_sz, flags);
+#endif
 		if (newbuf != MAP_FAILED) {
 			*buf = newbuf;
 			return 0;
@@ -82,14 +115,25 @@ static int try_remap(
 		case ENOMEM:
 		case EAGAIN:
 			continue;
-		case EFAULT:
 		case EINVAL:
+#if defined(MREMAP_FIXED)
+			/*
+			 * Earlier kernels may not support this or we
+			 * chose a bad random address, so just fall
+			 * back to non fixed remapping
+			 */
+			if (flags & MREMAP_FIXED) {
+				flags &= ~MREMAP_FIXED;
+				continue;
+			}
+#endif
+			break;
+		case EFAULT:
 		default:
 			break;
 		}
 	}
-	pr_fail(stderr, "%s: mremap failed, errno = %d (%s)\n",
-		name, errno, strerror(errno));
+	pr_fail_err(name, "mremap");
 	return -1;
 }
 
@@ -135,46 +179,27 @@ static void stress_mremap_set(
 	}
 }
 
-/*
- *  stress_mremap()
- *	stress mmap
- */
-int stress_mremap(
+static int stress_mremap_child(
 	uint64_t *const counter,
-	const uint32_t instance,
 	const uint64_t max_ops,
-	const char *name)
+	const char *name,
+	const size_t sz,
+	size_t new_sz,
+	const size_t page_size,
+	int *flags)
 {
-	uint8_t *buf = NULL;
-	const size_t page_size = stress_get_pagesize();
-	size_t sz, new_sz, old_sz;
-	int flags = MAP_PRIVATE | MAP_ANONYMOUS;
-
-	(void)instance;
-#ifdef MAP_POPULATE
-	flags |= MAP_POPULATE;
-#endif
-	if (!set_mremap_bytes) {
-		if (opt_flags & OPT_FLAGS_MAXIMIZE)
-			opt_mremap_bytes = MAX_MREMAP_BYTES;
-		if (opt_flags & OPT_FLAGS_MINIMIZE)
-			opt_mremap_bytes = MIN_MREMAP_BYTES;
-	}
-	new_sz = sz = opt_mremap_bytes & ~(page_size - 1);
-
-	/* Make sure this is killable by OOM killer */
-	set_oom_adjustment(name, true);
-
 	do {
+		uint8_t *buf = NULL;
+		size_t old_sz;
 
 		if (!opt_do_run)
 			break;
 
-		buf = mmap(NULL, new_sz, PROT_READ | PROT_WRITE, flags, -1, 0);
+		buf = mmap(NULL, new_sz, PROT_READ | PROT_WRITE, *flags, -1, 0);
 		if (buf == MAP_FAILED) {
 			/* Force MAP_POPULATE off, just in case */
-#ifdef MAP_POPULATE
-			flags &= ~MAP_POPULATE;
+#if defined(MAP_POPULATE)
+			*flags &= ~MAP_POPULATE;
 #endif
 			continue;	/* Try again */
 		}
@@ -233,4 +258,119 @@ int stress_mremap(
 	return EXIT_SUCCESS;
 }
 
+/*
+ *  stress_mremap()
+ *	stress mmap
+ */
+int stress_mremap(
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
+{
+	const size_t page_size = stress_get_pagesize();
+	size_t sz, new_sz;
+	int rc = EXIT_SUCCESS, flags = MAP_PRIVATE | MAP_ANONYMOUS;
+	pid_t pid;
+	uint32_t ooms = 0, segvs = 0, buserrs = 0;
+
+	(void)instance;
+#if defined(MAP_POPULATE)
+	flags |= MAP_POPULATE;
+#endif
+	if (!set_mremap_bytes) {
+		if (opt_flags & OPT_FLAGS_MAXIMIZE)
+			opt_mremap_bytes = MAX_MREMAP_BYTES;
+		if (opt_flags & OPT_FLAGS_MINIMIZE)
+			opt_mremap_bytes = MIN_MREMAP_BYTES;
+	}
+	new_sz = sz = opt_mremap_bytes & ~(page_size - 1);
+
+	/* Make sure this is killable by OOM killer */
+	set_oom_adjustment(name, true);
+
+again:
+	if (!opt_do_run)
+		return EXIT_SUCCESS;
+	pid = fork();
+	if (pid < 0) {
+		if (errno == EAGAIN)
+			goto again;
+		pr_err(stderr, "%s: fork failed: errno=%d: (%s)\n",
+			name, errno, strerror(errno));
+	} else if (pid > 0) {
+		int status, ret;
+
+		(void)setpgid(pid, pgrp);
+		/* Parent, wait for child */
+		ret = waitpid(pid, &status, 0);
+		if (ret < 0) {
+			if (errno != EINTR)
+				pr_dbg(stderr, "%s: waitpid(): errno=%d (%s)\n",
+					name, errno, strerror(errno));
+			(void)kill(pid, SIGTERM);
+			(void)kill(pid, SIGKILL);
+			(void)waitpid(pid, &status, 0);
+		} else if (WIFSIGNALED(status)) {
+			/* If we got killed by sigbus, re-start */
+			if (WTERMSIG(status) == SIGBUS) {
+				/* Happens frequently, so be silent */
+				buserrs++;
+				goto again;
+			}
+
+			pr_dbg(stderr, "%s: child died: %s (instance %d)\n",
+				name, stress_strsignal(WTERMSIG(status)),
+				instance);
+			/* If we got killed by OOM killer, re-start */
+			if (WTERMSIG(status) == SIGKILL) {
+				log_system_mem_info();
+				pr_dbg(stderr, "%s: assuming killed by OOM "
+					"killer, restarting again "
+					"(instance %d)\n",
+					name, instance);
+				ooms++;
+				goto again;
+			}
+			/* If we got killed by sigsegv, re-start */
+			if (WTERMSIG(status) == SIGSEGV) {
+				pr_dbg(stderr, "%s: killed by SIGSEGV, "
+					"restarting again "
+					"(instance %d)\n",
+					name, instance);
+				segvs++;
+				goto again;
+			}
+		} else {
+			rc = WEXITSTATUS(status);
+		}
+	} else if (pid == 0) {
+		(void)setpgid(0, pgrp);
+		stress_parent_died_alarm();
+
+		/* Make sure this is killable by OOM killer */
+		set_oom_adjustment(name, true);
+
+		rc = stress_mremap_child(counter, max_ops, name, sz,
+			new_sz, page_size, &flags);
+		exit(rc);
+	}
+
+	if (ooms + segvs + buserrs > 0)
+		pr_dbg(stderr, "%s: OOM restarts: %" PRIu32
+			", SEGV restarts: %" PRIu32
+			", SIGBUS signals: %" PRIu32 "\n",
+			name, ooms, segvs, buserrs);
+
+	return rc;
+}
+#else
+int stress_mremap(
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
+{
+	return stress_not_implemented(counter, instance, max_ops, name);
+}
 #endif
