@@ -22,25 +22,12 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
 
-#if defined(STRESS_MSG)
+#if !defined(__gnu_hurd__) && NEED_GLIBC(2,0,0)
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <string.h>
-#include <unistd.h>
-#include <signal.h>
-#include <limits.h>
-#include <errno.h>
-#include <sys/types.h>
-#include <sys/wait.h>
 #include <sys/ipc.h>
 #include <sys/msg.h>
-#include <sys/stat.h>
 
 #define MAX_SIZE	(8)
 #define MSG_STOP	"STOPMSG"
@@ -50,6 +37,31 @@ typedef struct {
 	char msg[MAX_SIZE];
 } msg_t;
 
+static int stress_msg_getstats(const char *name, const int msgq_id)
+{
+	struct msqid_ds buf;
+#if defined(__linux__)
+	struct msginfo info;
+#endif
+
+	if (msgctl(msgq_id, IPC_STAT, &buf) < 0) {
+		pr_fail_err(name, "msgctl: IPC_STAT");
+		return -errno;
+	}
+#if defined(__linux__)
+	if (msgctl(msgq_id, IPC_INFO, (struct msqid_ds *)&info) < 0) {
+		pr_fail_err(name, "msgctl: IPC_INFO");
+		return -errno;
+	}
+	if (msgctl(msgq_id, MSG_INFO, (struct msqid_ds *)&info) < 0) {
+		pr_fail_err(name, "msgctl: MSG_INFO");
+		return -errno;
+	}
+#endif
+
+	return 0;
+}
+
 /*
  *  stress_msg
  *	stress by message queues
@@ -80,7 +92,7 @@ again:
 		pr_fail_dbg(name, "fork");
 		return EXIT_FAILURE;
 	} else if (pid == 0) {
-		setpgid(0, pgrp);
+		(void)setpgid(0, pgrp);
 		stress_parent_died_alarm();
 
 		while (opt_do_run) {
@@ -110,7 +122,7 @@ again:
 		int status;
 
 		/* Parent */
-		setpgid(pid, pgrp);
+		(void)setpgid(pid, pgrp);
 
 		do {
 			memcpy(msg.msg, &i, sizeof(i));
@@ -120,6 +132,9 @@ again:
 					pr_fail_dbg(name, "msgsnd");
 				break;
 			}
+			if ((i & 0x1f) == 0)
+				if (stress_msg_getstats(name, msgq_id) < 0)
+					break;
 			i++;
 			(*counter)++;
 		} while (opt_do_run && (!max_ops || *counter < max_ops));
@@ -137,5 +152,13 @@ again:
 	}
 	return EXIT_SUCCESS;
 }
-
+#else
+int stress_msg(
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
+{
+	return stress_not_implemented(counter, instance, max_ops, name);
+}
 #endif
