@@ -22,23 +22,8 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
-#include <stdint.h>
-#include <stdlib.h>
-#include <stdbool.h>
-#include <unistd.h>
-#include <sched.h>
-#include <errno.h>
-#include <time.h>
-#include <signal.h>
-#include <sys/resource.h>
-#include <sys/types.h>
-#include <sys/wait.h>
-
 #include "stress-ng.h"
 
-
 /*
  *  stress on sched_nice()
  *	stress system by sched_nice
@@ -54,7 +39,7 @@ int stress_nice(
 	(void)instance;
 	(void)name;
 
-#ifdef RLIMIT_NICE
+#if defined(RLIMIT_NICE)
 	{
 		struct rlimit rlim;
 
@@ -81,7 +66,7 @@ int stress_nice(
 			int i;
 
 			/* Child */
-			setpgid(0, pgrp);
+			(void)setpgid(0, pgrp);
 			stress_parent_died_alarm();
 
 			pid = getpid();
@@ -102,7 +87,7 @@ int stress_nice(
 		if (pid > 0) {
 			int status;
 
-			setpgid(pid, pgrp);
+			(void)setpgid(pid, pgrp);
 
 			/* Parent, wait for child */
 			if (waitpid(pid, &status, 0) < 0) {
