@@ -22,87 +22,12 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
 
-#if defined(STRESS_OOM_PIPE)
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <string.h>
-#include <unistd.h>
-#include <limits.h>
-#include <signal.h>
-#include <sys/time.h>
-#include <sys/types.h>
-#include <sys/wait.h>
+#if defined(__linux__) && defined(F_SETPIPE_SZ)
 
 static int page_size;
 
-/*
- *  check_max_pipe_size()
- *	check if the given pipe size is allowed
- */
-static int check_max_pipe_size(const int sz)
-{
-	int fds[2];
-
-	if (sz < page_size)
-		return -1;
-
-	if (pipe(fds) < 0)
-		return -1;
-
-	if (fcntl(fds[0], F_SETPIPE_SZ, sz) < 0)
-		return -1;
-
-	(void)close(fds[0]);
-	(void)close(fds[1]);
-	return 0;
-}
-
-/*
- *  probe_max_pipe_size()
- *	determine the maximim allowed pipe size
- */
-static int probe_max_pipe_size(void)
-{
-	int i, ret, prev_sz, sz, min, max;
-	char buf[64];
-
-	/*
-	 *  Try and find maximum pipe size directly
-	 */
-	ret = system_read("/proc/sys/fs/pipe-max-size", buf, sizeof(buf));
-	if (ret > 0) {
-		if (sscanf(buf, "%d", &sz) == 1)
-			if (!check_max_pipe_size(sz))
-				return sz;
-	}
-
-	/*
-	 *  Need to find size by binary chop probing
-	 */
-	min = page_size;
-	max = INT_MAX;
-	prev_sz = 0;
-	for (i = 0; i < 64; i++) {
-		sz = min + (max - min) / 2;
-		if (prev_sz == sz)
-			return sz;
-		prev_sz = sz;
-		if (check_max_pipe_size(sz) == 0) {
-			min = sz;
-		} else {
-			max = sz;
-		}
-	}
-
-	return sz;
-}
-
 /*
  *  pipe_empty()
  *	read data from read end of pipe
@@ -125,9 +50,9 @@ static void pipe_empty(const int fd, const int max)
  *  pipe_fill()
  *	write data to fill write end of pipe
  */
-static void pipe_fill(const int fd, const int max)
+static void pipe_fill(const int fd, const size_t max)
 {
-	int i;
+	size_t i;
 	char buffer[page_size];
 
 	memset(buffer, 'X', sizeof(buffer));
@@ -150,7 +75,7 @@ static int stress_oom_pipe_expander(
 	const uint32_t instance,
 	const uint64_t max_ops,
 	const char *name,
-	const int max_pipe_size,
+	const size_t max_pipe_size,
 	const int max_pipes)
 {
 	pid_t pid;
@@ -166,7 +91,7 @@ again:
 	} else if (pid > 0) {
 		int status, ret;
 
-		setpgid(pid, pgrp);
+		(void)setpgid(pid, pgrp);
 		stress_parent_died_alarm();
 
 		/* Patent, wait for child */
@@ -197,28 +122,24 @@ again:
 		int fds[max_pipes * 2], *fd, i, pipes_open = 0;
 		const bool aggressive = (opt_flags & OPT_FLAGS_AGGRESSIVE);
 
-		setpgid(0, pgrp);
+		(void)setpgid(0, pgrp);
 		set_oom_adjustment(name, true);
 
 		for (i = 0; i < max_pipes * 2; i++)
 			fds[i] = -1;
 
 		for (i = 0; i < max_pipes; i++) {
-			int *fd = fds + (2 * i);
-			if (pipe(fd) < 0) {
-				fd[0] = -1;
-				fd[1] = -1;
+			int *pfd = fds + (2 * i);
+			if (pipe(pfd) < 0) {
+				pfd[0] = -1;
+				pfd[1] = -1;
 			} else {
-				if (fcntl(fd[0], F_SETFL, O_NONBLOCK) < 0) {
-					pr_fail(stderr, "%s: fcntl O_NONBLOCK failed, "
-						"errno = %d (%s)\n",
-						name, errno, strerror(errno));
+				if (fcntl(pfd[0], F_SETFL, O_NONBLOCK) < 0) {
+					pr_fail_err(name, "fcntl O_NONBLOCK");
 					goto clean;
 				}
-				if (fcntl(fd[1], F_SETFL, O_NONBLOCK) < 0) {
-					pr_fail(stderr, "%s: fcntl O_NONBLOCK failed, "
-						"errno = %d (%s)\n",
-						name, errno, strerror(errno));
+				if (fcntl(pfd[1], F_SETFL, O_NONBLOCK) < 0) {
+					pr_fail_err(name, "fcntl O_NONBLOCK");
 					goto clean;
 				}
 				pipes_open++;
@@ -233,21 +154,25 @@ again:
 
 		do {
 			/* Set to maximum size */
-			for (i = 0, fd = fds; i < max_pipes * 2; i++, fd++) {
-				int max_size = max_pipe_size;
-				if (*fd < 0)
+			for (i = 0, fd = fds; i < max_pipes; i++, fd += 2) {
+				size_t max_size = max_pipe_size;
+
+				if ((fd[0] < 0) || (fd[1] < 0))
 					continue;
-				if (fcntl(*fd, F_SETPIPE_SZ, max_size) < 0)
+				if (fcntl(fd[0], F_SETPIPE_SZ, max_size) < 0)
+					max_size = page_size;
+				if (fcntl(fd[1], F_SETPIPE_SZ, max_size) < 0)
 					max_size = page_size;
 				pipe_fill(fd[1], max_size);
 				if (!aggressive)
 					pipe_empty(fd[0], max_size);
 			}
 			/* Set to minimum size */
-			for (i = 0, fd = fds; i < max_pipes * 2; i++, fd++) {
-				if (*fd < 0)
+			for (i = 0, fd = fds; i < max_pipes; i++, fd += 2) {
+				if ((fd[0] < 0) || (fd[1] < 0))
 					continue;
-				(void)fcntl(*fd, F_SETPIPE_SZ, page_size);
+				(void)fcntl(fd[0], F_SETPIPE_SZ, page_size);
+				(void)fcntl(fd[1], F_SETPIPE_SZ, page_size);
 				pipe_fill(fd[1], max_pipe_size);
 				if (!aggressive)
 					pipe_empty(fd[0], page_size);
@@ -279,14 +204,22 @@ int stress_oom_pipe(
 {
 	const size_t max_fd = stress_get_file_limit();
 	const size_t max_pipes = max_fd / 2;
-	int max_pipe_size;
+	size_t max_pipe_size;
 
 	page_size = stress_get_pagesize();
-	max_pipe_size = probe_max_pipe_size() & ~(page_size - 1);
+	max_pipe_size = stress_probe_max_pipe_size() & ~(page_size - 1);
 
 	return stress_oom_pipe_expander(
 		counter, instance, max_ops, name,
 		max_pipe_size, max_pipes);
 }
-
+#else
+int stress_oom_pipe(
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
+{
+	return stress_not_implemented(counter, instance, max_ops, name);
+}
 #endif
