@@ -22,16 +22,6 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <unistd.h>
-#include <fcntl.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-
 #include "stress-ng.h"
 
 typedef int (*open_func_t)(void);
@@ -156,12 +146,15 @@ int stress_open(
 	const char *name)
 {
 	int fds[STRESS_FD_MAX];
-	const size_t max_fd = stress_get_file_limit();
+	size_t max_fd = stress_get_file_limit();
 	size_t i;
 
 	(void)instance;
 	(void)name;
 
+	if (max_fd > SIZEOF_ARRAY(fds))
+		max_fd = SIZEOF_ARRAY(fds);
+
 	do {
 		for (i = 0; i < max_fd; i++) {
 			int idx = mwc32() % SIZEOF_ARRAY(open_funcs);
