@@ -22,15 +22,10 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
 #include "stress-ng.h"
 
-#if defined(STRESS_PERSONALITY)
+#if defined(__linux__)
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <unistd.h>
 #include <sys/personality.h>
 
 /* Personalities are determined at build time */
@@ -48,22 +43,22 @@ int stress_personality(
 	const uint64_t max_ops,
 	const char *name)
 {
-	const size_t n = SIZEOF_ARRAY(personalities);
+	const ssize_t n = SIZEOF_ARRAY(personalities);
 	bool failed[n];
 
 	(void)instance;
 
-	memset(failed, 0, sizeof(failed));
-
 	if (n == 0) {
 		pr_inf(stderr, "%s: no personalities to stress test\n", name);
-		return EXIT_FAILURE;
+		return EXIT_NOT_IMPLEMENTED;
 	}
+	memset(failed, 0, sizeof(failed));
+
 	if (instance == 0)
 		pr_dbg(stderr, "%s: exercising %zu personalities\n", name, n);
 
 	do {
-		size_t i, fails = 0;
+		ssize_t i, fails = 0;
 
 		for (i = 0; i < n; i++) {
 			unsigned long p = personalities[i];
@@ -94,9 +89,18 @@ int stress_personality(
 				"to be set\n", name, fails);
 			break;
 		}
+		(*counter)++;
 	} while (opt_do_run && (!max_ops || *counter < max_ops));
 
 	return EXIT_SUCCESS;
 }
-
+#else
+int stress_personality(
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
+{
+	return stress_not_implemented(counter, instance, max_ops, name);
+}
 #endif
