@@ -22,20 +22,10 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <unistd.h>
-#include <poll.h>
-#include <errno.h>
-#include <signal.h>
-#include <sys/types.h>
-#include <sys/wait.h>
-
 #include "stress-ng.h"
 
+#include <poll.h>
+
 #define MAX_PIPES	(5)
 #define POLL_BUF	(4)
 
@@ -88,7 +78,7 @@ int stress_poll(
 	int pipefds[MAX_PIPES][2];
 	int i;
 	pid_t pid;
-	int ret = EXIT_SUCCESS;
+	int rc = EXIT_SUCCESS;
 
 	(void)instance;
 
@@ -109,13 +99,13 @@ again:
 		if (opt_do_run && (errno == EAGAIN))
 			goto again;
 		pr_fail_dbg(name, "fork");
-		ret = EXIT_FAILURE;
+		rc = EXIT_FAILURE;
 		goto tidy;
 	}
 	else if (pid == 0) {
 		/* Child writer */
 
-		setpgid(0, pgrp);
+		(void)setpgid(0, pgrp);
 		stress_parent_died_alarm();
 
 		for (i = 0; i < MAX_PIPES; i++)
@@ -147,7 +137,7 @@ abort:
 		struct pollfd fds[MAX_PIPES];
 		fd_set rfds;
 
-		setpgid(pid, pgrp);
+		(void)setpgid(pid, pgrp);
 
 		FD_ZERO(&rfds);
 		for (i = 0; i < MAX_PIPES; i++) {
@@ -171,8 +161,7 @@ abort:
 			ret = poll(fds, MAX_PIPES, 1);
 			if ((opt_flags & OPT_FLAGS_VERIFY) &&
 			    (ret < 0) && (errno != EINTR)) {
-				pr_fail(stderr, "%s: poll failed with error: %d (%s)\n",
-					name, errno, strerror(errno));
+				pr_fail_err(name, "poll");
 			}
 			if (ret > 0) {
 				for (i = 0; i < MAX_PIPES; i++) {
@@ -192,8 +181,7 @@ abort:
 			ret = select(maxfd + 1, &rfds, NULL, NULL, &tv);
 			if ((opt_flags & OPT_FLAGS_VERIFY) &&
 			    (ret < 0) && (errno != EINTR)) {
-				pr_fail(stderr, "%s: select failed with error: %d (%s)\n",
-					name, errno, strerror(errno));
+				pr_fail_err(name, "select");
 			}
 			if (ret > 0) {
 				for (i = 0; i < MAX_PIPES; i++) {
@@ -225,5 +213,5 @@ tidy:
 		(void)close(pipefds[i][1]);
 	}
 
-	return ret;
+	return rc;
 }
