@@ -22,37 +22,25 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
-
-#if defined(STRESS_PTHREAD)
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <unistd.h>
-#include <sys/types.h>
-#include <sys/wait.h>
-#include <pthread.h>
-#include <errno.h>
-#include <signal.h>
+#if defined(HAVE_LIB_PTHREAD)
 #if defined(__linux__)
-/* For get_robust_list on Linux: */
-#include <syscall.h>
 #if defined(__NR_get_robust_list)
 #include <linux/futex.h>
-#include <sys/types.h>
 #endif
 #endif
 
+static pthread_cond_t cond;
+static pthread_mutex_t mutex;
+static pthread_spinlock_t spinlock;
+static bool thread_terminate;
+static uint64_t pthread_count;
+static sigset_t set;
+
+#endif
+
 static uint64_t opt_pthread_max = DEFAULT_PTHREAD;
 static bool set_pthread_max = false;
-static pthread_cond_t cond = PTHREAD_COND_INITIALIZER;
-static pthread_mutex_t mutex = PTHREAD_MUTEX_INITIALIZER;
-static bool thread_terminate;
-static uint64_t pthread_count;
-static sigset_t set;
 
 void stress_set_pthread_max(const char *optarg)
 {
@@ -72,6 +60,8 @@ void stress_adjust_pthread_max(uint64_t max)
 	}
 }
 
+#if defined(HAVE_LIB_PTHREAD)
+
 #if defined(__linux__) && defined(__NR_get_robust_list)
 static inline long sys_get_robust_list(int pid, struct robust_list_head **head_ptr, size_t *len_ptr)
 {
@@ -85,7 +75,7 @@ static inline long sys_get_robust_list(int pid, struct robust_list_head **head_p
  */
 static void *stress_pthread_func(void *ctxt)
 {
-	uint8_t stack[SIGSTKSZ];
+	uint8_t stack[SIGSTKSZ + STACK_ALIGNMENT];
 	stack_t ss;
 	static void *nowt = NULL;
 	int ret;
@@ -108,7 +98,7 @@ static void *stress_pthread_func(void *ctxt)
 	 *  However, we block signals in this thread
 	 *  so this is probably just totally unncessary.
 	 */
-	ss.ss_sp = (void *)stack;
+	ss.ss_sp = (void *)align_address(stack, STACK_ALIGNMENT);
 	ss.ss_size = SIGSTKSZ;
 	ss.ss_flags = 0;
 	if (sigaltstack(&ss, NULL) < 0) {
@@ -131,15 +121,15 @@ static void *stress_pthread_func(void *ctxt)
 	/*
 	 *  Bump count of running threads
 	 */
-	ret = pthread_mutex_lock(&mutex);
+	ret = pthread_spin_lock(&spinlock);
 	if (ret) {
-		pr_fail_errno("pthread", "mutex lock", ret);
+		pr_fail_errno("pthread", "spinlock lock", ret);
 		goto die;
 	}
 	pthread_count++;
-	ret = pthread_mutex_unlock(&mutex);
+	ret = pthread_spin_unlock(&spinlock);
 	if (ret) {
-		pr_fail_errno("pthread", "mutex unlock", ret);
+		pr_fail_errno("pthread", "spin unlock", ret);
 		goto die;
 	}
 
@@ -180,6 +170,7 @@ int stress_pthread(
 	pthread_t pthreads[MAX_PTHREAD];
 	bool ok = true;
 	uint64_t limited = 0, attempted = 0;
+	int ret;
 
 	if (!set_pthread_max) {
 		if (opt_flags & OPT_FLAGS_MAXIMIZE)
@@ -188,10 +179,25 @@ int stress_pthread(
 			opt_pthread_max = MIN_PTHREAD;
 	}
 
+	ret = pthread_cond_init(&cond, NULL);
+	if (ret) {
+		pr_fail_errno(name, "pthread_cond_init", ret);
+		return EXIT_FAILURE;
+	}
+	ret = pthread_spin_init(&spinlock, 0);
+	if (ret) {
+		pr_fail_errno(name, "pthread_spin_init", ret);
+		return EXIT_FAILURE;
+	}
+	ret = pthread_mutex_init(&mutex, NULL);
+	if (ret) {
+		pr_fail_errno(name, "pthread_mutx_init", ret);
+		return EXIT_FAILURE;
+	}
+
 	sigfillset(&set);
 	do {
 		uint64_t i, j;
-		int ret;
 
 		thread_terminate = false;
 		pthread_count = 0;
@@ -281,8 +287,17 @@ reap:
 
 	(void)pthread_cond_destroy(&cond);
 	(void)pthread_mutex_destroy(&mutex);
+	(void)pthread_spin_destroy(&spinlock);
 
 	return EXIT_SUCCESS;
 }
-
+#else
+int stress_pthread(
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
+{
+	return stress_not_implemented(counter, instance, max_ops, name);
+}
 #endif
