@@ -22,24 +22,10 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
+#if defined(__linux__)
 
-#if defined(STRESS_PTRACE)
-
-#include <stdio.h>
-#include <stdint.h>
-#include <stdbool.h>
-#include <stdlib.h>
-#include <string.h>
-#include <unistd.h>
-#include <errno.h>
-#include <signal.h>
-
-#include <sys/types.h>
 #include <sys/ptrace.h>
-#include <sys/wait.h>
 
 /*
  *  main syscall ptrace loop
@@ -56,7 +42,8 @@ static inline bool stress_syscall_wait(
 			return true;
 		}
 		if (waitpid(pid, &status, 0) < 0) {
-			pr_fail_dbg(name, "waitpid");
+			if (errno != EINTR)
+				pr_fail_dbg(name, "waitpid");
 			return true;
 		}
 
@@ -88,7 +75,7 @@ int stress_ptrace(
 		pr_fail_dbg(name, "fork");
 		return EXIT_FAILURE;
 	} else if (pid == 0) {
-		setpgid(0, pgrp);
+		(void)setpgid(0, pgrp);
 		stress_parent_died_alarm();
 
 		/*
@@ -121,11 +108,14 @@ int stress_ptrace(
 		/* Parent to do the tracing */
 		int status;
 
-		setpgid(pid, pgrp);
+		(void)setpgid(pid, pgrp);
 
 		if (waitpid(pid, &status, 0) < 0) {
-			pr_fail_dbg(name, "waitpid");
-			return EXIT_FAILURE;
+			if (errno != EINTR) {
+				pr_fail_dbg(name, "waitpid");
+				return EXIT_FAILURE;
+			}
+			return EXIT_SUCCESS;
 		}
 		if (ptrace(PTRACE_SETOPTIONS, pid,
 			0, PTRACE_O_TRACESYSGOOD) < 0) {
@@ -153,5 +143,13 @@ int stress_ptrace(
 	}
 	return EXIT_SUCCESS;
 }
-
+#else
+int stress_ptrace(
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
+{
+	return stress_not_implemented(counter, instance, max_ops, name);
+}
 #endif
