@@ -22,23 +22,14 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
 
-#include <stdio.h>
-#include <stdint.h>
-#include <unistd.h>
-#include <stdlib.h>
-#include <string.h>
-#include <inttypes.h>
-
-#if defined(STRESS_RDRAND)
-
-static bool rdrand_supported = false;
+#if defined(STRESS_X86) && !defined(__OpenBSD__) && NEED_GNUC(4,6,0)
 
 #include <cpuid.h>
 
+static bool rdrand_supported = false;
+
 /*
  *  stress_rdrand_supported()
  *	check if rdrand is supported
@@ -178,11 +169,6 @@ int stress_rdrand(
         const uint64_t max_ops,
         const char *name)
 {
-	(void)counter;
-	(void)instance;
-	(void)max_ops;
-	(void)name;
-
-	return EXIT_SUCCESS;
+	return stress_not_implemented(counter, instance, max_ops, name);
 }
 #endif
