@@ -22,21 +22,8 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
 
-#if defined(STRESS_READAHEAD)
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <unistd.h>
-#include <errno.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <fcntl.h>
-
 #define BUF_ALIGNMENT		(4096)
 #define BUF_SIZE		(512)
 #define MAX_OFFSETS		(16)
@@ -52,7 +39,9 @@ void stress_set_readahead_bytes(const char *optarg)
 		MIN_HDD_BYTES, MAX_HDD_BYTES);
 }
 
-int do_readahead(
+#if defined(__linux__) && NEED_GLIBC(2,3,0)
+
+static int do_readahead(
 	const char *name,
 	const int fd,
 	off_t *offsets,
@@ -134,7 +123,7 @@ int stress_readahead(
 
 	/* Sequential Write */
 	for (i = 0; i < opt_readahead_bytes; i += BUF_SIZE) {
-		ssize_t ret;
+		ssize_t pret;
 		size_t j;
 		off_t o = i / BUF_SIZE;
 seq_wr_retry:
@@ -148,8 +137,8 @@ seq_wr_retry:
 		for (j = 0; j < BUF_SIZE; j++)
 			buf[j] = (o + j) & 0xff;
 
-		ret = pwrite(fd, buf, BUF_SIZE, i);
-		if (ret <= 0) {
+		pret = pwrite(fd, buf, BUF_SIZE, i);
+		if (pret <= 0) {
 			if ((errno == EAGAIN) || (errno == EINTR))
 				goto seq_wr_retry;
 			if (errno == ENOSPC)
@@ -176,7 +165,7 @@ seq_wr_retry:
 
 		if (do_readahead(name, fd, offsets, readahead_bytes) < 0)
 			goto close_finish;
-				
+
 		for (i = 0; i < MAX_OFFSETS; i++) {
 rnd_rd_retry:
 			if (!opt_do_run || (max_ops && *counter >= max_ops))
@@ -226,5 +215,13 @@ finish:
 
 	return rc;
 }
-
+#else
+int stress_readahead(
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
+{
+	return stress_not_implemented(counter, instance, max_ops, name);
+}
 #endif
