@@ -22,19 +22,9 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
 
-#if defined(STRESS_REMAP_FILE_PAGES)
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <unistd.h>
-#include <errno.h>
-#include <string.h>
-#include <sys/mman.h>
+#if defined(__linux__) && NEED_GLIBC(2,3,0) && defined(__NR_remap_file_pages)
 
 #define N_PAGES		(512)
 
@@ -84,8 +74,7 @@ static int remap_order(
 		ret = remap_file_pages(data + (i * stride), page_size,
 			0, order[i], 0);
 		if (ret < 0) {
-			pr_fail(stderr, "%s: remap_file_pages: errno=%d (%s)\n",
-				name, errno, strerror(errno));
+			pr_fail_err(name, "remap_file_pages");
 			return -1;
 		}
 	}
@@ -169,5 +158,13 @@ int stress_remap(
 
 	return EXIT_SUCCESS;
 }
-
+#else
+int stress_remap(
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
+{
+	return stress_not_implemented(counter, instance, max_ops, name);
+}
 #endif
