@@ -22,22 +22,9 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
 
-#if defined(STRESS_RLIMIT)
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <stdbool.h>
-#include <setjmp.h>
-#include <string.h>
-#include <unistd.h>
-#include <signal.h>
-#include <sys/time.h>
-#include <sys/resource.h>
+#if defined(__linux__)
 
 static volatile bool do_jmp = true;
 static sigjmp_buf jmp_env;
@@ -125,5 +112,13 @@ int stress_rlimit(
 
 	return EXIT_SUCCESS;
 }
-
+#else
+int stress_rlimit(
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
+{
+	return stress_not_implemented(counter, instance, max_ops, name);
+}
 #endif
