@@ -22,41 +22,26 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
 
-#if defined(STRESS_SCTP)
+#if defined(HAVE_LIB_SCTP)
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <string.h>
-#include <stdbool.h>
-#include <signal.h>
-#include <unistd.h>
-#include <errno.h>
-
-#include <sys/types.h>
-#include <sys/socket.h>
-#include <sys/wait.h>
 #include <netinet/in.h>
 #include <netinet/sctp.h>
 #include <arpa/inet.h>
-#ifdef AF_INET6
+#if defined(AF_INET6)
 #include <netinet/in.h>
 #endif
-#ifdef AF_UNIX
+#if defined(AF_UNIX)
 #include <sys/un.h>
 #endif
-#if defined(__linux__)
-#include <sys/syscall.h>
-#endif
 
 #if !defined(LOCALTIME_STREAM)
 #define LOCALTIME_STREAM        0
 #endif
 
+#endif
+
 static int opt_sctp_domain = AF_INET;
 static int opt_sctp_port = DEFAULT_SCTP_PORT;
 
@@ -81,6 +66,8 @@ int stress_set_sctp_domain(const char *name)
 				     name, &opt_sctp_domain);
 }
 
+#if defined(HAVE_LIB_SCTP)
+
 /*
  *  stress_sctp_client()
  *	client reader
@@ -94,7 +81,7 @@ static void stress_sctp_client(
 {
 	struct sockaddr *addr;
 
-	setpgid(0, pgrp);
+	(void)setpgid(0, pgrp);
 	stress_parent_died_alarm();
 
 	do {
@@ -120,7 +107,7 @@ retry:
 			&addr, &addr_len, NET_ADDR_LOOPBACK);
 		if (connect(fd, addr, addr_len) < 0) {
 			(void)close(fd);
-			usleep(10000);
+			(void)shim_usleep(10000);
 			retries++;
 			if (retries > 100) {
 				/* Give up.. */
@@ -158,7 +145,7 @@ retry:
 		(void)close(fd);
 	} while (opt_do_run && (!max_ops || *counter < max_ops));
 
-#ifdef AF_UNIX
+#if defined(AF_UNIX)
 	if (opt_sctp_domain == AF_UNIX) {
 		struct sockaddr_un *addr_un = (struct sockaddr_un *)addr;
 		(void)unlink(addr_un->sun_path);
@@ -196,11 +183,11 @@ static int stress_sctp_server(
 	int fd, status;
 	int so_reuseaddr = 1;
 	socklen_t addr_len = 0;
-	struct sockaddr *addr;
+	struct sockaddr *addr = NULL;
 	uint64_t msgs = 0;
 	int rc = EXIT_SUCCESS;
 
-	setpgid(pid, pgrp);
+	(void)setpgid(pid, pgrp);
 
 	if (stress_sighandler(name, SIGALRM, handle_sctp_sigalrm, NULL) < 0) {
 		rc = EXIT_FAILURE;
@@ -269,8 +256,8 @@ static int stress_sctp_server(
 die_close:
 	(void)close(fd);
 die:
-#ifdef AF_UNIX
-	if (opt_sctp_domain == AF_UNIX) {
+#if defined(AF_UNIX)
+	if (addr && opt_sctp_domain == AF_UNIX) {
 		struct sockaddr_un *addr_un = (struct sockaddr_un *)addr;
 		(void)unlink(addr_un->sun_path);
 	}
@@ -313,5 +300,13 @@ again:
 		return stress_sctp_server(counter, instance, max_ops, name, pid, ppid);
 	}
 }
-
+#else
+int stress_sctp(
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
+{
+	return stress_not_implemented(counter, instance, max_ops, name);
+}
 #endif
