@@ -22,24 +22,11 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
 
-#if defined(STRESS_SECCOMP)
-
-#include <stdio.h>
-#include <stddef.h>
-#include <stdlib.h>
-#include <unistd.h>
-#include <string.h>
-#include <errno.h>
+#if defined(HAVE_SECCOMP_H) && defined(__linux__) && defined(PR_SET_SECCOMP)
 
 #include <sys/prctl.h>
-#include <sys/types.h>
-#include <sys/wait.h>
-#include <sys/syscall.h>
-
 #include <linux/audit.h>
 #include <linux/filter.h>
 #include <linux/seccomp.h>
@@ -104,13 +91,6 @@ static struct sock_fprog prog_random = {
 	.filter = filter_random
 };
 
-#if defined(__NR_seccomp)
-static int sys_seccomp(unsigned int operation, unsigned int flags, void *args)
-{
-	return (int)syscall(__NR_seccomp, operation, flags, args);
-}
-#endif
-
 /*
  *  stress_seccomp_set_filter()
  *	set up a seccomp filter, allow writes
@@ -143,8 +123,7 @@ static inline int stress_seccomp_set_filter(
 	}
 
 	if (prctl(PR_SET_NO_NEW_PRIVS, 1, 0, 0, 0) < 0) {
-		pr_fail(stderr, "%s: prctl PR_SET_NEW_PRIVS failed: %d (%s)\n",
-			name, errno, strerror(errno));
+		pr_fail_err(name, "prctl PR_SET_NEW_PRIVS");
 		return -1;
 	}
 #if defined(__NR_seccomp)
@@ -153,7 +132,7 @@ static inline int stress_seccomp_set_filter(
 	 */
 	if (use_seccomp) {
 redo_seccomp:
-		if (sys_seccomp(SECCOMP_SET_MODE_FILTER, 0, p) == 0)
+		if (shim_seccomp(SECCOMP_SET_MODE_FILTER, 0, p) == 0)
 			return 0;
 
 		if (errno != ENOSYS) {
@@ -162,9 +141,7 @@ redo_seccomp:
 				p = &prog;
 				goto redo_seccomp;
 			}
-			pr_fail(stderr, "%s: seccomp SECCOMP_SET_MODE_FILTER "
-				"failed: %d (%s)\n",
-				name, errno, strerror(errno));
+			pr_fail_err(name, "seccomp SECCOMP_SET_MODE_FILTER");
 			return -1;
 		}
 		use_seccomp = false;
@@ -178,8 +155,7 @@ redo_prctl:
 			p = &prog;
 			goto redo_prctl;
 		}
-		pr_fail(stderr, "%s: prctl PR_SET_SECCOMP failed: %d (%s)\n",
-			name, errno, strerror(errno));
+		pr_fail_err(name, "prctl PR_SET_SECCOMP");
 		return -1;
 	}
 	return 0;
@@ -205,8 +181,7 @@ int stress_seccomp(
 
 		pid = fork();
 		if (pid == -1) {
-			pr_fail(stderr, "%s: fork failed: %d (%s)\n",
-				name, errno, strerror(errno));
+			pr_fail_err(name, "fork");
 			break;
 		}
 		if (pid == 0) {
@@ -275,5 +250,13 @@ int stress_seccomp(
 
 	return EXIT_SUCCESS;
 }
-
+#else
+int stress_seccomp(
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
+{
+	return stress_not_implemented(counter, instance, max_ops, name);
+}
 #endif
