@@ -22,33 +22,22 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
 
-#if defined(STRESS_SEMAPHORE_SYSV)
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <unistd.h>
-#include <errno.h>
-#include <signal.h>
-#include <time.h>
-#include <sys/types.h>
-#include <sys/wait.h>
+#if defined(__linux__)
 #include <sys/ipc.h>
 #include <sys/sem.h>
 
-static uint64_t opt_semaphore_sysv_procs = DEFAULT_SEMAPHORE_PROCS;
-static bool set_semaphore_sysv_procs = false;
-
 typedef union _semun {
 	int              val;	/* Value for SETVAL */
 	struct semid_ds *buf;	/* Buffer for IPC_STAT, IPC_SET */
 	unsigned short  *array;	/* Array for GETALL, SETALL */
 	struct seminfo  *__buf;	/* Buffer for IPC_INFO (Linux-specific) */
 } semun_t;
+#endif
+
+static uint64_t opt_semaphore_sysv_procs = DEFAULT_SEMAPHORE_PROCS;
+static bool set_semaphore_sysv_procs = false;
 
 void stress_set_semaphore_sysv_procs(const char *optarg)
 {
@@ -58,6 +47,8 @@ void stress_set_semaphore_sysv_procs(const char *optarg)
 		MIN_SEMAPHORE_PROCS, MAX_SEMAPHORE_PROCS);
 }
 
+#if defined(__linux__)
+
 /*
  *  stress_semaphore_sysv_init()
  *	initialise a System V semaphore
@@ -90,12 +81,12 @@ void stress_semaphore_sysv_init(void)
 	}
 
 	if (opt_sequential) {
-		pr_inf(stderr, "Semaphore init failed: errno=%d: (%s), "
-			"skipping semaphore stressor\n",
+		pr_inf(stderr, "semaphore init (System V) failed: errno=%d: "
+			"(%s), skipping semaphore stressor\n",
 			errno, strerror(errno));
 	} else {
-		pr_err(stderr, "Semaphore init failed: errno=%d: (%s)\n",
-			errno, strerror(errno));
+		pr_err(stderr, "semaphore init (System V) failed: errno=%d: "
+			"(%s)\n", errno, strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 }
@@ -119,6 +110,8 @@ static void semaphore_sysv_thrash(
 	const uint64_t max_ops,
 	uint64_t *counter)
 {
+	const int sem_id = shared->sem_sysv.sem_id;
+
 	do {
 		int i;
 		struct timespec timeout;
@@ -140,7 +133,7 @@ static void semaphore_sysv_thrash(
 			semsignal.sem_op = 1;
 			semsignal.sem_flg = SEM_UNDO;
 
-			if (semtimedop(shared->sem_sysv.sem_id, &semwait, 1, &timeout) < 0) {
+			if (semtimedop(sem_id, &semwait, 1, &timeout) < 0) {
 				if (errno == EAGAIN) {
 					pr_inf(stderr, "Semaphore timed out: errno=%d (%s)\n",
 						errno, strerror(errno));
@@ -151,7 +144,7 @@ static void semaphore_sysv_thrash(
 				break;
 			}
 			(*counter)++;
-			if (semop(shared->sem_sysv.sem_id, &semsignal, 1) < 0) {
+			if (semop(sem_id, &semsignal, 1) < 0) {
 				if (errno != EINTR)
 					pr_fail_dbg(name, "semop signal");
 				break;
@@ -160,6 +153,62 @@ timed_out:
 			if (!opt_do_run)
 				break;
 		}
+#if defined(IPC_STAT)
+		{
+			struct semid_ds ds;
+			semun_t s;
+
+			s.buf = &ds;
+			if (semctl(sem_id, 0, IPC_STAT, &s) < 0)
+				pr_fail_dbg(name, "semctl IPC_STAT");
+		}
+#endif
+#if defined(SEM_STAT)
+		{
+			struct semid_ds ds;
+			semun_t s;
+
+			s.buf = &ds;
+			if (semctl(sem_id, 0, SEM_STAT, &s) < 0)
+				pr_fail_dbg(name, "semctl SEM_STAT");
+		}
+#endif
+#if defined(IPC_INFO)
+		{
+			struct seminfo si;
+			semun_t s;
+
+			s.__buf = &si;
+			if (semctl(sem_id, 0, IPC_INFO, &s) < 0)
+				pr_fail_dbg(name, "semctl IPC_INFO");
+		}
+#endif
+#if defined(SEM_INFO)
+		{
+			struct seminfo si;
+			semun_t s;
+
+			s.__buf = &si;
+			if (semctl(sem_id, 0, SEM_INFO, &s) < 0)
+				pr_fail_dbg(name, "semctl SEM_INFO");
+		}
+#endif
+#if defined(GETVAL)
+		if (semctl(sem_id, 0, GETVAL) < 0)
+			pr_fail_dbg(name, "semctl GETVAL");
+#endif
+#if defined(GETPID)
+		if (semctl(sem_id, 0, GETPID) < 0)
+			pr_fail_dbg(name, "semctl GETPID");
+#endif
+#if defined(GETNCNT)
+		if (semctl(sem_id, 0, GETNCNT) < 0)
+			pr_fail_dbg(name, "semctl GETNCNT");
+#endif
+#if defined(GEZCNT)
+		if (semctl(sem_id, 0, GETZCNT) < 0)
+			pr_fail_dbg(name, "semctl GETZCNT");
+#endif
 	} while (opt_do_run && (!max_ops || *counter < max_ops));
 }
 
@@ -182,13 +231,13 @@ again:
 		return -1;
 	}
 	if (pid == 0) {
-		setpgid(0, pgrp);
+		(void)setpgid(0, pgrp);
 		stress_parent_died_alarm();
 
 		semaphore_sysv_thrash(name, max_ops, counter);
 		exit(EXIT_SUCCESS);
 	}
-	setpgid(pid, pgrp);
+	(void)setpgid(pid, pgrp);
 	return pid;
 }
 
@@ -227,7 +276,7 @@ int stress_sem_sysv(
 	}
 	/* Wait for termination */
 	while (opt_do_run && (!max_ops || *counter < max_ops))
-		usleep(100000);
+		(void)shim_usleep(100000);
 reap:
 	for (i = 0; i < opt_semaphore_sysv_procs; i++) {
 		if (pids[i] > 0)
@@ -243,5 +292,21 @@ reap:
 
 	return EXIT_SUCCESS;
 }
+#else
+void stress_semaphore_sysv_init(void)
+{
+}
 
+void stress_semaphore_sysv_destroy(void)
+{
+}
+
+int stress_sem_sysv(
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
+{
+	return stress_not_implemented(counter, instance, max_ops, name);
+}
 #endif
