@@ -22,22 +22,11 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
 
-#if defined(STRESS_SEMAPHORE_POSIX)
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <unistd.h>
-#include <errno.h>
+#if defined(HAVE_LIB_PTHREAD) && defined(__linux__)
 #include <semaphore.h>
-#include <signal.h>
-#include <time.h>
-#include <sys/types.h>
-#include <sys/wait.h>
+#endif
 
 static uint64_t opt_semaphore_posix_procs = DEFAULT_SEMAPHORE_PROCS;
 static bool set_semaphore_posix_procs = false;
@@ -50,6 +39,8 @@ void stress_set_semaphore_posix_procs(const char *optarg)
 		MIN_SEMAPHORE_PROCS, MAX_SEMAPHORE_PROCS);
 }
 
+#if defined(HAVE_LIB_PTHREAD) && defined(__linux__)
+
 /*
  *  stress_semaphore_posix_init()
  *	initialize a POSIX semaphore
@@ -144,13 +135,13 @@ again:
 		return -1;
 	}
 	if (pid == 0) {
-		setpgid(0, pgrp);
+		(void)setpgid(0, pgrp);
 		stress_parent_died_alarm();
 
 		semaphore_posix_thrash(name, max_ops, counter);
 		exit(EXIT_SUCCESS);
 	}
-	setpgid(pid, pgrp);
+	(void)setpgid(pid, pgrp);
 	return pid;
 }
 
@@ -190,7 +181,7 @@ int stress_sem(
 
 	/* Wait for termination */
 	while (opt_do_run && (!max_ops || *counter < max_ops))
-		usleep(100000);
+		(void)shim_usleep(100000);
 reap:
 	for (i = 0; i < opt_semaphore_posix_procs; i++) {
 		if (pids[i] > 0)
@@ -206,5 +197,21 @@ reap:
 
 	return EXIT_SUCCESS;
 }
+#else
+void stress_semaphore_posix_init(void)
+{
+}
 
+void stress_semaphore_posix_destroy(void)
+{
+}
+
+int stress_sem(
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
+{
+	return stress_not_implemented(counter, instance, max_ops, name);
+}
 #endif
