@@ -22,22 +22,11 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
 
-#if defined(STRESS_SENDFILE)
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <inttypes.h>
-#include <unistd.h>
-#include <fcntl.h>
-#include <sys/types.h>
-#include <sys/stat.h>
+#if defined(__linux__) && NEED_GLIBC(2,1,0)
 #include <sys/sendfile.h>
-
+#endif
 
 static int64_t opt_sendfile_size = DEFAULT_SENDFILE_SIZE;
 static bool set_sendfile_size = false;
@@ -50,6 +39,8 @@ void stress_set_sendfile_size(const char *optarg)
 		MIN_SENDFILE_SIZE, MAX_SENDFILE_SIZE);
 }
 
+#if defined(__linux__) && NEED_GLIBC(2,1,0)
+
 /*
  *  stress_sendfile
  *	stress reading of a temp file and writing to /dev/null via sendfile
@@ -121,4 +112,13 @@ dir_out:
 
 	return rc;
 }
+#else
+int stress_sendfile(
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
+{
+	return stress_not_implemented(counter, instance, max_ops, name);
+}
 #endif
