@@ -22,24 +22,10 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
+#include "stress-ng.h"
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <string.h>
-#include <stdbool.h>
-#include <unistd.h>
-#include <errno.h>
-#include <sys/types.h>
-#include <sys/stat.h>
 #include <sys/ipc.h>
 #include <sys/shm.h>
-#include <sys/wait.h>
-#include <fcntl.h>
-#include <signal.h>
-
-#include "stress-ng.h"
 
 #define KEY_GET_RETRIES		(40)
 
@@ -246,8 +232,7 @@ static int stress_shm_sysv_child(
 			}
 			if (shm_id < 0) {
 				ok = false;
-				pr_fail(stderr, "%s: shmget failed: errno=%d (%s)\n",
-					name, errno, strerror(errno));
+				pr_fail_err(name, "shmget");
 				rc = EXIT_FAILURE;
 				goto reap;
 			}
@@ -265,8 +250,7 @@ static int stress_shm_sysv_child(
 			addr = shmat(shm_id, NULL, 0);
 			if (addr == (char *) -1) {
 				ok = false;
-				pr_fail(stderr, "%s: shmat failed: errno=%d (%s)\n",
-					name, errno, strerror(errno));
+				pr_fail_err(name, "shmat");
 				rc = EXIT_FAILURE;
 				goto reap;
 			}
@@ -277,9 +261,7 @@ static int stress_shm_sysv_child(
 			if (!opt_do_run)
 				goto reap;
 			(void)mincore_touch_pages(addr, sz);
-#if !defined(__gnu_hurd__) && !defined(__minix__)
-			(void)msync(addr, sz, (mwc32() & 1) ? MS_ASYNC : MS_SYNC);
-#endif
+			(void)shim_msync(addr, sz, (mwc32() & 1) ? MS_ASYNC : MS_SYNC);
 
 			if (!opt_do_run)
 				goto reap;
@@ -323,15 +305,13 @@ reap:
 		for (i = 0; i < opt_shm_sysv_segments; i++) {
 			if (addrs[i]) {
 				if (shmdt(addrs[i]) < 0) {
-					pr_fail(stderr, "%s: shmdt failed: errno=%d (%s)\n",
-						name, errno, strerror(errno));
+					pr_fail_err(name, "shmdt");
 				}
 			}
 			if (shm_ids[i] >= 0) {
 				if (shmctl(shm_ids[i], IPC_RMID, NULL) < 0) {
 					if (errno != EIDRM)
-						pr_fail(stderr, "%s: shmctl failed: errno=%d (%s)\n",
-							name, errno, strerror(errno));
+						pr_fail_err(name, "shmctl");
 				}
 			}
 
@@ -417,7 +397,7 @@ fork_again:
 			/* Parent */
 			int status, shm_ids[MAX_SHM_SYSV_SEGMENTS];
 
-			setpgid(pid, pgrp);
+			(void)setpgid(pid, pgrp);
 			set_oom_adjustment(name, false);
 			(void)close(pipefds[1]);
 
@@ -432,7 +412,7 @@ fork_again:
 				 *  Blocking read on child shm ID info
 				 *  pipe.  We break out if pipe breaks
 				 *  on child death, or child tells us
-				 *  off its demise.
+				 *  about its demise.
 				 */
 				n = read(pipefds[0], &msg, sizeof(msg));
 				if (n <= 0) {
@@ -478,7 +458,7 @@ fork_again:
 			}
 		} else if (pid == 0) {
 			/* Child, stress memory */
-			setpgid(0, pgrp);
+			(void)setpgid(0, pgrp);
 			stress_parent_died_alarm();
 
 			/*
