@@ -22,25 +22,8 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
 
-#if defined(STRESS_SHM_POSIX)
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <string.h>
-#include <stdbool.h>
-#include <unistd.h>
-#include <errno.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <sys/wait.h>
-#include <fcntl.h>
-#include <signal.h>
-
 #define SHM_NAME_LEN	128
 
 typedef struct {
@@ -63,12 +46,14 @@ void stress_set_shm_posix_bytes(const char *optarg)
 
 void stress_set_shm_posix_objects(const char *optarg)
 {
-	opt_shm_posix_objects = true;
+	set_shm_posix_objects = true;
 	opt_shm_posix_objects = (size_t)get_uint64_byte(optarg);
 	check_range("shm-segments", opt_shm_posix_objects,
 		MIN_SHM_POSIX_OBJECTS, MAX_SHM_POSIX_OBJECTS);
 }
 
+#if defined(HAVE_LIB_RT)
+
 /*
  *  stress_shm_posix_check()
  *	simple check if shared memory is sane
@@ -137,15 +122,14 @@ static int stress_shm_posix_child(
 				goto reap;
 
 			snprintf(shm_name, SHM_NAME_LEN,
-				"/stress-ng-%u-%" PRIx64 "-%" PRIx32,
-					pid, id, mwc32());
+				"/stress-ng-%d-%" PRIx64 "-%" PRIx32,
+					(int)pid, id, mwc32());
 
 			shm_fd = shm_open(shm_name, O_CREAT | O_RDWR | O_TRUNC,
 				S_IRUSR | S_IWUSR);
 			if (shm_fd < 0) {
 				ok = false;
-				pr_fail(stderr, "%s: shm_open failed: errno=%d (%s)\n",
-					name, errno, strerror(errno));
+				pr_fail_err(name, "shm_open");
 				rc = EXIT_FAILURE;
 				goto reap;
 			}
@@ -166,22 +150,31 @@ static int stress_shm_posix_child(
 				MAP_SHARED | MAP_ANONYMOUS, shm_fd, 0);
 			if (addr == MAP_FAILED) {
 				ok = false;
-				pr_fail(stderr, "%s: mmap failed, giving up: errno=%d (%s)\n",
-					name, errno, strerror(errno));
+				pr_fail_err(name, "mmap");
 				rc = EXIT_FAILURE;
 				(void)close(shm_fd);
 				goto reap;
 			}
 			addrs[i] = addr;
-			(void)close(shm_fd);
 
-			if (!opt_do_run)
+			if (!opt_do_run) {
+				(void)close(shm_fd);
 				goto reap;
+			}
 			(void)mincore_touch_pages(addr, sz);
 
-			if (!opt_do_run)
+			if (!opt_do_run) {
+				(void)close(shm_fd);
 				goto reap;
+			}
 			(void)madvise_random(addr, sz);
+			(void)shim_msync(addr, sz, (mwc32() & 1) ? MS_ASYNC : MS_SYNC);
+			(void)fsync(shm_fd);
+
+			/* Expand and shrink the mapping */
+			(void)shim_fallocate(shm_fd, 0, 0, sz + page_size);
+			(void)shim_fallocate(shm_fd, 0, 0, sz);
+			(void)close(shm_fd);
 
 			if (!opt_do_run)
 				goto reap;
@@ -202,9 +195,7 @@ reap:
 				(void)munmap(addrs[i], sz);
 			if (*shm_name) {
 				if (shm_unlink(shm_name) < 0) {
-					pr_fail(stderr, "%s: shm_unlink "
-						"failed: errno=%d (%s)\n",
-						name, errno, strerror(errno));
+					pr_fail_err(name, "shm_unlink");
 				}
 			}
 
@@ -235,10 +226,10 @@ reap:
 }
 
 /*
- *  stress_shm_posix()
+ *  stress_shm()
  *	stress SYSTEM V shared memory
  */
-int stress_shm_posix(
+int stress_shm(
 	uint64_t *const counter,
 	const uint32_t instance,
 	const uint64_t max_ops,
@@ -290,7 +281,7 @@ fork_again:
 			int status;
 			char shm_names[MAX_SHM_POSIX_OBJECTS][SHM_NAME_LEN];
 
-			setpgid(pid, pgrp);
+			(void)setpgid(pid, pgrp);
 			(void)close(pipefds[1]);
 
 			memset(shm_names, 0, sizeof(shm_names));
@@ -304,7 +295,7 @@ fork_again:
 				 *  Blocking read on child shm ID info
 				 *  pipe.  We break out if pipe breaks
 				 *  on child death, or child tells us
-				 *  off its demise.
+				 *  about its demise.
 				 */
 				n = read(pipefds[0], &msg, sizeof(msg));
 				if (n <= 0) {
@@ -332,6 +323,7 @@ fork_again:
 			if (WIFSIGNALED(status)) {
 				if ((WTERMSIG(status) == SIGKILL) ||
 				    (WTERMSIG(status) == SIGKILL)) {
+					log_system_mem_info();
 					pr_dbg(stderr, "%s: assuming killed by OOM killer, "
 						"restarting again (instance %d)\n",
 						name, instance);
@@ -354,7 +346,7 @@ fork_again:
 			}
 		} else if (pid == 0) {
 			/* Child, stress memory */
-			setpgid(0, pgrp);
+			(void)setpgid(0, pgrp);
 			stress_parent_died_alarm();
 
 			(void)close(pipefds[0]);
@@ -373,5 +365,13 @@ fork_again:
 	}
 	return rc;
 }
-
+#else
+int stress_shm(
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
+{
+	return stress_not_implemented(counter, instance, max_ops, name);
+}
 #endif
