@@ -22,18 +22,8 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <string.h>
-#include <unistd.h>
-#include <signal.h>
-#include <sys/wait.h>
-
 #define CACHE_STRIDE_SHIFT	(6)
 
 /*
@@ -78,7 +68,7 @@ again:
 			pr_fail_dbg(name, "fork");
 			goto reap;
 		} else if (pid[n] == 0) {
-			setpgid(0, pgrp);
+			(void)setpgid(0, pgrp);
 			stress_parent_died_alarm();
 
 			while (opt_do_run) {
@@ -87,7 +77,7 @@ again:
 			}
 			_exit(0);
 		}
-		setpgid(pid[n], pgrp);
+		(void)setpgid(pid[n], pgrp);
 	}
 
 	/* Parent */
