@@ -22,32 +22,19 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
 
-#if defined(STRESS_SOCKET_FD)
+#if defined(__linux__)
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <string.h>
-#include <stdbool.h>
-#include <signal.h>
-#include <unistd.h>
-#include <errno.h>
-
-#include <sys/types.h>
-#include <sys/socket.h>
-#include <sys/wait.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
 #include <sys/un.h>
 
-
 #define MSG_ID			'M'
 #define MAX_FDS			(65536)
 
+#endif
+
 static int opt_socket_fd_port = DEFAULT_SOCKET_FD_PORT;
 
 /*
@@ -61,6 +48,8 @@ void stress_set_socket_fd_port(const char *optarg)
 		&opt_socket_fd_port);
 }
 
+#if defined(__linux__)
+
 /*
  *  stress_socket_fd_send()
  *	send a fd (fd_send) over a socket fd
@@ -152,7 +141,7 @@ static void stress_socket_client(
 {
 	struct sockaddr *addr;
 
-	setpgid(0, pgrp);
+	(void)setpgid(0, pgrp);
 	stress_parent_died_alarm();
 
 	do {
@@ -176,7 +165,7 @@ retry:
 			&addr, &addr_len, NET_ADDR_ANY);
 		if (connect(fd, addr, addr_len) < 0) {
 			(void)close(fd);
-			usleep(10000);
+			(void)shim_usleep(10000);
 			retries++;
 			if (retries > 100) {
 				/* Give up.. */
@@ -237,7 +226,7 @@ static int stress_socket_server(
 	uint64_t msgs = 0;
 	int rc = EXIT_SUCCESS;
 
-	setpgid(pid, pgrp);
+	(void)setpgid(pid, pgrp);
 
 	if (stress_sighandler(name, SIGALRM, handle_socket_sigalrm, NULL) < 0) {
 		rc = EXIT_FAILURE;
@@ -333,5 +322,13 @@ again:
 		return stress_socket_server(counter, instance, max_ops, name, pid, ppid, max_fd);
 	}
 }
-
+#else
+int stress_sockfd(
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
+{
+	return stress_not_implemented(counter, instance, max_ops, name);
+}
 #endif
