@@ -22,40 +22,23 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
+#include "stress-ng.h"
 
 #if defined(__linux__)
 #define SOCKET_NODELAY
 #endif
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <string.h>
-#include <stdbool.h>
-#include <signal.h>
-#include <unistd.h>
-#include <errno.h>
-
 #if defined(SOCKET_NODELAY)
 #include <netinet/tcp.h>
 #endif
-#include <sys/types.h>
-#include <sys/socket.h>
-#include <sys/wait.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
-#ifdef AF_INET6
+#if defined(AF_INET6)
 #include <netinet/in.h>
 #endif
-#ifdef AF_UNIX
+#if defined(AF_UNIX)
 #include <sys/un.h>
 #endif
-#if defined(__linux__)
-#include <sys/syscall.h>
-#endif
-
-#include "stress-ng.h"
 
 #if defined(__linux__) && defined(__NR_sendmmsg) && NEED_GLIBC(2,14,0)
 #define HAVE_SENDMMSG
@@ -181,7 +164,7 @@ static void stress_sctp_client(
 {
 	struct sockaddr *addr;
 
-	setpgid(0, pgrp);
+	(void)setpgid(0, pgrp);
 	stress_parent_died_alarm();
 
 	do {
@@ -206,7 +189,7 @@ retry:
 			&addr, &addr_len, NET_ADDR_ANY);
 		if (connect(fd, addr, addr_len) < 0) {
 			(void)close(fd);
-			usleep(10000);
+			(void)shim_usleep(10000);
 			retries++;
 			if (retries > 100) {
 				/* Give up.. */
@@ -231,7 +214,7 @@ retry:
 		(void)close(fd);
 	} while (opt_do_run && (!max_ops || *counter < max_ops));
 
-#ifdef AF_UNIX
+#if defined(AF_UNIX)
 	if (opt_socket_domain == AF_UNIX) {
 		struct sockaddr_un *addr_un = (struct sockaddr_un *)addr;
 		(void)unlink(addr_un->sun_path);
@@ -273,7 +256,7 @@ static int stress_sctp_server(
 	uint64_t msgs = 0;
 	int rc = EXIT_SUCCESS;
 
-	setpgid(pid, pgrp);
+	(void)setpgid(pid, pgrp);
 
 	if (stress_sighandler(name, SIGALRM, handle_socket_sigalrm, NULL) < 0) {
 		rc = EXIT_FAILURE;
@@ -309,7 +292,7 @@ static int stress_sctp_server(
 		int sfd = accept(fd, (struct sockaddr *)NULL, NULL);
 		if (sfd >= 0) {
 			size_t i, j;
-			struct sockaddr addr;
+			struct sockaddr saddr;
 			socklen_t len;
 			int sndbuf;
 			struct msghdr msg;
@@ -321,8 +304,8 @@ static int stress_sctp_server(
 #if defined(SOCKET_NODELAY)
 			int one = 1;
 #endif
-			len = sizeof(addr);
-			if (getsockname(fd, &addr, &len) < 0) {
+			len = sizeof(saddr);
+			if (getsockname(fd, &saddr, &len) < 0) {
 				pr_fail_dbg(name, "getsockname");
 				(void)close(sfd);
 				break;
@@ -340,8 +323,8 @@ static int stress_sctp_server(
 					pr_inf(stderr, "%s: setsockopt TCP_NODELAY "
 						"failed and disabled, errno=%d (%s)\n",
 						name, errno, strerror(errno));
-						opt_flags &= ~OPT_FLAGS_SOCKET_NODELAY;
-					}
+					opt_flags &= ~OPT_FLAGS_SOCKET_NODELAY;
+				}
 			}
 #endif
 			memset(buf, 'A' + (*counter % 26), sizeof(buf));
@@ -396,7 +379,7 @@ static int stress_sctp_server(
 				(void)close(sfd);
 				goto die_close;
 			}
-			if (getpeername(sfd, &addr, &len) < 0) {
+			if (getpeername(sfd, &saddr, &len) < 0) {
 				pr_fail_dbg(name, "getpeername");
 			}
 			(void)close(sfd);
@@ -407,7 +390,7 @@ static int stress_sctp_server(
 die_close:
 	(void)close(fd);
 die:
-#ifdef AF_UNIX
+#if defined(AF_UNIX)
 	if (opt_socket_domain == AF_UNIX) {
 		struct sockaddr_un *addr_un = (struct sockaddr_un *)addr;
 		(void)unlink(addr_un->sun_path);
@@ -435,7 +418,7 @@ int stress_sock(
 	pid_t pid, ppid = getppid();
 
 	pr_dbg(stderr, "%s: process [%d] using socket port %d\n",
-		name, getpid(), opt_socket_port + instance);
+		name, (int)getpid(), opt_socket_port + instance);
 
 again:
 	pid = fork();
