@@ -22,21 +22,6 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <setjmp.h>
-#include <string.h>
-#include <unistd.h>
-#include <signal.h>
-#include <errno.h>
-#include <sys/types.h>
-#include <sys/wait.h>
-#if defined(__sun__)
-#include <alloca.h>
-#endif
-
 #include "stress-ng.h"
 
 static sigjmp_buf jmp_env;
@@ -64,7 +49,7 @@ int stress_stack(
 	const char *name)
 {
 #if !defined(__minix__)
-	uint8_t stack[SIGSTKSZ] ALIGN64;
+	uint8_t stack[SIGSTKSZ + STACK_ALIGNMENT];
 	stack_t ss;
 #endif
 	pid_t pid;
@@ -78,7 +63,7 @@ int stress_stack(
 	 *  stack
 	 */
 	memset(stack, 0, sizeof(stack));
-	ss.ss_sp = (void *)stack;
+	ss.ss_sp = (void *)align_address(stack, STACK_ALIGNMENT);
 	ss.ss_size = SIGSTKSZ;
 	ss.ss_flags = 0;
 	if (sigaltstack(&ss, NULL) < 0) {
@@ -98,7 +83,7 @@ again:
 		int status, ret;
 
 		/* Parent, wait for child */
-		setpgid(pid, pgrp);
+		(void)setpgid(pid, pgrp);
 		ret = waitpid(pid, &status, 0);
 		if (ret < 0) {
 			if (errno != EINTR)
@@ -123,7 +108,7 @@ again:
 	} else if (pid == 0) {
 		char *start_ptr = sbrk(0);
 
-		setpgid(0, pgrp);
+		(void)setpgid(0, pgrp);
 		stress_parent_died_alarm();
 
 		if (start_ptr == (void *) -1) {
