@@ -27,19 +27,12 @@
  *   https://www.cs.virginia.edu/stream/FTP/Code/stream.c
  *
  * This is loosely based on a variant of the STREAM benchmark code,
- * so DO NOT submit results based on this as it is intended to 
+ * so DO NOT submit results based on this as it is intended to
  * stress memory and compute and NOT intended for STREAM accurate
- * tuned or non-tuned benchmarking whatsoever.  I believe this 
+ * tuned or non-tuned benchmarking whatsoever.  I believe this
  * conforms to section 3a, 3b of the original License.
  *
  */
-#define _GNU_SOURCE
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <sys/mman.h>
-
 #include "stress-ng.h"
 
 static uint64_t opt_stream_L3_size = DEFAULT_STREAM_L3_SIZE;
@@ -135,7 +128,7 @@ static inline uint64_t stream_L3_size(
 {
 	uint64_t cache_size = MEM_CACHE_SIZE;
 #if defined(__linux__)
-	cpus_t *cpu_caches = NULL;
+	cpus_t *cpu_caches;
 	cpu_cache_t *cache = NULL;
 	uint16_t max_cache_level;
 
