@@ -22,17 +22,6 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <unistd.h>
-#include <signal.h>
-#include <fcntl.h>
-#include <sys/types.h>
-#include <sys/wait.h>
-
 #include "stress-ng.h"
 
 #define SWITCH_STOP	'X'
@@ -92,7 +81,7 @@ again:
 	} else if (pid == 0) {
 		char buf[buf_size];
 
-		setpgid(0, pgrp);
+		(void)setpgid(0, pgrp);
 		stress_parent_died_alarm();
 
 		(void)close(pipefds[1]);
@@ -119,7 +108,7 @@ again:
 		int status;
 
 		/* Parent */
-		setpgid(pid, pgrp);
+		(void)setpgid(pid, pgrp);
 		(void)close(pipefds[0]);
 
 		memset(buf, '_', buf_size);
