@@ -22,22 +22,9 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
 
-#if defined(STRESS_SYSFS)
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdbool.h>
-#include <unistd.h>
-#include <fcntl.h>
-#include <dirent.h>
-#include <sys/stat.h>
-#include <sys/types.h>
-#include <pthread.h>
-#include <signal.h>
+#if defined(HAVE_LIB_PTHREAD) && defined(__linux__)
 
 #define SYS_BUF_SZ		(4096)
 #define MAX_READ_THREADS	(4)
@@ -52,10 +39,10 @@ typedef struct ctxt {
 } ctxt_t;
 
 /*
- *  stress_sys_read()
+ *  stress_sys_rw()
  *	read a proc file
  */
-static inline void stress_sys_read(
+static inline void stress_sys_rw(
 	const char *name,
 	const char *path,
 	char *badbuf)
@@ -72,15 +59,11 @@ static inline void stress_sys_read(
 	 */
 	while (i < (4096 * SYS_BUF_SZ)) {
 		ssize_t sz = 1 + (mwc32() % sizeof(buffer));
-redo:
 		if (!opt_do_run)
 			break;
 		ret = read(fd, buffer, sz);
-		if (ret < 0) {
-			if ((errno == EAGAIN) || (errno == EINTR))
-				goto redo;
+		if (ret < 0)
 			break;
-		}
 		if (ret < sz)
 			break;
 		i += sz;
@@ -91,9 +74,7 @@ redo:
 		struct stat buf;
 
 		if (fstat(fd, &buf) < 0) {
-			pr_fail(stderr, "%s: stat failed on %s: "
-				"errno=%d (%s)\n",
-				name, path, errno, strerror(errno));
+			pr_fail_err(name, "stat");
 		} else {
 			if ((buf.st_mode & S_IROTH) == 0) {
 				pr_fail(stderr, "%s: read access failed on %s which "
@@ -109,36 +90,40 @@ redo:
 	/*
 	 *  Zero sized reads
 	 */
-redo_zero:
 	ret = read(fd, buffer, 0);
-	if (ret < 0) {
-		if ((errno == EAGAIN) || (errno == EINTR))
-			goto redo_zero;
-	}
+	if (ret < 0)
+		goto err;
 
 	/*
 	 *  Bad read buffer
 	 */
 	if (badbuf) {
-redo_badbuf:
 		ret = read(fd, badbuf, SYS_BUF_SZ);
-		if (ret < 0) {
-			if ((errno == EAGAIN) || (errno == EINTR))
-				goto redo_badbuf;
-		}
+		if (ret < 0)
+			goto err;
 	}
+err:
+	(void)close(fd);
+
+	/*
+	 *  Zero sized writes
+	 */
+	if ((fd = open(path, O_WRONLY | O_NONBLOCK)) < 0)
+		return;
+	ret = write(fd, buffer, 0);
+	(void)ret;
 	(void)close(fd);
 }
 
 /*
- *  stress_sys_read_thread
+ *  stress_sys_rw_thread
  *	keep exercising a sysfs entry until
  *	controlling thread triggers an exit
  */
-static void *stress_sys_read_thread(void *ctxt_ptr)
+static void *stress_sys_rw_thread(void *ctxt_ptr)
 {
 	static void *nowt = NULL;
-	uint8_t stack[SIGSTKSZ] = { 0 };
+	uint8_t stack[SIGSTKSZ + STACK_ALIGNMENT];
         stack_t ss;
 	ctxt_t *ctxt = (ctxt_t *)ctxt_ptr;
 
@@ -147,6 +132,7 @@ static void *stress_sys_read_thread(void *ctxt_ptr)
 	 *  handle these
 	 */
 	sigprocmask(SIG_BLOCK, &set, NULL);
+	memset(stack, 0, sizeof(stack));
 
 	/*
 	 *  According to POSIX.1 a thread should have
@@ -154,7 +140,7 @@ static void *stress_sys_read_thread(void *ctxt_ptr)
 	 *  However, we block signals in this thread
 	 *  so this is probably just totally unncessary.
 	 */
-	ss.ss_sp = (void *)stack;
+	ss.ss_sp = (void *)align_address(stack, STACK_ALIGNMENT);
 	ss.ss_size = SIGSTKSZ;
 	ss.ss_flags = 0;
 	if (sigaltstack(&ss, NULL) < 0) {
@@ -162,7 +148,7 @@ static void *stress_sys_read_thread(void *ctxt_ptr)
 		return &nowt;
 	}
 	while (keep_running && opt_do_run)
-		stress_sys_read(ctxt->name, ctxt->path, ctxt->badbuf);
+		stress_sys_rw(ctxt->name, ctxt->path, ctxt->badbuf);
 
 	return &nowt;
 }
@@ -171,7 +157,7 @@ static void *stress_sys_read_thread(void *ctxt_ptr)
  *  stress_proc_sys_threads()
  *	create a bunch of threads to thrash read a sys entry
  */
-static void stress_sys_read_threads(const char *name, const char *path)
+static void stress_sys_rw_threads(const char *name, const char *path)
 {
 	size_t i;
 	pthread_t pthreads[MAX_READ_THREADS];
@@ -192,12 +178,12 @@ static void stress_sys_read_threads(const char *name, const char *path)
 
 	for (i = 0; i < MAX_READ_THREADS; i++) {
 		ret[i] = pthread_create(&pthreads[i], NULL,
-				stress_sys_read_thread, &ctxt);
+				stress_sys_rw_thread, &ctxt);
 	}
 	for (i = 0; i < 8; i++) {
 		if (!opt_do_run)
 			break;
-		stress_sys_read(name, path, ctxt.badbuf);
+		stress_sys_rw(name, path, ctxt.badbuf);
 	}
 	keep_running = false;
 
@@ -219,7 +205,7 @@ static void stress_sys_dir(
 	const char *path,
 	const bool recurse,
 	const int depth,
-	bool sys_read)
+	bool sys_rw)
 {
 	DIR *dp;
 	struct dirent *d;
@@ -249,14 +235,14 @@ static void stress_sys_dir(
 				snprintf(filename, sizeof(filename),
 					"%s/%s", path, d->d_name);
 				stress_sys_dir(name, filename, recurse,
-					depth + 1, sys_read);
+					depth + 1, sys_rw);
 			}
 			break;
 		case DT_REG:
-			if (sys_read) {
+			if (sys_rw) {
 				snprintf(filename, sizeof(filename),
 					"%s/%s", path, d->d_name);
-				stress_sys_read_threads(name, filename);
+				stress_sys_rw_threads(name, filename);
 			}
 			break;
 		default:
@@ -276,21 +262,32 @@ int stress_sysfs(
 	const uint64_t max_ops,
 	const char *name)
 {
-	bool sys_read = true;
+	bool sys_rw = true;
 
 	(void)instance;
 
-	if ((instance == 0) && (geteuid() == 0)) {
-		pr_inf(stderr, "%s: running as root, just traversing /sys "
-			"and not reading files.\n", name);
-		sys_read = false;
+	if (geteuid() == 0) {
+		if (instance == 0) {
+			pr_inf(stderr, "%s: running as root, just traversing /sys "
+				"and not read/writing to /sys files.\n", name);
+		}
+		sys_rw = false;
 	}
 
 	do {
-		stress_sys_dir(name, "/sys", true, 0, sys_read);
+		stress_sys_dir(name, "/sys", true, 0, sys_rw);
 		(*counter)++;
 	} while (opt_do_run && (!max_ops || *counter < max_ops));
 
 	return EXIT_SUCCESS;
 }
+#else
+int stress_sysfs(
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
+{
+	return stress_not_implemented(counter, instance, max_ops, name);
+}
 #endif
