@@ -22,20 +22,13 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
 
-#include <stdlib.h>
-#include <string.h>
-#include <unistd.h>
-#include <errno.h>
 #if defined(__linux__)
 #include <sys/sysinfo.h>
 #include <sys/statfs.h>
 #endif
 #include <sys/statvfs.h>
-#include <sys/times.h>
 
 #define check_do_run()		\
 	if (!opt_do_run)	\
@@ -61,8 +54,9 @@ int stress_sysinfo(
 		pr_err(stderr, "%s: failed to get mount points\n", name);
 		return EXIT_FAILURE;
 	}
-	pr_dbg(stderr, "%s: found %d mount points\n",
-		name, n_mounts);
+	if (instance == 0)
+		pr_dbg(stderr, "%s: found %d mount points\n",
+			name, n_mounts);
 
 	do {
 		struct tms tms_buf;
@@ -77,8 +71,7 @@ int stress_sysinfo(
 #if defined(__linux__)
 		ret = sysinfo(&sysinfo_buf);
 		if ((ret < 0) && (opt_flags & OPT_FLAGS_VERIFY)) {
-			 pr_fail(stderr, "%s: sysinfo failed: errno=%d (%s)\n",
-				name, errno, strerror(errno));
+			 pr_fail_err(name, "sysinfo");
 		}
 		check_do_run();
 
@@ -154,8 +147,7 @@ int stress_sysinfo(
 		check_do_run();
 		clk = times(&tms_buf);
 		if ((clk == (clock_t)-1) && (opt_flags & OPT_FLAGS_VERIFY)) {
-			 pr_fail(stderr, "%s: times failed: errno=%d (%s)\n",
-				name, errno, strerror(errno));
+			 pr_fail_err(name, "times");
 		}
 		(*counter)++;
 	} while (opt_do_run && (!max_ops || *counter < max_ops));
