@@ -22,23 +22,9 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
 
-#if defined(STRESS_TEE)
-
-#include <fcntl.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <unistd.h>
-#include <errno.h>
-#include <limits.h>
-#include <string.h>
-#include <sys/types.h>
-#include <sys/wait.h>
-#include <signal.h>
+#if defined(__linux__) && NEED_GLIBC(2,5,0)
 
 #define TEE_IO_SIZE	(65536)
 
@@ -72,13 +58,13 @@ again:
                 return -1;
         }
         if (pid == 0) {
-		setpgid(0, pgrp);
+		(void)setpgid(0, pgrp);
 		stress_parent_died_alarm();
 
                 func(fds);
                 exit(EXIT_SUCCESS);
         }
-	setpgid(pid, pgrp);
+	(void)setpgid(pid, pgrp);
         return pid;
 }
 
@@ -210,4 +196,13 @@ tidy_child1:
 
 	return ret;
 }
+#else
+int stress_tee(
+        uint64_t *const counter,
+        const uint32_t instance,
+        const uint64_t max_ops,
+        const char *name)
+{
+	return stress_not_implemented(counter, instance, max_ops, name);
+}
 #endif
