@@ -22,26 +22,13 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
 
-#if defined(STRESS_TLB_SHOOTDOWN)
-
-#include <stdio.h>
-#include <stdint.h>
-#include <stdlib.h>
-#include <unistd.h>
-#include <sys/mman.h>
-#include <sys/types.h>
-#include <sys/wait.h>
-#include <signal.h>
-#include <sched.h>
+#if defined(__linux__)
 
 #define MAX_TLB_PROCS	(4)
 #define MMAP_PAGES	(512)
 
-
 /*
  *  stress_tlb_shootdown()
  *	stress out TLB shootdowns
@@ -66,9 +53,7 @@ int stress_tlb_shootdown(
 		const int32_t max_cpus = stress_get_processors_configured();
 
 		if (sched_getaffinity(0, sizeof(proc_mask), &proc_mask) < 0) {
-			pr_fail(stderr, "%s: could not get CPU affinity: "
-				"errno=%d, (%s)\n",
-				name, errno, strerror(errno));
+			pr_fail_err(name, "could not get CPU affinity");
 			return EXIT_FAILURE;
 		}
 		cpus = CPU_COUNT(&proc_mask);
@@ -82,9 +67,7 @@ int stress_tlb_shootdown(
 					if (--retry < 0)
 						return EXIT_NO_RESOURCE;
 				} else {
-					pr_fail(stderr, "%s: mmap failed: "
-						"errno=%d (%s)\n",
-						name, errno, strerror(errno));
+					pr_fail_err(name, "mmap");
 				}
 			} else {
 				break;
@@ -143,5 +126,13 @@ int stress_tlb_shootdown(
 
 	return EXIT_SUCCESS;
 }
-
+#else
+int stress_tlb_shootdown(
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
+{
+	return stress_not_implemented(counter, instance, max_ops, name);
+}
 #endif
