@@ -22,14 +22,8 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
-#include <stdio.h>
-#include <stdint.h>
-#include <stdlib.h>
-#include <search.h>
-
 #include "stress-ng.h"
+#include <search.h>
 
 static uint64_t opt_tsearch_size = DEFAULT_TSEARCH_SIZE;
 static bool set_tsearch_size = false;
@@ -52,8 +46,8 @@ void stress_set_tsearch_size(const char *optarg)
  */
 static int cmp(const void *p1, const void *p2)
 {
-	int32_t *i1 = (int32_t *)p1;
-	int32_t *i2 = (int32_t *)p2;
+	const int32_t *i1 = (const int32_t *)p1;
+	const int32_t *i2 = (const int32_t *)p2;
 
 	if (*i1 > *i2)
 		return 1;
