@@ -22,31 +22,17 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
+#include "stress-ng.h"
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <string.h>
-#include <stdbool.h>
-#include <signal.h>
-#include <unistd.h>
-#include <errno.h>
-
-#include <sys/types.h>
-#include <sys/socket.h>
-#include <sys/wait.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
-#ifdef AF_INET6
+#if defined(AF_INET6)
 #include <netinet/in.h>
 #endif
-#ifdef AF_UNIX
+#if defined(AF_UNIX)
 #include <sys/un.h>
 #endif
 
-#include "stress-ng.h"
-
 /* See bugs section of udplite(7) */
 #if !defined(SOL_UDPLITE)
 #define SOL_UDPLITE		(136)
@@ -99,14 +85,14 @@ int stress_udp(
 {
 	pid_t pid, ppid = getppid();
 	int rc = EXIT_SUCCESS;
-#if defined(OPT_UDP_LITE)
+#if defined(IPPROTO_UDPLITE)
 	int proto = (opt_flags & OPT_FLAGS_UDP_LITE) ?
 		IPPROTO_UDPLITE : IPPROTO_UDP;
 #else
 	int proto = 0;
 #endif
 
-#if defined(OPT_UDP_LITE)
+#if defined(IPPROTO_UDPLITE)
 	if ((proto == IPPROTO_UDPLITE) &&
 	    (opt_udp_domain == AF_UNIX)) {
 		proto = 0;
@@ -119,7 +105,7 @@ int stress_udp(
 #endif
 
 	pr_dbg(stderr, "%s: process [%d] using udp port %d\n",
-		name, getpid(), opt_udp_port + instance);
+		name, (int)getpid(), opt_udp_port + instance);
 
 again:
 	pid = fork();
@@ -132,7 +118,7 @@ again:
 		/* Child, client */
 		struct sockaddr *addr = NULL;
 
-		setpgid(0, pgrp);
+		(void)setpgid(0, pgrp);
 		stress_parent_died_alarm();
 
 		do {
@@ -140,7 +126,7 @@ again:
 			socklen_t len;
 			int fd;
 			int j = 0;
-#if defined(OPT_UDP_LITE)
+#if defined(IPPROTO_UDPLITE)
 			int val;
 #endif
 
@@ -153,7 +139,7 @@ again:
 			stress_set_sockaddr(name, instance, ppid,
 				opt_udp_domain, opt_udp_port,
 				&addr, &len, NET_ADDR_ANY);
-#if defined(OPT_UDP_LITE)
+#if defined(IPPROTO_UDPLITE)
 			if (proto == IPPROTO_UDPLITE) {
 				val = 8;	/* Just the 8 byte header */
 				if (setsockopt(fd, SOL_UDPLITE, UDPLITE_SEND_CSCOV, &val, sizeof(int)) < 0) {
@@ -180,7 +166,7 @@ again:
 			(void)close(fd);
 		} while (opt_do_run && (!max_ops || *counter < max_ops));
 
-#ifdef AF_UNIX
+#if defined(AF_UNIX)
 		if ((opt_udp_domain == AF_UNIX) && addr) {
 			struct sockaddr_un *addr_un = (struct sockaddr_un *)addr;
 			(void)unlink(addr_un->sun_path);
@@ -194,14 +180,16 @@ again:
 
 		char buf[UDP_BUF];
 		int fd, status;
+#if !defined(__minix__)
 		int so_reuseaddr = 1;
-#if defined(OPT_UDP_LITE)
+#endif
+#if defined(IPPROTO_UDPLITE)
 		int val;
 #endif
 		socklen_t addr_len = 0;
 		struct sockaddr *addr = NULL;
 
-		setpgid(pid, pgrp);
+		(void)setpgid(pid, pgrp);
 
 		if (stress_sighandler(name, SIGALRM, handle_udp_sigalrm, NULL) < 0) {
 			rc = EXIT_FAILURE;
@@ -215,7 +203,7 @@ again:
 		stress_set_sockaddr(name, instance, ppid,
 			opt_udp_domain, opt_udp_port,
 			&addr, &addr_len, NET_ADDR_ANY);
-#if defined(OPT_UDP_LITE)
+#if defined(IPPROTO_UDPLITE)
 		if (proto == IPPROTO_UDPLITE) {
 			val = 8;	/* Just the 8 byte header */
 			if (setsockopt(fd, SOL_UDPLITE, UDPLITE_RECV_CSCOV, &val, sizeof(int)) < 0) {
@@ -230,11 +218,13 @@ again:
 			rc = EXIT_FAILURE;
 			goto die_close;
 		}
+#if !defined(__minix__)
 		if (setsockopt(fd, SOL_SOCKET, SO_REUSEADDR, &so_reuseaddr, sizeof(so_reuseaddr)) < 0) {
 			pr_fail_dbg(name, "setsockopt");
 			rc = EXIT_FAILURE;
 			goto die_close;
 		}
+#endif
 
 		do {
 			socklen_t len = addr_len;
@@ -252,7 +242,7 @@ again:
 die_close:
 		(void)close(fd);
 die:
-#ifdef AF_UNIX
+#if defined(AF_UNIX)
 		if ((opt_udp_domain == AF_UNIX) && addr) {
 			struct sockaddr_un *addr_un = (struct sockaddr_un *)addr;
 			(void)unlink(addr_un->sun_path);
