@@ -22,22 +22,12 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
 
-#if defined(STRESS_URANDOM)
+#if defined(__linux__) || defined(__gnu_hurd__)
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <unistd.h>
-#include <fcntl.h>
-#include <sys/types.h>
-#include <sys/stat.h>
 #if defined(__linux__)
 #include <linux/random.h>
-#include <sys/ioctl.h>
 #endif
 
 #if defined(__linux__) && defined(RNDGETENTCNT)
@@ -91,7 +81,7 @@ int stress_urandom(
 
 #if defined(DEV_RANDOM)
 		/*
-		 * Fetch entropy pool count, not considered fatal 
+		 * Fetch entropy pool count, not considered fatal
 		 * this fails, just skip this part of the stressor
 		 */
 		if (ioctl(fd_rnd, RNDGETENTCNT, &val) < 0)
@@ -120,4 +110,13 @@ err:
 
 	return rc;
 }
+#else
+int stress_urandom(
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
+{
+	return stress_not_implemented(counter, instance, max_ops, name);
+}
 #endif
