@@ -22,25 +22,11 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
 
-#if defined(STRESS_USERFAULTFD)
+#if defined(__linux__) && defined(__NR_userfaultfd)
 
-#include <stddef.h>
-#include <stdio.h>
-#include <stdint.h>
-#include <stdlib.h>
-#include <stdbool.h>
-#include <unistd.h>
-#include <fcntl.h>
 #include <poll.h>
-#include <sys/syscall.h>
-#include <sys/mman.h>
-#include <sys/ioctl.h>
-#include <sys/types.h>
-#include <sys/wait.h>
 #include <linux/userfaultfd.h>
 
 #define STACK_SIZE	(64 * 1024)
@@ -56,14 +42,11 @@ typedef struct {
 	pid_t parent;
 } context_t;
 
+#endif
+
 static size_t opt_userfaultfd_bytes = DEFAULT_MMAP_BYTES;
 static bool set_userfaultfd_bytes = false;
 
-static int sys_userfaultfd(int flags)
-{
-	return syscall(__NR_userfaultfd, flags);
-}
-
 void stress_set_userfaultfd_bytes(const char *optarg)
 {
 	set_userfaultfd_bytes = true;
@@ -72,6 +55,20 @@ void stress_set_userfaultfd_bytes(const char *optarg)
 		MIN_MMAP_BYTES, MAX_MMAP_BYTES);
 }
 
+#if defined(__linux__) && defined(__NR_userfaultfd)
+
+/*
+ *  stress_child_alarm_handler()
+ *	SIGALRM handler to terminate child immediately
+ */
+static void MLOCKED stress_child_alarm_handler(int dummy)
+{
+        (void)dummy;
+
+	_exit(0);
+}
+
+
 /*
  *  stress_userfaultfd_child()
  *	generate page faults for parent to handle
@@ -80,6 +77,11 @@ static int stress_userfaultfd_child(void *arg)
 {
 	context_t *c = (context_t *)arg;
 
+	(void)setpgid(0, pgrp);
+	stress_parent_died_alarm();
+	if (stress_sighandler(c->name, SIGALRM, stress_child_alarm_handler, NULL) < 0)
+		return EXIT_NO_RESOURCE;
+
 	do {
 		uint8_t *ptr, *end = c->data + c->sz;
 
@@ -92,7 +94,6 @@ static int stress_userfaultfd_child(void *arg)
 		/* and trigger some page faults */
 		for (ptr = c->data; ptr < end; ptr += c->page_size)
 			*ptr = 0xff;
-
 	} while (opt_do_run && (!c->max_ops || *c->counter < c->max_ops));
 
 	return 0;
@@ -144,10 +145,12 @@ static inline int handle_page_fault(
 }
 
 /*
- *  stress_userfaultfd()
- *	stress userfaultfd
+ *  stress_userfaultfd_oomable()
+ *	stress userfaultfd system call, this
+ *	is an OOM-able child process that the
+ *	parent can restart
  */
-int stress_userfaultfd(
+static int stress_userfaultfd_oomable(
 	uint64_t *const counter,
 	const uint32_t instance,
 	const uint64_t max_ops,
@@ -157,7 +160,7 @@ int stress_userfaultfd(
 	size_t sz;
 	uint8_t *data;
 	void *zero_page = NULL;
-	int fd, status, rc = EXIT_SUCCESS;
+	int fd = -1, status, rc = EXIT_SUCCESS;
 	const unsigned int uffdio_copy = 1 << _UFFDIO_COPY;
 	const unsigned int uffdio_zeropage = 1 << _UFFDIO_ZEROPAGE;
 	pid_t pid;
@@ -169,7 +172,7 @@ int stress_userfaultfd(
 	/* Child clone stack */
 	static uint8_t stack[STACK_SIZE];
         const ssize_t stack_offset =
-                stress_get_stack_direction(&fd) * (STACK_SIZE - 64);
+                stress_get_stack_direction() * (STACK_SIZE - 64);
 	uint8_t *stack_top = stack + stack_offset;
 
 	(void)instance;
@@ -183,21 +186,20 @@ int stress_userfaultfd(
 	sz = opt_userfaultfd_bytes & ~(page_size - 1);
 
 	if (posix_memalign(&zero_page, page_size, page_size)) {
-		rc = exit_status(errno);
 		pr_err(stderr, "%s: zero page allocation failed\n", name);
-		return rc;
+		return EXIT_NO_RESOURCE;
 	}
 
 	data = mmap(NULL, sz, PROT_READ | PROT_WRITE,
 		MAP_PRIVATE | MAP_ANONYMOUS, -1, 0);
 	if (data == MAP_FAILED) {
-		rc = exit_status(errno);
+		rc = EXIT_NO_RESOURCE;
 		pr_err(stderr, "%s: mmap failed\n", name);
 		goto free_zeropage;
 	}
 
 	/* Get userfault fd */
-	if ((fd = sys_userfaultfd(0)) < 0) {
+	if ((fd = shim_userfaultfd(0)) < 0) {
 		rc = exit_status(errno);
 		pr_err(stderr, "%s: userfaultfd failed, errno = %d (%s)\n",
 			name, errno, strerror(errno));
@@ -359,8 +361,73 @@ unmap_data:
 	(void)munmap(data, sz);
 free_zeropage:
 	free(zero_page);
-
 	return rc;
 }
 
+/*
+ *  stress_userfaultfd()
+ *	stress userfaultfd
+ */
+int stress_userfaultfd(
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
+{
+	pid_t pid;
+	int rc = EXIT_FAILURE;
+
+	pid = fork();
+	if (pid < 0) {
+		if (errno == EAGAIN)
+			return EXIT_NO_RESOURCE;
+		pr_err(stderr, "%s: fork failed: errno=%d: (%s)\n",
+			name, errno, strerror(errno));
+	} else if (pid > 0) {
+		/* Parent */
+		int status, ret;
+
+		(void)setpgid(pid, pgrp);
+		ret = waitpid(pid, &status, 0);
+		if (ret < 0) {
+			if (errno != EINTR)
+				pr_dbg(stderr, "%s: waitpid(): errno=%d (%s)\n",
+					name, errno, strerror(errno));
+			(void)kill(pid, SIGTERM);
+			(void)kill(pid, SIGKILL);
+			(void)waitpid(pid, &status, 0);
+		} else if (WIFSIGNALED(status)) {
+			pr_dbg(stderr, "%s: child died: %s (instance %d)\n",
+				name, stress_strsignal(WTERMSIG(status)),
+				instance);
+			/* If we got killed by OOM killer, report this */
+			if (WTERMSIG(status) == SIGKILL) {
+				log_system_mem_info();
+				pr_dbg(stderr, "%s: assuming killed by OOM "
+					"killer, aborting "
+					"(instance %d)\n",
+					name, instance);
+				return EXIT_NO_RESOURCE;
+			}
+			return EXIT_FAILURE;
+		}
+		rc = WEXITSTATUS(status);
+	} else if (pid == 0) {
+		/* Child */
+		(void)setpgid(0, pgrp);
+		stress_parent_died_alarm();
+
+		_exit(stress_userfaultfd_oomable(counter, instance, max_ops, name));
+	}
+	return rc;
+}
+#else
+int stress_userfaultfd(
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
+{
+	return stress_not_implemented(counter, instance, max_ops, name);
+}
 #endif
