@@ -22,22 +22,14 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
 
-#if defined(STRESS_VM_RW)
+#if defined(__linux__) &&		\
+    defined(__NR_process_vm_readv) &&	\
+    defined(__NR_process_vm_writev) &&	\
+    NEED_GLIBC(2,15,0)
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <unistd.h>
-#include <signal.h>
-#include <sys/types.h>
-#include <sys/wait.h>
-#include <sys/mman.h>
 #include <sys/uio.h>
-#include <errno.h>
 
 #define STACK_SIZE	(64 * 1024)
 
@@ -57,6 +49,8 @@ typedef struct {
 	uint8_t val;	/* Value to check */
 } addr_msg_t;
 
+#endif
+
 static size_t opt_vm_rw_bytes = DEFAULT_VM_RW_BYTES;
 static bool set_vm_rw_bytes = false;
 
@@ -68,7 +62,12 @@ void stress_set_vm_rw_bytes(const char *optarg)
 		MIN_VM_RW_BYTES, MAX_VM_RW_BYTES);
 }
 
-int stress_vm_child(void *arg)
+#if defined(__linux__) &&		\
+    defined(__NR_process_vm_readv) &&	\
+    defined(__NR_process_vm_writev) &&	\
+    NEED_GLIBC(2,15,0)
+
+static int stress_vm_child(void *arg)
 {
 	context_t *ctxt = (context_t *)arg;
 
@@ -76,7 +75,7 @@ int stress_vm_child(void *arg)
 	int ret = EXIT_SUCCESS;
 	addr_msg_t msg_rd, msg_wr;
 
-	setpgid(0, pgrp);
+	(void)setpgid(0, pgrp);
 	stress_parent_died_alarm();
 
 	/* Close unwanted ends */
@@ -93,7 +92,7 @@ int stress_vm_child(void *arg)
 
 	while (opt_do_run) {
 		uint8_t *ptr, *end = buf + ctxt->sz;
-		int ret;
+		int rwret;
 
 		memset(&msg_wr, 0, sizeof(msg_wr));
 		msg_wr.addr = buf;
@@ -101,8 +100,8 @@ int stress_vm_child(void *arg)
 
 		/* Send address of buffer to parent */
 redo_wr1:
-		ret = write(ctxt->pipe_wr[1], &msg_wr, sizeof(msg_wr));
-		if (ret < 0) {
+		rwret = write(ctxt->pipe_wr[1], &msg_wr, sizeof(msg_wr));
+		if (rwret < 0) {
 			if ((errno == EAGAIN) || (errno == EINTR))
 				goto redo_wr1;
 			if (errno != EBADF)
@@ -111,16 +110,16 @@ redo_wr1:
 		}
 redo_rd1:
 		/* Wait for parent to populate data */
-		ret = read(ctxt->pipe_rd[0], &msg_rd, sizeof(msg_rd));
-		if (ret < 0) {
+		rwret = read(ctxt->pipe_rd[0], &msg_rd, sizeof(msg_rd));
+		if (rwret < 0) {
 			if ((errno == EAGAIN) || (errno == EINTR))
 				goto redo_rd1;
 			pr_fail_dbg(ctxt->name, "read");
 			break;
 		}
-		if (ret == 0)
+		if (rwret == 0)
 			break;
-		if (ret != sizeof(msg_rd)) {
+		if (rwret != sizeof(msg_rd)) {
 			pr_fail_dbg(ctxt->name, "read");
 			break;
 		}
@@ -154,7 +153,7 @@ cleanup:
 	return ret;
 }
 
-int stress_vm_parent(context_t *ctxt)
+static int stress_vm_parent(context_t *ctxt)
 {
 	/* Parent */
 	int status;
@@ -162,7 +161,7 @@ int stress_vm_parent(context_t *ctxt)
 	uint8_t *localbuf;
 	addr_msg_t msg_rd, msg_wr;
 
-	setpgid(ctxt->pid, pgrp);
+	(void)setpgid(ctxt->pid, pgrp);
 
 	localbuf = mmap(NULL, ctxt->sz, PROT_READ | PROT_WRITE,
 			MAP_ANONYMOUS | MAP_PRIVATE, -1, 0);
@@ -289,7 +288,7 @@ int stress_vm_rw(
 	context_t ctxt;
 	uint8_t stack[64*1024];
 	const ssize_t stack_offset =
-		stress_get_stack_direction(&ctxt) * (STACK_SIZE - 64);
+		stress_get_stack_direction() * (STACK_SIZE - 64);
 	uint8_t *stack_top = stack + stack_offset;
 
 	(void)instance;
@@ -329,5 +328,13 @@ int stress_vm_rw(
 	}
 	return stress_vm_parent(&ctxt);
 }
-
+#else
+int stress_vm_rw(
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
+{
+	return stress_not_implemented(counter, instance, max_ops, name);
+}
 #endif
