@@ -22,21 +22,8 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
 
-#if defined(STRESS_VM_SPLICE)
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <unistd.h>
-#include <fcntl.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <sys/mman.h>
-
 static size_t opt_vm_splice_bytes = DEFAULT_VM_SPLICE_BYTES;
 static bool set_vm_splice_bytes = false;
 
@@ -48,6 +35,8 @@ void stress_set_vm_splice_bytes(const char *optarg)
 		MIN_VM_SPLICE_BYTES, MAX_VM_SPLICE_BYTES);
 }
 
+#if defined(__linux__) && NEED_GLIBC(2,5,0)
+
 /*
  *  stress_splice
  *	stress copying of /dev/zero to /dev/null
@@ -122,5 +111,13 @@ int stress_vm_splice(
 
 	return EXIT_SUCCESS;
 }
-
+#else
+int stress_vm_splice(
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
+{
+	return stress_not_implemented(counter, instance, max_ops, name);
+}
 #endif
