@@ -22,17 +22,6 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <signal.h>
-#include <errno.h>
-#include <sys/mman.h>
-#include <sys/types.h>
-#include <sys/wait.h>
-
 #include "stress-ng.h"
 
 #define VM_BOGO_SHIFT		(12)
@@ -40,7 +29,6 @@
 
 #define NO_MEM_RETRIES_MAX	(100)
 
-
 /*
  *  the VM stress test has diffent methods of vm stressor
  */
@@ -704,7 +692,7 @@ static size_t stress_vm_swap(
 	const size_t chunk_sz = 64, chunks = sz / chunk_sz;
 	uint64_t w1, z1, c = *counter;
 	uint8_t *buf_end = buf + sz;
-	volatile uint8_t *ptr;
+	uint8_t *ptr;
 	size_t bit_errors = 0, i;
 	size_t *swaps;
 
@@ -731,9 +719,9 @@ static size_t stress_vm_swap(
 	for (i = 0, ptr = buf; ptr < buf_end; ptr += chunk_sz, i++) {
 		size_t offset = swaps[i];
 
-		volatile uint8_t *dst = buf + offset,
-			*src = ptr,
-			*src_end = src + chunk_sz;
+		volatile uint8_t *dst = buf + offset;
+		volatile uint8_t *src = (volatile uint8_t *)ptr;
+		volatile uint8_t *src_end = src + chunk_sz;
 
 		while (src < src_end) {
 			uint8_t tmp = *src;
@@ -750,9 +738,9 @@ static size_t stress_vm_swap(
 	for (i = chunks - 1, ptr = buf_end - chunk_sz; ptr >= buf; ptr -= chunk_sz, i--) {
 		size_t offset = swaps[i];
 
-		volatile uint8_t *dst = buf + offset,
-			*src = ptr,
-			*src_end = src + chunk_sz;
+		volatile uint8_t *dst = buf + offset;
+		volatile uint8_t *src = (volatile uint8_t *)ptr;
+		volatile uint8_t *src_end = src + chunk_sz;
 
 		while (src < src_end) {
 			uint8_t tmp = *src;
@@ -771,7 +759,8 @@ static size_t stress_vm_swap(
 
 	mwc_seed(w1, z1);
 	for (ptr = buf; ptr < buf_end; ptr += chunk_sz) {
-		volatile uint8_t *p = ptr, *p_end = ptr + chunk_sz;
+		volatile uint8_t *p = (volatile uint8_t *)ptr;
+		volatile uint8_t *p_end = (volatile uint8_t *)ptr + chunk_sz;
 		uint8_t val = mwc8();
 
 		while (p < p_end) {
@@ -1919,7 +1908,7 @@ again:
 		int status, ret;
 
 		/* Parent, wait for child */
-		setpgid(pid, pgrp);
+		(void)setpgid(pid, pgrp);
 		ret = waitpid(pid, &status, 0);
 		if (ret < 0) {
 			if (errno != EINTR)
@@ -1945,7 +1934,7 @@ again:
 	} else if (pid == 0) {
 		int no_mem_retries = 0;
 
-		setpgid(0, pgrp);
+		(void)setpgid(0, pgrp);
 		stress_parent_died_alarm();
 
 		/* Make sure this is killable by OOM killer */
@@ -1967,7 +1956,7 @@ again:
 				if (buf == MAP_FAILED) {
 					buf = NULL;
 					no_mem_retries++;
-					usleep(100000);
+					(void)shim_usleep(100000);
 					continue;	/* Try again */
 				}
 				(void)madvise_random(buf, buf_sz);
