@@ -22,21 +22,9 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
 
-#if defined(STRESS_WAIT)
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <inttypes.h>
-#include <string.h>
-#include <unistd.h>
-#include <signal.h>
-#include <sys/types.h>
-#include <sys/wait.h>
+#if !defined(__gnu_hurd__) && !defined(__NetBSD__)
 
 #define ABORT_TIMEOUT	(8.0)
 
@@ -62,13 +50,13 @@ again:
 		return -1;
 	}
 	if (pid == 0) {
-		setpgid(0, pgrp);
+		(void)setpgid(0, pgrp);
 		stress_parent_died_alarm();
 
 		func(name, pid_arg, counter, max_ops);
 		exit(EXIT_SUCCESS);
 	}
-	setpgid(pid, pgrp);
+	(void)setpgid(pid, pgrp);
 	return pid;
 }
 
@@ -85,7 +73,7 @@ static void runner(
 {
 	(void)pid;
 
-	pr_dbg(stderr, "%s: wait: runner started [%d]\n", name, getpid());
+	pr_dbg(stderr, "%s: wait: runner started [%d]\n", name, (int)getpid());
 
 	do {
 		(void)pause();
@@ -108,7 +96,7 @@ static void killer(
 	double start = time_now();
 	uint64_t last_counter = *counter;
 
-	pr_dbg(stderr, "%s: wait: killer started [%d]\n", name, getpid());
+	pr_dbg(stderr, "%s: wait: killer started [%d]\n", name, (int)getpid());
 
 	do {
 		(void)kill(pid, SIGSTOP);
@@ -156,7 +144,7 @@ int stress_wait(
 	(void)instance;
 
 	pr_dbg(stderr, "%s: waiter started [%d]\n",
-		name, getpid());
+		name, (int)getpid());
 
 	pid_r = spawn(name, runner, 0, counter, max_ops);
 	if (pid_r < 0) {
@@ -217,5 +205,13 @@ tidy:
 
 	return ret;
 }
-
+#else
+int stress_wait(
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
+{
+	return stress_not_implemented(counter, instance, max_ops, name);
+}
 #endif
