@@ -22,24 +22,12 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
 
-#if defined(STRESS_XATTR)
+#if defined(__linux__) && defined(HAVE_XATTR_H)
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <unistd.h>
-#include <errno.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <fcntl.h>
-#include <sys/types.h>
 #include <attr/xattr.h>
 
-
 /*
  *  stress_xattr
  *	stress the xattr operations
@@ -70,17 +58,16 @@ int stress_xattr(
 
 	do {
 		int i, j;
-		int ret;
-		char name[32];
+		char attrname[32];
 		char value[32];
 		ssize_t sz;
 		char *buffer;
 
 		for (i = 0; i < 4096; i++) {
-			snprintf(name, sizeof(name), "user.var_%d", i);
-			snprintf(value, sizeof(value), "orig-value-%i", i);
+			snprintf(attrname, sizeof(attrname), "user.var_%d", i);
+			snprintf(value, sizeof(value), "orig-value-%d", i);
 
-			ret = fsetxattr(fd, name, value, strlen(value), XATTR_CREATE);
+			ret = fsetxattr(fd, attrname, value, strlen(value), XATTR_CREATE);
 			if (ret < 0) {
 				if (errno == ENOTSUP) {
 					pr_inf(stderr, "%s stressor will be "
@@ -94,10 +81,10 @@ int stress_xattr(
 			}
 		}
 		for (j = 0; j < i; j++) {
-			snprintf(name, sizeof(name), "user.var_%d", j);
-			snprintf(value, sizeof(value), "value-%i", j);
+			snprintf(attrname, sizeof(attrname), "user.var_%d", j);
+			snprintf(value, sizeof(value), "value-%d", j);
 
-			ret = fsetxattr(fd, name, value, strlen(value),
+			ret = fsetxattr(fd, attrname, value, strlen(value),
 				XATTR_REPLACE);
 			if (ret < 0) {
 				if (errno == ENOSPC || errno == EDQUOT)
@@ -109,10 +96,10 @@ int stress_xattr(
 		for (j = 0; j < i; j++) {
 			char tmp[sizeof(value)];
 
-			snprintf(name, sizeof(name), "user.var_%d", j);
-			snprintf(value, sizeof(value), "value-%i", j);
+			snprintf(attrname, sizeof(attrname), "user.var_%d", j);
+			snprintf(value, sizeof(value), "value-%d", j);
 
-			ret = fgetxattr(fd, name, tmp, sizeof(tmp));
+			ret = fgetxattr(fd, attrname, tmp, sizeof(tmp));
 			if (ret < 0) {
 				pr_fail_err(name, "fgetxattr");
 				goto out_close;
@@ -127,7 +114,7 @@ int stress_xattr(
 		/* Determine how large a buffer we required... */
 		sz = flistxattr(fd, NULL, 0);
 		if (sz < 0) {
-			pr_fail_err(name, "fremovexattr");
+			pr_fail_err(name, "flistxattr");
 			goto out_close;
 		}
 		buffer = malloc(sz);
@@ -137,14 +124,14 @@ int stress_xattr(
 			free(buffer);
 
 			if (sz < 0) {
-				pr_fail_err(name, "fremovexattr");
+				pr_fail_err(name, "flistxattr");
 				goto out_close;
 			}
 		}
 		for (j = 0; j < i; j++) {
-			snprintf(name, sizeof(name), "user.var_%d", j);
-			
-			ret = fremovexattr(fd, name);
+			snprintf(attrname, sizeof(attrname), "user.var_%d", j);
+
+			ret = fremovexattr(fd, attrname);
 			if (ret < 0) {
 				pr_fail_err(name, "fremovexattr");
 				goto out_close;
@@ -160,5 +147,13 @@ out:
 	(void)stress_temp_dir_rm(name, pid, instance);
 	return rc;
 }
-
+#else
+int stress_xattr(
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
+{
+	return stress_not_implemented(counter, instance, max_ops, name);
+}
 #endif
