@@ -22,26 +22,9 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
 #include "stress-ng.h"
 
-#if defined(STRESS_YIELD)
-
-#include <stdlib.h>
-#include <string.h>
-#include <unistd.h>
-#include <errno.h>
-#include <sched.h>
-#include <sys/types.h>
-#include <sys/wait.h>
-#include <signal.h>
-#if defined(__sun__)
-#include <alloca.h>
-#endif
-#if defined(__linux__) && NEED_GLIBC(2,3,0)
-#include <sched.h>
-#endif
+#if defined(_POSIX_PRIORITY_SCHEDULING) && !defined(__minix__)
 
 /*
  *  stress on sched_yield()
@@ -104,7 +87,11 @@ int stress_yield(
 
 	max_ops_per_yielder = max_ops / yielders;
 	yielders_sz = yielders * sizeof(pid_t);
-	pids = alloca(yielders_sz);
+	pids = calloc(yielders, sizeof(pid_t));
+	if (!pids) {
+		pr_err(stderr, "%s: calloc failed\n", name);
+		return EXIT_NO_RESOURCE;
+	}
 	memset(pids, 0, yielders_sz);
 
 	counters_sz = yielders * sizeof(uint64_t);
@@ -115,6 +102,7 @@ int stress_yield(
 
 		pr_err(stderr, "%s: mmap failed: errno=%d (%s)\n",
 			name, errno, strerror(errno));
+		free(pids);
 		return rc;
 	}
 	memset(counters, 0, counters_sz);
@@ -126,16 +114,15 @@ int stress_yield(
 				", yielder %zd): errno=%d (%s)\n",
 				name, instance, i, errno, strerror(errno));
 		} else if (pids[i] == 0) {
-			setpgid(0, pgrp);
+			(void)setpgid(0, pgrp);
 			stress_parent_died_alarm();
 
 			do {
 				int ret;
 
-				ret = sched_yield();
+				ret = shim_sched_yield();
 				if ((ret < 0) && (opt_flags & OPT_FLAGS_VERIFY))
-					pr_fail(stderr, "%s: sched_yield failed: errno=%d (%s)\n",
-						name, errno, strerror(errno));
+					pr_fail_err(name, "sched_yield");
 				counters[i]++;
 			} while (opt_do_run && (!max_ops_per_yielder || *counter < max_ops_per_yielder));
 			_exit(EXIT_SUCCESS);
@@ -160,7 +147,17 @@ int stress_yield(
 		}
 	}
 	(void)munmap((void *)counters, counters_sz);
+	free(pids);
 
 	return EXIT_SUCCESS;
 }
+#else
+int stress_yield(
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
+{
+	return stress_not_implemented(counter, instance, max_ops, name);
+}
 #endif
