@@ -22,15 +22,6 @@
  * functionality.
  *
  */
-#define _GNU_SOURCE
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <unistd.h>
-#include <sys/types.h>
-#include <sys/wait.h>
-
 #include "stress-ng.h"
 
 static uint64_t opt_zombie_max = DEFAULT_ZOMBIES;
@@ -85,7 +76,7 @@ static zombie_t *stress_zombie_new(void)
  *	reap a zombie and remove a zombie from head of list, put it onto
  *	the free zombie list
  */
-void stress_zombie_head_remove(void)
+static void stress_zombie_head_remove(void)
 {
 	if (zombies.head) {
 		int status;
@@ -113,7 +104,7 @@ void stress_zombie_head_remove(void)
  *  stress_zombie_free()
  *	free the zombies off the zombie free lists
  */
-void stress_zombie_free(void)
+static void stress_zombie_free(void)
 {
 	while (zombies.head) {
 		zombie_t *next = zombies.head->next;
@@ -172,7 +163,7 @@ int stress_zombie(
 
 			zombie->pid = fork();
 			if (zombie->pid == 0) {
-				setpgid(0, pgrp);
+				(void)setpgid(0, pgrp);
 				stress_parent_died_alarm();
 
 				stress_zombie_free();
@@ -183,7 +174,7 @@ int stress_zombie(
 				stress_zombie_head_remove();
 				continue;
 			}
-			setpgid(zombie->pid, pgrp);
+			(void)setpgid(zombie->pid, pgrp);
 
 			if (max_zombies < zombies.length)
 				max_zombies = zombies.length;
